<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'phuza: umntu omdala, umntu omdala, ithoni yesikhumba esikhanyayo, ithoni yesikhumba esikhanyayo phakathi',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'phuza: umntu omdala, umntu omdala, ithoni yesikhumba esikhanyayo, ithoni yesikhumba esiphakathi',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'phuza: umntu omdala, umntu omdala, ithoni yesikhumba esikhanyayo, ithoni yesikhumba esiphakathi mnyama',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'phuza: umntu omdala, umntu omdala, ithoni yesikhumba esikhanyayo, ithoni yesikhumba emnyama',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'phuza: umntu omdala, umntu omdala, ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esikhanyayo',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'phuza: umntu omdala, umntu omdala, ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esiphakathi',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'phuza: umntu omdala, umntu omdala, ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esiphakathi mnyama',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'phuza: umntu omdala, umntu omdala, ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba emnyama',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'phuza: umntu omdala, umntu omdala, ithoni yesikhumba esiphakathi, ithoni yesikhumba esikhanyayo',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'phuza: umntu omdala, umntu omdala, ithoni yesikhumba esiphakathi, ithoni yesikhumba esikhanyayo phakathi',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'phuza: umntu omdala, umntu omdala, ithoni yesikhumba esiphakathi, ithoni yesikhumba esiphakathi mnyama',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'phuza: umntu omdala, umntu omdala, ithoni yesikhumba esiphakathi, ithoni yesikhumba emnyama',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'phuza: umntu omdala, umntu omdala, ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esikhanyayo',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'phuza: umntu omdala, umntu omdala, ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esikhanyayo phakathi',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'phuza: umntu omdala, umntu omdala, ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esiphakathi',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'phuza: umntu omdala, umntu omdala, ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba emnyama',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'phuza: umntu omdala, umntu omdala, ithoni yesikhumba emnyama, ithoni yesikhumba esikhanyayo',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'phuza: umntu omdala, umntu omdala, ithoni yesikhumba emnyama, ithoni yesikhumba esikhanyayo phakathi',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'phuza: umntu omdala, umntu omdala, ithoni yesikhumba emnyama, ithoni yesikhumba esiphakathi',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'phuza: umntu omdala, umntu omdala, ithoni yesikhumba emnyama, ithoni yesikhumba esiphakathi mnyama',
    '👨🏻‍❤‍💋‍👨🏻' => 'phuza: indoda, indoda, ithoni yesikhumba esikhanyayo',
    '👨🏻‍❤‍💋‍👨🏼' => 'phuza: indoda, indoda, ithoni yesikhumba esikhanyayo, ithoni yesikhumba esikhanyayo phakathi',
    '👨🏻‍❤‍💋‍👨🏽' => 'phuza: indoda, indoda, ithoni yesikhumba esikhanyayo, ithoni yesikhumba esiphakathi',
    '👨🏻‍❤‍💋‍👨🏾' => 'phuza: indoda, indoda, ithoni yesikhumba esikhanyayo, ithoni yesikhumba esiphakathi mnyama',
    '👨🏻‍❤‍💋‍👨🏿' => 'phuza: indoda, indoda, ithoni yesikhumba esikhanyayo, ithoni yesikhumba emnyama',
    '👨🏼‍❤‍💋‍👨🏻' => 'phuza: indoda, indoda, ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esikhanyayo',
    '👨🏼‍❤‍💋‍👨🏼' => 'phuza: indoda, indoda, ithoni yesikhumba esikhanyayo phakathi',
    '👨🏼‍❤‍💋‍👨🏽' => 'phuza: indoda, indoda, ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esiphakathi',
    '👨🏼‍❤‍💋‍👨🏾' => 'phuza: indoda, indoda, ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esiphakathi mnyama',
    '👨🏼‍❤‍💋‍👨🏿' => 'phuza: indoda, indoda, ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba emnyama',
    '👨🏽‍❤‍💋‍👨🏻' => 'phuza: indoda, indoda, ithoni yesikhumba esiphakathi, ithoni yesikhumba esikhanyayo',
    '👨🏽‍❤‍💋‍👨🏼' => 'phuza: indoda, indoda, ithoni yesikhumba esiphakathi, ithoni yesikhumba esikhanyayo phakathi',
    '👨🏽‍❤‍💋‍👨🏽' => 'phuza: indoda, indoda, ithoni yesikhumba esiphakathi',
    '👨🏽‍❤‍💋‍👨🏾' => 'phuza: indoda, indoda, ithoni yesikhumba esiphakathi, ithoni yesikhumba esiphakathi mnyama',
    '👨🏽‍❤‍💋‍👨🏿' => 'phuza: indoda, indoda, ithoni yesikhumba esiphakathi, ithoni yesikhumba emnyama',
    '👨🏾‍❤‍💋‍👨🏻' => 'phuza: indoda, indoda, ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esikhanyayo',
    '👨🏾‍❤‍💋‍👨🏼' => 'phuza: indoda, indoda, ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esikhanyayo phakathi',
    '👨🏾‍❤‍💋‍👨🏽' => 'phuza: indoda, indoda, ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esiphakathi',
    '👨🏾‍❤‍💋‍👨🏾' => 'phuza: indoda, indoda, ithoni yesikhumba esiphakathi mnyama',
    '👨🏾‍❤‍💋‍👨🏿' => 'phuza: indoda, indoda, ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba emnyama',
    '👨🏿‍❤‍💋‍👨🏻' => 'phuza: indoda, indoda, ithoni yesikhumba emnyama, ithoni yesikhumba esikhanyayo',
    '👨🏿‍❤‍💋‍👨🏼' => 'phuza: indoda, indoda, ithoni yesikhumba emnyama, ithoni yesikhumba esikhanyayo phakathi',
    '👨🏿‍❤‍💋‍👨🏽' => 'phuza: indoda, indoda, ithoni yesikhumba emnyama, ithoni yesikhumba esiphakathi',
    '👨🏿‍❤‍💋‍👨🏾' => 'phuza: indoda, indoda, ithoni yesikhumba emnyama, ithoni yesikhumba esiphakathi mnyama',
    '👨🏿‍❤‍💋‍👨🏿' => 'phuza: indoda, indoda, ithoni yesikhumba emnyama',
    '👩🏻‍❤‍💋‍👨🏻' => 'phuza: ibhinqa, indoda, ithoni yesikhumba esikhanyayo',
    '👩🏻‍❤‍💋‍👨🏼' => 'phuza: ibhinqa, indoda, ithoni yesikhumba esikhanyayo, ithoni yesikhumba esikhanyayo phakathi',
    '👩🏻‍❤‍💋‍👨🏽' => 'phuza: ibhinqa, indoda, ithoni yesikhumba esikhanyayo, ithoni yesikhumba esiphakathi',
    '👩🏻‍❤‍💋‍👨🏾' => 'phuza: ibhinqa, indoda, ithoni yesikhumba esikhanyayo, ithoni yesikhumba esiphakathi mnyama',
    '👩🏻‍❤‍💋‍👨🏿' => 'phuza: ibhinqa, indoda, ithoni yesikhumba esikhanyayo, ithoni yesikhumba emnyama',
    '👩🏼‍❤‍💋‍👨🏻' => 'phuza: ibhinqa, indoda, ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esikhanyayo',
    '👩🏼‍❤‍💋‍👨🏼' => 'phuza: ibhinqa, indoda, ithoni yesikhumba esikhanyayo phakathi',
    '👩🏼‍❤‍💋‍👨🏽' => 'phuza: ibhinqa, indoda, ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esiphakathi',
    '👩🏼‍❤‍💋‍👨🏾' => 'phuza: ibhinqa, indoda, ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esiphakathi mnyama',
    '👩🏼‍❤‍💋‍👨🏿' => 'phuza: ibhinqa, indoda, ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba emnyama',
    '👩🏽‍❤‍💋‍👨🏻' => 'phuza: ibhinqa, indoda, ithoni yesikhumba esiphakathi, ithoni yesikhumba esikhanyayo',
    '👩🏽‍❤‍💋‍👨🏼' => 'phuza: ibhinqa, indoda, ithoni yesikhumba esiphakathi, ithoni yesikhumba esikhanyayo phakathi',
    '👩🏽‍❤‍💋‍👨🏽' => 'phuza: ibhinqa, indoda, ithoni yesikhumba esiphakathi',
    '👩🏽‍❤‍💋‍👨🏾' => 'phuza: ibhinqa, indoda, ithoni yesikhumba esiphakathi, ithoni yesikhumba esiphakathi mnyama',
    '👩🏽‍❤‍💋‍👨🏿' => 'phuza: ibhinqa, indoda, ithoni yesikhumba esiphakathi, ithoni yesikhumba emnyama',
    '👩🏾‍❤‍💋‍👨🏻' => 'phuza: ibhinqa, indoda, ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esikhanyayo',
    '👩🏾‍❤‍💋‍👨🏼' => 'phuza: ibhinqa, indoda, ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esikhanyayo phakathi',
    '👩🏾‍❤‍💋‍👨🏽' => 'phuza: ibhinqa, indoda, ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esiphakathi',
    '👩🏾‍❤‍💋‍👨🏾' => 'phuza: ibhinqa, indoda, ithoni yesikhumba esiphakathi mnyama',
    '👩🏾‍❤‍💋‍👨🏿' => 'phuza: ibhinqa, indoda, ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba emnyama',
    '👩🏿‍❤‍💋‍👨🏻' => 'phuza: ibhinqa, indoda, ithoni yesikhumba emnyama, ithoni yesikhumba esikhanyayo',
    '👩🏿‍❤‍💋‍👨🏼' => 'phuza: ibhinqa, indoda, ithoni yesikhumba emnyama, ithoni yesikhumba esikhanyayo phakathi',
    '👩🏿‍❤‍💋‍👨🏽' => 'phuza: ibhinqa, indoda, ithoni yesikhumba emnyama, ithoni yesikhumba esiphakathi',
    '👩🏿‍❤‍💋‍👨🏾' => 'phuza: ibhinqa, indoda, ithoni yesikhumba emnyama, ithoni yesikhumba esiphakathi mnyama',
    '👩🏿‍❤‍💋‍👨🏿' => 'phuza: ibhinqa, indoda, ithoni yesikhumba emnyama',
    '👩🏻‍❤‍💋‍👩🏻' => 'phuza: ibhinqa, ibhinqa, ithoni yesikhumba esikhanyayo',
    '👩🏻‍❤‍💋‍👩🏼' => 'phuza: ibhinqa, ibhinqa, ithoni yesikhumba esikhanyayo, ithoni yesikhumba esikhanyayo phakathi',
    '👩🏻‍❤‍💋‍👩🏽' => 'phuza: ibhinqa, ibhinqa, ithoni yesikhumba esikhanyayo, ithoni yesikhumba esiphakathi',
    '👩🏻‍❤‍💋‍👩🏾' => 'phuza: ibhinqa, ibhinqa, ithoni yesikhumba esikhanyayo, ithoni yesikhumba esiphakathi mnyama',
    '👩🏻‍❤‍💋‍👩🏿' => 'phuza: ibhinqa, ibhinqa, ithoni yesikhumba esikhanyayo, ithoni yesikhumba emnyama',
    '👩🏼‍❤‍💋‍👩🏻' => 'phuza: ibhinqa, ibhinqa, ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esikhanyayo',
    '👩🏼‍❤‍💋‍👩🏼' => 'phuza: ibhinqa, ibhinqa, ithoni yesikhumba esikhanyayo phakathi',
    '👩🏼‍❤‍💋‍👩🏽' => 'phuza: ibhinqa, ibhinqa, ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esiphakathi',
    '👩🏼‍❤‍💋‍👩🏾' => 'phuza: ibhinqa, ibhinqa, ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esiphakathi mnyama',
    '👩🏼‍❤‍💋‍👩🏿' => 'phuza: ibhinqa, ibhinqa, ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba emnyama',
    '👩🏽‍❤‍💋‍👩🏻' => 'phuza: ibhinqa, ibhinqa, ithoni yesikhumba esiphakathi, ithoni yesikhumba esikhanyayo',
    '👩🏽‍❤‍💋‍👩🏼' => 'phuza: ibhinqa, ibhinqa, ithoni yesikhumba esiphakathi, ithoni yesikhumba esikhanyayo phakathi',
    '👩🏽‍❤‍💋‍👩🏽' => 'phuza: ibhinqa, ibhinqa, ithoni yesikhumba esiphakathi',
    '👩🏽‍❤‍💋‍👩🏾' => 'phuza: ibhinqa, ibhinqa, ithoni yesikhumba esiphakathi, ithoni yesikhumba esiphakathi mnyama',
    '👩🏽‍❤‍💋‍👩🏿' => 'phuza: ibhinqa, ibhinqa, ithoni yesikhumba esiphakathi, ithoni yesikhumba emnyama',
    '👩🏾‍❤‍💋‍👩🏻' => 'phuza: ibhinqa, ibhinqa, ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esikhanyayo',
    '👩🏾‍❤‍💋‍👩🏼' => 'phuza: ibhinqa, ibhinqa, ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esikhanyayo phakathi',
    '👩🏾‍❤‍💋‍👩🏽' => 'phuza: ibhinqa, ibhinqa, ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esiphakathi',
    '👩🏾‍❤‍💋‍👩🏾' => 'phuza: ibhinqa, ibhinqa, ithoni yesikhumba esiphakathi mnyama',
    '👩🏾‍❤‍💋‍👩🏿' => 'phuza: ibhinqa, ibhinqa, ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba emnyama',
    '👩🏿‍❤‍💋‍👩🏻' => 'phuza: ibhinqa, ibhinqa, ithoni yesikhumba emnyama, ithoni yesikhumba esikhanyayo',
    '👩🏿‍❤‍💋‍👩🏼' => 'phuza: ibhinqa, ibhinqa, ithoni yesikhumba emnyama, ithoni yesikhumba esikhanyayo phakathi',
    '👩🏿‍❤‍💋‍👩🏽' => 'phuza: ibhinqa, ibhinqa, ithoni yesikhumba emnyama, ithoni yesikhumba esiphakathi',
    '👩🏿‍❤‍💋‍👩🏾' => 'phuza: ibhinqa, ibhinqa, ithoni yesikhumba emnyama, ithoni yesikhumba esiphakathi mnyama',
    '👩🏿‍❤‍💋‍👩🏿' => 'phuza: ibhinqa, ibhinqa, ithoni yesikhumba emnyama',
    '🧑🏻‍🫯‍🧑🏼' => 'abantu abangqulanayo: ithoni yesikhumba esikhanyayo, ithoni yesikhumba esikhanyayo phakathi',
    '🧑🏻‍🫯‍🧑🏽' => 'abantu abangqulanayo: ithoni yesikhumba esikhanyayo, ithoni yesikhumba esiphakathi',
    '🧑🏻‍🫯‍🧑🏾' => 'abantu abangqulanayo: ithoni yesikhumba esikhanyayo, ithoni yesikhumba esiphakathi mnyama',
    '🧑🏻‍🫯‍🧑🏿' => 'abantu abangqulanayo: ithoni yesikhumba esikhanyayo, ithoni yesikhumba emnyama',
    '🧑🏼‍🫯‍🧑🏻' => 'abantu abangqulanayo: ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esikhanyayo',
    '🧑🏼‍🫯‍🧑🏽' => 'abantu abangqulanayo: ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esiphakathi',
    '🧑🏼‍🫯‍🧑🏾' => 'abantu abangqulanayo: ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esiphakathi mnyama',
    '🧑🏼‍🫯‍🧑🏿' => 'abantu abangqulanayo: ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba emnyama',
    '🧑🏽‍🫯‍🧑🏻' => 'abantu abangqulanayo: ithoni yesikhumba esiphakathi, ithoni yesikhumba esikhanyayo',
    '🧑🏽‍🫯‍🧑🏼' => 'abantu abangqulanayo: ithoni yesikhumba esiphakathi, ithoni yesikhumba esikhanyayo phakathi',
    '🧑🏽‍🫯‍🧑🏾' => 'abantu abangqulanayo: ithoni yesikhumba esiphakathi, ithoni yesikhumba esiphakathi mnyama',
    '🧑🏽‍🫯‍🧑🏿' => 'abantu abangqulanayo: ithoni yesikhumba esiphakathi, ithoni yesikhumba emnyama',
    '🧑🏾‍🫯‍🧑🏻' => 'abantu abangqulanayo: ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esikhanyayo',
    '🧑🏾‍🫯‍🧑🏼' => 'abantu abangqulanayo: ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esikhanyayo phakathi',
    '🧑🏾‍🫯‍🧑🏽' => 'abantu abangqulanayo: ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esiphakathi',
    '🧑🏾‍🫯‍🧑🏿' => 'abantu abangqulanayo: ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba emnyama',
    '🧑🏿‍🫯‍🧑🏻' => 'abantu abangqulanayo: ithoni yesikhumba emnyama, ithoni yesikhumba esikhanyayo',
    '🧑🏿‍🫯‍🧑🏼' => 'abantu abangqulanayo: ithoni yesikhumba emnyama, ithoni yesikhumba esikhanyayo phakathi',
    '🧑🏿‍🫯‍🧑🏽' => 'abantu abangqulanayo: ithoni yesikhumba emnyama, ithoni yesikhumba esiphakathi',
    '🧑🏿‍🫯‍🧑🏾' => 'abantu abangqulanayo: ithoni yesikhumba emnyama, ithoni yesikhumba esiphakathi mnyama',
    '🧑🏻‍❤‍🧑🏼' => 'isibini esinentliziyo: umntu omdala, umntu omdala, ithoni yesikhumba esikhanyayo, ithoni yesikhumba esikhanyayo phakathi',
    '🧑🏻‍❤‍🧑🏽' => 'isibini esinentliziyo: umntu omdala, umntu omdala, ithoni yesikhumba esikhanyayo, ithoni yesikhumba esiphakathi',
    '🧑🏻‍❤‍🧑🏾' => 'isibini esinentliziyo: umntu omdala, umntu omdala, ithoni yesikhumba esikhanyayo, ithoni yesikhumba esiphakathi mnyama',
    '🧑🏻‍❤‍🧑🏿' => 'isibini esinentliziyo: umntu omdala, umntu omdala, ithoni yesikhumba esikhanyayo, ithoni yesikhumba emnyama',
    '🧑🏼‍❤‍🧑🏻' => 'isibini esinentliziyo: umntu omdala, umntu omdala, ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esikhanyayo',
    '🧑🏼‍❤‍🧑🏽' => 'isibini esinentliziyo: umntu omdala, umntu omdala, ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esiphakathi',
    '🧑🏼‍❤‍🧑🏾' => 'isibini esinentliziyo: umntu omdala, umntu omdala, ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esiphakathi mnyama',
    '🧑🏼‍❤‍🧑🏿' => 'isibini esinentliziyo: umntu omdala, umntu omdala, ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba emnyama',
    '🧑🏽‍❤‍🧑🏻' => 'isibini esinentliziyo: umntu omdala, umntu omdala, ithoni yesikhumba esiphakathi, ithoni yesikhumba esikhanyayo',
    '🧑🏽‍❤‍🧑🏼' => 'isibini esinentliziyo: umntu omdala, umntu omdala, ithoni yesikhumba esiphakathi, ithoni yesikhumba esikhanyayo phakathi',
    '🧑🏽‍❤‍🧑🏾' => 'isibini esinentliziyo: umntu omdala, umntu omdala, ithoni yesikhumba esiphakathi, ithoni yesikhumba esiphakathi mnyama',
    '🧑🏽‍❤‍🧑🏿' => 'isibini esinentliziyo: umntu omdala, umntu omdala, ithoni yesikhumba esiphakathi, ithoni yesikhumba emnyama',
    '🧑🏾‍❤‍🧑🏻' => 'isibini esinentliziyo: umntu omdala, umntu omdala, ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esikhanyayo',
    '🧑🏾‍❤‍🧑🏼' => 'isibini esinentliziyo: umntu omdala, umntu omdala, ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esikhanyayo phakathi',
    '🧑🏾‍❤‍🧑🏽' => 'isibini esinentliziyo: umntu omdala, umntu omdala, ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esiphakathi',
    '🧑🏾‍❤‍🧑🏿' => 'isibini esinentliziyo: umntu omdala, umntu omdala, ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba emnyama',
    '🧑🏿‍❤‍🧑🏻' => 'isibini esinentliziyo: umntu omdala, umntu omdala, ithoni yesikhumba emnyama, ithoni yesikhumba esikhanyayo',
    '🧑🏿‍❤‍🧑🏼' => 'isibini esinentliziyo: umntu omdala, umntu omdala, ithoni yesikhumba emnyama, ithoni yesikhumba esikhanyayo phakathi',
    '🧑🏿‍❤‍🧑🏽' => 'isibini esinentliziyo: umntu omdala, umntu omdala, ithoni yesikhumba emnyama, ithoni yesikhumba esiphakathi',
    '🧑🏿‍❤‍🧑🏾' => 'isibini esinentliziyo: umntu omdala, umntu omdala, ithoni yesikhumba emnyama, ithoni yesikhumba esiphakathi mnyama',
    '🧑🏻‍🐰‍🧑🏼' => 'abantu abaneendlebe zomvundla abakwitheko: ithoni yesikhumba esikhanyayo, ithoni yesikhumba esikhanyayo phakathi',
    '🧑🏻‍🐰‍🧑🏽' => 'abantu abaneendlebe zomvundla abakwitheko: ithoni yesikhumba esikhanyayo, ithoni yesikhumba esiphakathi',
    '🧑🏻‍🐰‍🧑🏾' => 'abantu abaneendlebe zomvundla abakwitheko: ithoni yesikhumba esikhanyayo, ithoni yesikhumba esiphakathi mnyama',
    '🧑🏻‍🐰‍🧑🏿' => 'abantu abaneendlebe zomvundla abakwitheko: ithoni yesikhumba esikhanyayo, ithoni yesikhumba emnyama',
    '🧑🏼‍🐰‍🧑🏻' => 'abantu abaneendlebe zomvundla abakwitheko: ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esikhanyayo',
    '🧑🏼‍🐰‍🧑🏽' => 'abantu abaneendlebe zomvundla abakwitheko: ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esiphakathi',
    '🧑🏼‍🐰‍🧑🏾' => 'abantu abaneendlebe zomvundla abakwitheko: ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esiphakathi mnyama',
    '🧑🏼‍🐰‍🧑🏿' => 'abantu abaneendlebe zomvundla abakwitheko: ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba emnyama',
    '🧑🏽‍🐰‍🧑🏻' => 'abantu abaneendlebe zomvundla abakwitheko: ithoni yesikhumba esiphakathi, ithoni yesikhumba esikhanyayo',
    '🧑🏽‍🐰‍🧑🏼' => 'abantu abaneendlebe zomvundla abakwitheko: ithoni yesikhumba esiphakathi, ithoni yesikhumba esikhanyayo phakathi',
    '🧑🏽‍🐰‍🧑🏾' => 'abantu abaneendlebe zomvundla abakwitheko: ithoni yesikhumba esiphakathi, ithoni yesikhumba esiphakathi mnyama',
    '🧑🏽‍🐰‍🧑🏿' => 'abantu abaneendlebe zomvundla abakwitheko: ithoni yesikhumba esiphakathi, ithoni yesikhumba emnyama',
    '🧑🏾‍🐰‍🧑🏻' => 'abantu abaneendlebe zomvundla abakwitheko: ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esikhanyayo',
    '🧑🏾‍🐰‍🧑🏼' => 'abantu abaneendlebe zomvundla abakwitheko: ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esikhanyayo phakathi',
    '🧑🏾‍🐰‍🧑🏽' => 'abantu abaneendlebe zomvundla abakwitheko: ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esiphakathi',
    '🧑🏾‍🐰‍🧑🏿' => 'abantu abaneendlebe zomvundla abakwitheko: ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba emnyama',
    '🧑🏿‍🐰‍🧑🏻' => 'abantu abaneendlebe zomvundla abakwitheko: ithoni yesikhumba emnyama, ithoni yesikhumba esikhanyayo',
    '🧑🏿‍🐰‍🧑🏼' => 'abantu abaneendlebe zomvundla abakwitheko: ithoni yesikhumba emnyama, ithoni yesikhumba esikhanyayo phakathi',
    '🧑🏿‍🐰‍🧑🏽' => 'abantu abaneendlebe zomvundla abakwitheko: ithoni yesikhumba emnyama, ithoni yesikhumba esiphakathi',
    '🧑🏿‍🐰‍🧑🏾' => 'abantu abaneendlebe zomvundla abakwitheko: ithoni yesikhumba emnyama, ithoni yesikhumba esiphakathi mnyama',
    '👨🏻‍🫯‍👨🏼' => 'amadoda angqulanayo: ithoni yesikhumba esikhanyayo, ithoni yesikhumba esikhanyayo phakathi',
    '👨🏻‍🫯‍👨🏽' => 'amadoda angqulanayo: ithoni yesikhumba esikhanyayo, ithoni yesikhumba esiphakathi',
    '👨🏻‍🫯‍👨🏾' => 'amadoda angqulanayo: ithoni yesikhumba esikhanyayo, ithoni yesikhumba esiphakathi mnyama',
    '👨🏻‍🫯‍👨🏿' => 'amadoda angqulanayo: ithoni yesikhumba esikhanyayo, ithoni yesikhumba emnyama',
    '👨🏼‍🫯‍👨🏻' => 'amadoda angqulanayo: ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esikhanyayo',
    '👨🏼‍🫯‍👨🏽' => 'amadoda angqulanayo: ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esiphakathi',
    '👨🏼‍🫯‍👨🏾' => 'amadoda angqulanayo: ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esiphakathi mnyama',
    '👨🏼‍🫯‍👨🏿' => 'amadoda angqulanayo: ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba emnyama',
    '👨🏽‍🫯‍👨🏻' => 'amadoda angqulanayo: ithoni yesikhumba esiphakathi, ithoni yesikhumba esikhanyayo',
    '👨🏽‍🫯‍👨🏼' => 'amadoda angqulanayo: ithoni yesikhumba esiphakathi, ithoni yesikhumba esikhanyayo phakathi',
    '👨🏽‍🫯‍👨🏾' => 'amadoda angqulanayo: ithoni yesikhumba esiphakathi, ithoni yesikhumba esiphakathi mnyama',
    '👨🏽‍🫯‍👨🏿' => 'amadoda angqulanayo: ithoni yesikhumba esiphakathi, ithoni yesikhumba emnyama',
    '👨🏾‍🫯‍👨🏻' => 'amadoda angqulanayo: ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esikhanyayo',
    '👨🏾‍🫯‍👨🏼' => 'amadoda angqulanayo: ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esikhanyayo phakathi',
    '👨🏾‍🫯‍👨🏽' => 'amadoda angqulanayo: ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esiphakathi',
    '👨🏾‍🫯‍👨🏿' => 'amadoda angqulanayo: ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba emnyama',
    '👨🏿‍🫯‍👨🏻' => 'amadoda angqulanayo: ithoni yesikhumba emnyama, ithoni yesikhumba esikhanyayo',
    '👨🏿‍🫯‍👨🏼' => 'amadoda angqulanayo: ithoni yesikhumba emnyama, ithoni yesikhumba esikhanyayo phakathi',
    '👨🏿‍🫯‍👨🏽' => 'amadoda angqulanayo: ithoni yesikhumba emnyama, ithoni yesikhumba esiphakathi',
    '👨🏿‍🫯‍👨🏾' => 'amadoda angqulanayo: ithoni yesikhumba emnyama, ithoni yesikhumba esiphakathi mnyama',
    '👨🏻‍❤‍👨🏻' => 'isibini esinentliziyo: indoda, indoda, ithoni yesikhumba esikhanyayo',
    '👨🏻‍❤‍👨🏼' => 'isibini esinentliziyo: indoda, indoda, ithoni yesikhumba esikhanyayo, ithoni yesikhumba esikhanyayo phakathi',
    '👨🏻‍❤‍👨🏽' => 'isibini esinentliziyo: indoda, indoda, ithoni yesikhumba esikhanyayo, ithoni yesikhumba esiphakathi',
    '👨🏻‍❤‍👨🏾' => 'isibini esinentliziyo: indoda, indoda, ithoni yesikhumba esikhanyayo, ithoni yesikhumba esiphakathi mnyama',
    '👨🏻‍❤‍👨🏿' => 'isibini esinentliziyo: indoda, indoda, ithoni yesikhumba esikhanyayo, ithoni yesikhumba emnyama',
    '👨🏼‍❤‍👨🏻' => 'isibini esinentliziyo: indoda, indoda, ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esikhanyayo',
    '👨🏼‍❤‍👨🏼' => 'isibini esinentliziyo: indoda, indoda, ithoni yesikhumba esikhanyayo phakathi',
    '👨🏼‍❤‍👨🏽' => 'isibini esinentliziyo: indoda, indoda, ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esiphakathi',
    '👨🏼‍❤‍👨🏾' => 'isibini esinentliziyo: indoda, indoda, ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esiphakathi mnyama',
    '👨🏼‍❤‍👨🏿' => 'isibini esinentliziyo: indoda, indoda, ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba emnyama',
    '👨🏽‍❤‍👨🏻' => 'isibini esinentliziyo: indoda, indoda, ithoni yesikhumba esiphakathi, ithoni yesikhumba esikhanyayo',
    '👨🏽‍❤‍👨🏼' => 'isibini esinentliziyo: indoda, indoda, ithoni yesikhumba esiphakathi, ithoni yesikhumba esikhanyayo phakathi',
    '👨🏽‍❤‍👨🏽' => 'isibini esinentliziyo: indoda, indoda, ithoni yesikhumba esiphakathi',
    '👨🏽‍❤‍👨🏾' => 'isibini esinentliziyo: indoda, indoda, ithoni yesikhumba esiphakathi, ithoni yesikhumba esiphakathi mnyama',
    '👨🏽‍❤‍👨🏿' => 'isibini esinentliziyo: indoda, indoda, ithoni yesikhumba esiphakathi, ithoni yesikhumba emnyama',
    '👨🏾‍❤‍👨🏻' => 'isibini esinentliziyo: indoda, indoda, ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esikhanyayo',
    '👨🏾‍❤‍👨🏼' => 'isibini esinentliziyo: indoda, indoda, ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esikhanyayo phakathi',
    '👨🏾‍❤‍👨🏽' => 'isibini esinentliziyo: indoda, indoda, ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esiphakathi',
    '👨🏾‍❤‍👨🏾' => 'isibini esinentliziyo: indoda, indoda, ithoni yesikhumba esiphakathi mnyama',
    '👨🏾‍❤‍👨🏿' => 'isibini esinentliziyo: indoda, indoda, ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba emnyama',
    '👨🏿‍❤‍👨🏻' => 'isibini esinentliziyo: indoda, indoda, ithoni yesikhumba emnyama, ithoni yesikhumba esikhanyayo',
    '👨🏿‍❤‍👨🏼' => 'isibini esinentliziyo: indoda, indoda, ithoni yesikhumba emnyama, ithoni yesikhumba esikhanyayo phakathi',
    '👨🏿‍❤‍👨🏽' => 'isibini esinentliziyo: indoda, indoda, ithoni yesikhumba emnyama, ithoni yesikhumba esiphakathi',
    '👨🏿‍❤‍👨🏾' => 'isibini esinentliziyo: indoda, indoda, ithoni yesikhumba emnyama, ithoni yesikhumba esiphakathi mnyama',
    '👨🏿‍❤‍👨🏿' => 'isibini esinentliziyo: indoda, indoda, ithoni yesikhumba emnyama',
    '👨🏻‍🐰‍👨🏼' => 'amadoda aneneendlebe zomvundla akwitheko: ithoni yesikhumba esikhanyayo, ithoni yesikhumba esikhanyayo phakathi',
    '👨🏻‍🐰‍👨🏽' => 'amadoda aneneendlebe zomvundla akwitheko: ithoni yesikhumba esikhanyayo, ithoni yesikhumba esiphakathi',
    '👨🏻‍🐰‍👨🏾' => 'amadoda aneneendlebe zomvundla akwitheko: ithoni yesikhumba esikhanyayo, ithoni yesikhumba esiphakathi mnyama',
    '👨🏻‍🐰‍👨🏿' => 'amadoda aneneendlebe zomvundla akwitheko: ithoni yesikhumba esikhanyayo, ithoni yesikhumba emnyama',
    '👨🏼‍🐰‍👨🏻' => 'amadoda aneneendlebe zomvundla akwitheko: ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esikhanyayo',
    '👨🏼‍🐰‍👨🏽' => 'amadoda aneneendlebe zomvundla akwitheko: ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esiphakathi',
    '👨🏼‍🐰‍👨🏾' => 'amadoda aneneendlebe zomvundla akwitheko: ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esiphakathi mnyama',
    '👨🏼‍🐰‍👨🏿' => 'amadoda aneneendlebe zomvundla akwitheko: ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba emnyama',
    '👨🏽‍🐰‍👨🏻' => 'amadoda aneneendlebe zomvundla akwitheko: ithoni yesikhumba esiphakathi, ithoni yesikhumba esikhanyayo',
    '👨🏽‍🐰‍👨🏼' => 'amadoda aneneendlebe zomvundla akwitheko: ithoni yesikhumba esiphakathi, ithoni yesikhumba esikhanyayo phakathi',
    '👨🏽‍🐰‍👨🏾' => 'amadoda aneneendlebe zomvundla akwitheko: ithoni yesikhumba esiphakathi, ithoni yesikhumba esiphakathi mnyama',
    '👨🏽‍🐰‍👨🏿' => 'amadoda aneneendlebe zomvundla akwitheko: ithoni yesikhumba esiphakathi, ithoni yesikhumba emnyama',
    '👨🏾‍🐰‍👨🏻' => 'amadoda aneneendlebe zomvundla akwitheko: ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esikhanyayo',
    '👨🏾‍🐰‍👨🏼' => 'amadoda aneneendlebe zomvundla akwitheko: ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esikhanyayo phakathi',
    '👨🏾‍🐰‍👨🏽' => 'amadoda aneneendlebe zomvundla akwitheko: ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esiphakathi',
    '👨🏾‍🐰‍👨🏿' => 'amadoda aneneendlebe zomvundla akwitheko: ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba emnyama',
    '👨🏿‍🐰‍👨🏻' => 'amadoda aneneendlebe zomvundla akwitheko: ithoni yesikhumba emnyama, ithoni yesikhumba esikhanyayo',
    '👨🏿‍🐰‍👨🏼' => 'amadoda aneneendlebe zomvundla akwitheko: ithoni yesikhumba emnyama, ithoni yesikhumba esikhanyayo phakathi',
    '👨🏿‍🐰‍👨🏽' => 'amadoda aneneendlebe zomvundla akwitheko: ithoni yesikhumba emnyama, ithoni yesikhumba esiphakathi',
    '👨🏿‍🐰‍👨🏾' => 'amadoda aneneendlebe zomvundla akwitheko: ithoni yesikhumba emnyama, ithoni yesikhumba esiphakathi mnyama',
    '👩🏻‍🫯‍👩🏼' => 'amabhinqa angqulanayo: ithoni yesikhumba esikhanyayo, ithoni yesikhumba esikhanyayo phakathi',
    '👩🏻‍🫯‍👩🏽' => 'amabhinqa angqulanayo: ithoni yesikhumba esikhanyayo, ithoni yesikhumba esiphakathi',
    '👩🏻‍🫯‍👩🏾' => 'amabhinqa angqulanayo: ithoni yesikhumba esikhanyayo, ithoni yesikhumba esiphakathi mnyama',
    '👩🏻‍🫯‍👩🏿' => 'amabhinqa angqulanayo: ithoni yesikhumba esikhanyayo, ithoni yesikhumba emnyama',
    '👩🏼‍🫯‍👩🏻' => 'amabhinqa angqulanayo: ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esikhanyayo',
    '👩🏼‍🫯‍👩🏽' => 'amabhinqa angqulanayo: ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esiphakathi',
    '👩🏼‍🫯‍👩🏾' => 'amabhinqa angqulanayo: ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esiphakathi mnyama',
    '👩🏼‍🫯‍👩🏿' => 'amabhinqa angqulanayo: ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba emnyama',
    '👩🏽‍🫯‍👩🏻' => 'amabhinqa angqulanayo: ithoni yesikhumba esiphakathi, ithoni yesikhumba esikhanyayo',
    '👩🏽‍🫯‍👩🏼' => 'amabhinqa angqulanayo: ithoni yesikhumba esiphakathi, ithoni yesikhumba esikhanyayo phakathi',
    '👩🏽‍🫯‍👩🏾' => 'amabhinqa angqulanayo: ithoni yesikhumba esiphakathi, ithoni yesikhumba esiphakathi mnyama',
    '👩🏽‍🫯‍👩🏿' => 'amabhinqa angqulanayo: ithoni yesikhumba esiphakathi, ithoni yesikhumba emnyama',
    '👩🏾‍🫯‍👩🏻' => 'amabhinqa angqulanayo: ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esikhanyayo',
    '👩🏾‍🫯‍👩🏼' => 'amabhinqa angqulanayo: ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esikhanyayo phakathi',
    '👩🏾‍🫯‍👩🏽' => 'amabhinqa angqulanayo: ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esiphakathi',
    '👩🏾‍🫯‍👩🏿' => 'amabhinqa angqulanayo: ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba emnyama',
    '👩🏿‍🫯‍👩🏻' => 'amabhinqa angqulanayo: ithoni yesikhumba emnyama, ithoni yesikhumba esikhanyayo',
    '👩🏿‍🫯‍👩🏼' => 'amabhinqa angqulanayo: ithoni yesikhumba emnyama, ithoni yesikhumba esikhanyayo phakathi',
    '👩🏿‍🫯‍👩🏽' => 'amabhinqa angqulanayo: ithoni yesikhumba emnyama, ithoni yesikhumba esiphakathi',
    '👩🏿‍🫯‍👩🏾' => 'amabhinqa angqulanayo: ithoni yesikhumba emnyama, ithoni yesikhumba esiphakathi mnyama',
    '👩🏻‍❤‍👨🏻' => 'isibini esinentliziyo: ibhinqa, indoda, ithoni yesikhumba esikhanyayo',
    '👩🏻‍❤‍👨🏼' => 'isibini esinentliziyo: ibhinqa, indoda, ithoni yesikhumba esikhanyayo, ithoni yesikhumba esikhanyayo phakathi',
    '👩🏻‍❤‍👨🏽' => 'isibini esinentliziyo: ibhinqa, indoda, ithoni yesikhumba esikhanyayo, ithoni yesikhumba esiphakathi',
    '👩🏻‍❤‍👨🏾' => 'isibini esinentliziyo: ibhinqa, indoda, ithoni yesikhumba esikhanyayo, ithoni yesikhumba esiphakathi mnyama',
    '👩🏻‍❤‍👨🏿' => 'isibini esinentliziyo: ibhinqa, indoda, ithoni yesikhumba esikhanyayo, ithoni yesikhumba emnyama',
    '👩🏼‍❤‍👨🏻' => 'isibini esinentliziyo: ibhinqa, indoda, ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esikhanyayo',
    '👩🏼‍❤‍👨🏼' => 'isibini esinentliziyo: ibhinqa, indoda, ithoni yesikhumba esikhanyayo phakathi',
    '👩🏼‍❤‍👨🏽' => 'isibini esinentliziyo: ibhinqa, indoda, ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esiphakathi',
    '👩🏼‍❤‍👨🏾' => 'isibini esinentliziyo: ibhinqa, indoda, ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esiphakathi mnyama',
    '👩🏼‍❤‍👨🏿' => 'isibini esinentliziyo: ibhinqa, indoda, ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba emnyama',
    '👩🏽‍❤‍👨🏻' => 'isibini esinentliziyo: ibhinqa, indoda, ithoni yesikhumba esiphakathi, ithoni yesikhumba esikhanyayo',
    '👩🏽‍❤‍👨🏼' => 'isibini esinentliziyo: ibhinqa, indoda, ithoni yesikhumba esiphakathi, ithoni yesikhumba esikhanyayo phakathi',
    '👩🏽‍❤‍👨🏽' => 'isibini esinentliziyo: ibhinqa, indoda, ithoni yesikhumba esiphakathi',
    '👩🏽‍❤‍👨🏾' => 'isibini esinentliziyo: ibhinqa, indoda, ithoni yesikhumba esiphakathi, ithoni yesikhumba esiphakathi mnyama',
    '👩🏽‍❤‍👨🏿' => 'isibini esinentliziyo: ibhinqa, indoda, ithoni yesikhumba esiphakathi, ithoni yesikhumba emnyama',
    '👩🏾‍❤‍👨🏻' => 'isibini esinentliziyo: ibhinqa, indoda, ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esikhanyayo',
    '👩🏾‍❤‍👨🏼' => 'isibini esinentliziyo: ibhinqa, indoda, ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esikhanyayo phakathi',
    '👩🏾‍❤‍👨🏽' => 'isibini esinentliziyo: ibhinqa, indoda, ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esiphakathi',
    '👩🏾‍❤‍👨🏾' => 'isibini esinentliziyo: ibhinqa, indoda, ithoni yesikhumba esiphakathi mnyama',
    '👩🏾‍❤‍👨🏿' => 'isibini esinentliziyo: ibhinqa, indoda, ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba emnyama',
    '👩🏿‍❤‍👨🏻' => 'isibini esinentliziyo: ibhinqa, indoda, ithoni yesikhumba emnyama, ithoni yesikhumba esikhanyayo',
    '👩🏿‍❤‍👨🏼' => 'isibini esinentliziyo: ibhinqa, indoda, ithoni yesikhumba emnyama, ithoni yesikhumba esikhanyayo phakathi',
    '👩🏿‍❤‍👨🏽' => 'isibini esinentliziyo: ibhinqa, indoda, ithoni yesikhumba emnyama, ithoni yesikhumba esiphakathi',
    '👩🏿‍❤‍👨🏾' => 'isibini esinentliziyo: ibhinqa, indoda, ithoni yesikhumba emnyama, ithoni yesikhumba esiphakathi mnyama',
    '👩🏿‍❤‍👨🏿' => 'isibini esinentliziyo: ibhinqa, indoda, ithoni yesikhumba emnyama',
    '👩🏻‍❤‍👩🏻' => 'isibini esinentliziyo: ibhinqa, ibhinqa, ithoni yesikhumba esikhanyayo',
    '👩🏻‍❤‍👩🏼' => 'isibini esinentliziyo: ibhinqa, ibhinqa, ithoni yesikhumba esikhanyayo, ithoni yesikhumba esikhanyayo phakathi',
    '👩🏻‍❤‍👩🏽' => 'isibini esinentliziyo: ibhinqa, ibhinqa, ithoni yesikhumba esikhanyayo, ithoni yesikhumba esiphakathi',
    '👩🏻‍❤‍👩🏾' => 'isibini esinentliziyo: ibhinqa, ibhinqa, ithoni yesikhumba esikhanyayo, ithoni yesikhumba esiphakathi mnyama',
    '👩🏻‍❤‍👩🏿' => 'isibini esinentliziyo: ibhinqa, ibhinqa, ithoni yesikhumba esikhanyayo, ithoni yesikhumba emnyama',
    '👩🏼‍❤‍👩🏻' => 'isibini esinentliziyo: ibhinqa, ibhinqa, ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esikhanyayo',
    '👩🏼‍❤‍👩🏼' => 'isibini esinentliziyo: ibhinqa, ibhinqa, ithoni yesikhumba esikhanyayo phakathi',
    '👩🏼‍❤‍👩🏽' => 'isibini esinentliziyo: ibhinqa, ibhinqa, ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esiphakathi',
    '👩🏼‍❤‍👩🏾' => 'isibini esinentliziyo: ibhinqa, ibhinqa, ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esiphakathi mnyama',
    '👩🏼‍❤‍👩🏿' => 'isibini esinentliziyo: ibhinqa, ibhinqa, ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba emnyama',
    '👩🏽‍❤‍👩🏻' => 'isibini esinentliziyo: ibhinqa, ibhinqa, ithoni yesikhumba esiphakathi, ithoni yesikhumba esikhanyayo',
    '👩🏽‍❤‍👩🏼' => 'isibini esinentliziyo: ibhinqa, ibhinqa, ithoni yesikhumba esiphakathi, ithoni yesikhumba esikhanyayo phakathi',
    '👩🏽‍❤‍👩🏽' => 'isibini esinentliziyo: ibhinqa, ibhinqa, ithoni yesikhumba esiphakathi',
    '👩🏽‍❤‍👩🏾' => 'isibini esinentliziyo: ibhinqa, ibhinqa, ithoni yesikhumba esiphakathi, ithoni yesikhumba esiphakathi mnyama',
    '👩🏽‍❤‍👩🏿' => 'isibini esinentliziyo: ibhinqa, ibhinqa, ithoni yesikhumba esiphakathi, ithoni yesikhumba emnyama',
    '👩🏾‍❤‍👩🏻' => 'isibini esinentliziyo: ibhinqa, ibhinqa, ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esikhanyayo',
    '👩🏾‍❤‍👩🏼' => 'isibini esinentliziyo: ibhinqa, ibhinqa, ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esikhanyayo phakathi',
    '👩🏾‍❤‍👩🏽' => 'isibini esinentliziyo: ibhinqa, ibhinqa, ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esiphakathi',
    '👩🏾‍❤‍👩🏾' => 'isibini esinentliziyo: ibhinqa, ibhinqa, ithoni yesikhumba esiphakathi mnyama',
    '👩🏾‍❤‍👩🏿' => 'isibini esinentliziyo: ibhinqa, ibhinqa, ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba emnyama',
    '👩🏿‍❤‍👩🏻' => 'isibini esinentliziyo: ibhinqa, ibhinqa, ithoni yesikhumba emnyama, ithoni yesikhumba esikhanyayo',
    '👩🏿‍❤‍👩🏼' => 'isibini esinentliziyo: ibhinqa, ibhinqa, ithoni yesikhumba emnyama, ithoni yesikhumba esikhanyayo phakathi',
    '👩🏿‍❤‍👩🏽' => 'isibini esinentliziyo: ibhinqa, ibhinqa, ithoni yesikhumba emnyama, ithoni yesikhumba esiphakathi',
    '👩🏿‍❤‍👩🏾' => 'isibini esinentliziyo: ibhinqa, ibhinqa, ithoni yesikhumba emnyama, ithoni yesikhumba esiphakathi mnyama',
    '👩🏿‍❤‍👩🏿' => 'isibini esinentliziyo: ibhinqa, ibhinqa, ithoni yesikhumba emnyama',
    '👩🏻‍🐰‍👩🏼' => 'ibhinqa elineendlebe zomvundla elikwitheko: ithoni yesikhumba esikhanyayo, ithoni yesikhumba esikhanyayo phakathi',
    '👩🏻‍🐰‍👩🏽' => 'ibhinqa elineendlebe zomvundla elikwitheko: ithoni yesikhumba esikhanyayo, ithoni yesikhumba esiphakathi',
    '👩🏻‍🐰‍👩🏾' => 'ibhinqa elineendlebe zomvundla elikwitheko: ithoni yesikhumba esikhanyayo, ithoni yesikhumba esiphakathi mnyama',
    '👩🏻‍🐰‍👩🏿' => 'ibhinqa elineendlebe zomvundla elikwitheko: ithoni yesikhumba esikhanyayo, ithoni yesikhumba emnyama',
    '👩🏼‍🐰‍👩🏻' => 'ibhinqa elineendlebe zomvundla elikwitheko: ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esikhanyayo',
    '👩🏼‍🐰‍👩🏽' => 'ibhinqa elineendlebe zomvundla elikwitheko: ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esiphakathi',
    '👩🏼‍🐰‍👩🏾' => 'ibhinqa elineendlebe zomvundla elikwitheko: ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esiphakathi mnyama',
    '👩🏼‍🐰‍👩🏿' => 'ibhinqa elineendlebe zomvundla elikwitheko: ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba emnyama',
    '👩🏽‍🐰‍👩🏻' => 'ibhinqa elineendlebe zomvundla elikwitheko: ithoni yesikhumba esiphakathi, ithoni yesikhumba esikhanyayo',
    '👩🏽‍🐰‍👩🏼' => 'ibhinqa elineendlebe zomvundla elikwitheko: ithoni yesikhumba esiphakathi, ithoni yesikhumba esikhanyayo phakathi',
    '👩🏽‍🐰‍👩🏾' => 'ibhinqa elineendlebe zomvundla elikwitheko: ithoni yesikhumba esiphakathi, ithoni yesikhumba esiphakathi mnyama',
    '👩🏽‍🐰‍👩🏿' => 'ibhinqa elineendlebe zomvundla elikwitheko: ithoni yesikhumba esiphakathi, ithoni yesikhumba emnyama',
    '👩🏾‍🐰‍👩🏻' => 'ibhinqa elineendlebe zomvundla elikwitheko: ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esikhanyayo',
    '👩🏾‍🐰‍👩🏼' => 'ibhinqa elineendlebe zomvundla elikwitheko: ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esikhanyayo phakathi',
    '👩🏾‍🐰‍👩🏽' => 'ibhinqa elineendlebe zomvundla elikwitheko: ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esiphakathi',
    '👩🏾‍🐰‍👩🏿' => 'ibhinqa elineendlebe zomvundla elikwitheko: ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba emnyama',
    '👩🏿‍🐰‍👩🏻' => 'ibhinqa elineendlebe zomvundla elikwitheko: ithoni yesikhumba emnyama, ithoni yesikhumba esikhanyayo',
    '👩🏿‍🐰‍👩🏼' => 'ibhinqa elineendlebe zomvundla elikwitheko: ithoni yesikhumba emnyama, ithoni yesikhumba esikhanyayo phakathi',
    '👩🏿‍🐰‍👩🏽' => 'ibhinqa elineendlebe zomvundla elikwitheko: ithoni yesikhumba emnyama, ithoni yesikhumba esiphakathi',
    '👩🏿‍🐰‍👩🏾' => 'ibhinqa elineendlebe zomvundla elikwitheko: ithoni yesikhumba emnyama, ithoni yesikhumba esiphakathi mnyama',
    '👩🏻‍🤝‍👩🏼' => 'amabhinqa amabini abambene ngezandla: ithoni yesikhumba esikhanyayo, ithoni yesikhumba esikhanyayo phakathi',
    '👩🏻‍🤝‍👩🏽' => 'amabhinqa amabini abambene ngezandla: ithoni yesikhumba esikhanyayo, ithoni yesikhumba esiphakathi',
    '👩🏻‍🤝‍👩🏾' => 'amabhinqa amabini abambene ngezandla: ithoni yesikhumba esikhanyayo, ithoni yesikhumba esiphakathi mnyama',
    '👩🏻‍🤝‍👩🏿' => 'amabhinqa amabini abambene ngezandla: ithoni yesikhumba esikhanyayo, ithoni yesikhumba emnyama',
    '👩🏼‍🤝‍👩🏻' => 'amabhinqa amabini abambene ngezandla: ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esikhanyayo',
    '👩🏼‍🤝‍👩🏽' => 'amabhinqa amabini abambene ngezandla: ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esiphakathi',
    '👩🏼‍🤝‍👩🏾' => 'amabhinqa amabini abambene ngezandla: ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esiphakathi mnyama',
    '👩🏼‍🤝‍👩🏿' => 'amabhinqa amabini abambene ngezandla: ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba emnyama',
    '👩🏽‍🤝‍👩🏻' => 'amabhinqa amabini abambene ngezandla: ithoni yesikhumba esiphakathi, ithoni yesikhumba esikhanyayo',
    '👩🏽‍🤝‍👩🏼' => 'amabhinqa amabini abambene ngezandla: ithoni yesikhumba esiphakathi, ithoni yesikhumba esikhanyayo phakathi',
    '👩🏽‍🤝‍👩🏾' => 'amabhinqa amabini abambene ngezandla: ithoni yesikhumba esiphakathi, ithoni yesikhumba esiphakathi mnyama',
    '👩🏽‍🤝‍👩🏿' => 'amabhinqa amabini abambene ngezandla: ithoni yesikhumba esiphakathi, ithoni yesikhumba emnyama',
    '👩🏾‍🤝‍👩🏻' => 'amabhinqa amabini abambene ngezandla: ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esikhanyayo',
    '👩🏾‍🤝‍👩🏼' => 'amabhinqa amabini abambene ngezandla: ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esikhanyayo phakathi',
    '👩🏾‍🤝‍👩🏽' => 'amabhinqa amabini abambene ngezandla: ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esiphakathi',
    '👩🏾‍🤝‍👩🏿' => 'amabhinqa amabini abambene ngezandla: ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba emnyama',
    '👩🏿‍🤝‍👩🏻' => 'amabhinqa amabini abambene ngezandla: ithoni yesikhumba emnyama, ithoni yesikhumba esikhanyayo',
    '👩🏿‍🤝‍👩🏼' => 'amabhinqa amabini abambene ngezandla: ithoni yesikhumba emnyama, ithoni yesikhumba esikhanyayo phakathi',
    '👩🏿‍🤝‍👩🏽' => 'amabhinqa amabini abambene ngezandla: ithoni yesikhumba emnyama, ithoni yesikhumba esiphakathi',
    '👩🏿‍🤝‍👩🏾' => 'amabhinqa amabini abambene ngezandla: ithoni yesikhumba emnyama, ithoni yesikhumba esiphakathi mnyama',
    '👩🏻‍🤝‍👨🏼' => 'indoda nebhinqa abambe izandla: ithoni yesikhumba esikhanyayo, ithoni yesikhumba esikhanyayo phakathi',
    '👩🏻‍🤝‍👨🏽' => 'indoda nebhinqa abambe izandla: ithoni yesikhumba esikhanyayo, ithoni yesikhumba esiphakathi',
    '👩🏻‍🤝‍👨🏾' => 'indoda nebhinqa abambe izandla: ithoni yesikhumba esikhanyayo, ithoni yesikhumba esiphakathi mnyama',
    '👩🏻‍🤝‍👨🏿' => 'indoda nebhinqa abambe izandla: ithoni yesikhumba esikhanyayo, ithoni yesikhumba emnyama',
    '👩🏼‍🤝‍👨🏻' => 'indoda nebhinqa abambe izandla: ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esikhanyayo',
    '👩🏼‍🤝‍👨🏽' => 'indoda nebhinqa abambe izandla: ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esiphakathi',
    '👩🏼‍🤝‍👨🏾' => 'indoda nebhinqa abambe izandla: ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esiphakathi mnyama',
    '👩🏼‍🤝‍👨🏿' => 'indoda nebhinqa abambe izandla: ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba emnyama',
    '👩🏽‍🤝‍👨🏻' => 'indoda nebhinqa abambe izandla: ithoni yesikhumba esiphakathi, ithoni yesikhumba esikhanyayo',
    '👩🏽‍🤝‍👨🏼' => 'indoda nebhinqa abambe izandla: ithoni yesikhumba esiphakathi, ithoni yesikhumba esikhanyayo phakathi',
    '👩🏽‍🤝‍👨🏾' => 'indoda nebhinqa abambe izandla: ithoni yesikhumba esiphakathi, ithoni yesikhumba esiphakathi mnyama',
    '👩🏽‍🤝‍👨🏿' => 'indoda nebhinqa abambe izandla: ithoni yesikhumba esiphakathi, ithoni yesikhumba emnyama',
    '👩🏾‍🤝‍👨🏻' => 'indoda nebhinqa abambe izandla: ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esikhanyayo',
    '👩🏾‍🤝‍👨🏼' => 'indoda nebhinqa abambe izandla: ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esikhanyayo phakathi',
    '👩🏾‍🤝‍👨🏽' => 'indoda nebhinqa abambe izandla: ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esiphakathi',
    '👩🏾‍🤝‍👨🏿' => 'indoda nebhinqa abambe izandla: ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba emnyama',
    '👩🏿‍🤝‍👨🏻' => 'indoda nebhinqa abambe izandla: ithoni yesikhumba emnyama, ithoni yesikhumba esikhanyayo',
    '👩🏿‍🤝‍👨🏼' => 'indoda nebhinqa abambe izandla: ithoni yesikhumba emnyama, ithoni yesikhumba esikhanyayo phakathi',
    '👩🏿‍🤝‍👨🏽' => 'indoda nebhinqa abambe izandla: ithoni yesikhumba emnyama, ithoni yesikhumba esiphakathi',
    '👩🏿‍🤝‍👨🏾' => 'indoda nebhinqa abambe izandla: ithoni yesikhumba emnyama, ithoni yesikhumba esiphakathi mnyama',
    '👨🏻‍🤝‍👨🏼' => 'amadoda amabini abambene ngezandla: ithoni yesikhumba esikhanyayo, ithoni yesikhumba esikhanyayo phakathi',
    '👨🏻‍🤝‍👨🏽' => 'amadoda amabini abambene ngezandla: ithoni yesikhumba esikhanyayo, ithoni yesikhumba esiphakathi',
    '👨🏻‍🤝‍👨🏾' => 'amadoda amabini abambene ngezandla: ithoni yesikhumba esikhanyayo, ithoni yesikhumba esiphakathi mnyama',
    '👨🏻‍🤝‍👨🏿' => 'amadoda amabini abambene ngezandla: ithoni yesikhumba esikhanyayo, ithoni yesikhumba emnyama',
    '👨🏼‍🤝‍👨🏻' => 'amadoda amabini abambene ngezandla: ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esikhanyayo',
    '👨🏼‍🤝‍👨🏽' => 'amadoda amabini abambene ngezandla: ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esiphakathi',
    '👨🏼‍🤝‍👨🏾' => 'amadoda amabini abambene ngezandla: ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esiphakathi mnyama',
    '👨🏼‍🤝‍👨🏿' => 'amadoda amabini abambene ngezandla: ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba emnyama',
    '👨🏽‍🤝‍👨🏻' => 'amadoda amabini abambene ngezandla: ithoni yesikhumba esiphakathi, ithoni yesikhumba esikhanyayo',
    '👨🏽‍🤝‍👨🏼' => 'amadoda amabini abambene ngezandla: ithoni yesikhumba esiphakathi, ithoni yesikhumba esikhanyayo phakathi',
    '👨🏽‍🤝‍👨🏾' => 'amadoda amabini abambene ngezandla: ithoni yesikhumba esiphakathi, ithoni yesikhumba esiphakathi mnyama',
    '👨🏽‍🤝‍👨🏿' => 'amadoda amabini abambene ngezandla: ithoni yesikhumba esiphakathi, ithoni yesikhumba emnyama',
    '👨🏾‍🤝‍👨🏻' => 'amadoda amabini abambene ngezandla: ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esikhanyayo',
    '👨🏾‍🤝‍👨🏼' => 'amadoda amabini abambene ngezandla: ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esikhanyayo phakathi',
    '👨🏾‍🤝‍👨🏽' => 'amadoda amabini abambene ngezandla: ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esiphakathi',
    '👨🏾‍🤝‍👨🏿' => 'amadoda amabini abambene ngezandla: ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba emnyama',
    '👨🏿‍🤝‍👨🏻' => 'amadoda amabini abambene ngezandla: ithoni yesikhumba emnyama, ithoni yesikhumba esikhanyayo',
    '👨🏿‍🤝‍👨🏼' => 'amadoda amabini abambene ngezandla: ithoni yesikhumba emnyama, ithoni yesikhumba esikhanyayo phakathi',
    '👨🏿‍🤝‍👨🏽' => 'amadoda amabini abambene ngezandla: ithoni yesikhumba emnyama, ithoni yesikhumba esiphakathi',
    '👨🏿‍🤝‍👨🏾' => 'amadoda amabini abambene ngezandla: ithoni yesikhumba emnyama, ithoni yesikhumba esiphakathi mnyama',
    '👩‍❤‍💋‍👨' => 'phuza: ibhinqa, indoda',
    '👨‍❤‍💋‍👨' => 'phuza: indoda, indoda',
    '👩‍❤‍💋‍👩' => 'phuza: ibhinqa, ibhinqa',
    '👨‍👩‍👧‍👦' => 'usapho: indoda, ibhinqa, intombazana, inkwenkwe',
    '👨‍👩‍👦‍👦' => 'usapho: indoda, ibhinqa, inkwenkwe, inkwenkwe',
    '👨‍👩‍👧‍👧' => 'usapho: indoda, ibhinqa, intombazana, intombazana',
    '👨‍👨‍👧‍👦' => 'usapho: indoda, indoda, intombazana, inkwenkwe',
    '👨‍👨‍👦‍👦' => 'usapho: indoda, indoda, inkwenkwe, inkwenkwe',
    '👨‍👨‍👧‍👧' => 'usapho: indoda, indoda, intombazana, intombazana',
    '👩‍👩‍👧‍👦' => 'usapho: ibhinqa, ibhinqa, intombazana, inkwenkwe',
    '👩‍👩‍👦‍👦' => 'usapho: ibhinqa, ibhinqa, inkwenkwe, inkwenkwe',
    '👩‍👩‍👧‍👧' => 'usapho: ibhinqa, ibhinqa, intombazana, intombazana',
    '🫱🏻‍🫲🏼' => 'ukubamba isandla: ithoni yesikhumba esikhanyayo, ithoni yesikhumba esikhanyayo phakathi',
    '🫱🏻‍🫲🏽' => 'ukubamba isandla: ithoni yesikhumba esikhanyayo, ithoni yesikhumba esiphakathi',
    '🫱🏻‍🫲🏾' => 'ukubamba isandla: ithoni yesikhumba esikhanyayo, ithoni yesikhumba esiphakathi mnyama',
    '🫱🏻‍🫲🏿' => 'ukubamba isandla: ithoni yesikhumba esikhanyayo, ithoni yesikhumba emnyama',
    '🫱🏼‍🫲🏻' => 'ukubamba isandla: ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esikhanyayo',
    '🫱🏼‍🫲🏽' => 'ukubamba isandla: ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esiphakathi',
    '🫱🏼‍🫲🏾' => 'ukubamba isandla: ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba esiphakathi mnyama',
    '🫱🏼‍🫲🏿' => 'ukubamba isandla: ithoni yesikhumba esikhanyayo phakathi, ithoni yesikhumba emnyama',
    '🫱🏽‍🫲🏻' => 'ukubamba isandla: ithoni yesikhumba esiphakathi, ithoni yesikhumba esikhanyayo',
    '🫱🏽‍🫲🏼' => 'ukubamba isandla: ithoni yesikhumba esiphakathi, ithoni yesikhumba esikhanyayo phakathi',
    '🫱🏽‍🫲🏾' => 'ukubamba isandla: ithoni yesikhumba esiphakathi, ithoni yesikhumba esiphakathi mnyama',
    '🫱🏽‍🫲🏿' => 'ukubamba isandla: ithoni yesikhumba esiphakathi, ithoni yesikhumba emnyama',
    '🫱🏾‍🫲🏻' => 'ukubamba isandla: ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esikhanyayo',
    '🫱🏾‍🫲🏼' => 'ukubamba isandla: ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esikhanyayo phakathi',
    '🫱🏾‍🫲🏽' => 'ukubamba isandla: ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba esiphakathi',
    '🫱🏾‍🫲🏿' => 'ukubamba isandla: ithoni yesikhumba esiphakathi mnyama, ithoni yesikhumba emnyama',
    '🫱🏿‍🫲🏻' => 'ukubamba isandla: ithoni yesikhumba emnyama, ithoni yesikhumba esikhanyayo',
    '🫱🏿‍🫲🏼' => 'ukubamba isandla: ithoni yesikhumba emnyama, ithoni yesikhumba esikhanyayo phakathi',
    '🫱🏿‍🫲🏽' => 'ukubamba isandla: ithoni yesikhumba emnyama, ithoni yesikhumba esiphakathi',
    '🫱🏿‍🫲🏾' => 'ukubamba isandla: ithoni yesikhumba emnyama, ithoni yesikhumba esiphakathi mnyama',
    '👩‍❤‍👨' => 'isibini esinentliziyo: ibhinqa, indoda',
    '👨‍❤‍👨' => 'isibini esinentliziyo: indoda, indoda',
    '👩‍❤‍👩' => 'isibini esinentliziyo: ibhinqa, ibhinqa',
    '👨‍👩‍👦' => 'usapho: indoda, ibhinqa, inkwenkwe',
    '👨‍👩‍👧' => 'usapho: indoda, ibhinqa, intombazana',
    '👨‍👨‍👦' => 'usapho: indoda, indoda, inkwenkwe',
    '👨‍👨‍👧' => 'usapho: indoda, indoda, intombazana',
    '👩‍👩‍👦' => 'usapho: ibhinqa, ibhinqa, inkwenkwe',
    '👩‍👩‍👧' => 'usapho: ibhinqa, ibhinqa, intombazana',
    '👨‍👦‍👦' => 'usapho: indoda, inkwenkwe, inkwenkwe',
    '👨‍👧‍👦' => 'usapho: indoda, intombazana, inkwenkwe',
    '👨‍👧‍👧' => 'usapho: indoda, intombazana, intombazana',
    '👩‍👦‍👦' => 'usapho: ibhinqa, inkwenkwe, inkwenkwe',
    '👩‍👧‍👦' => 'usapho: ibhinqa, intombazana, inkwenkwe',
    '👩‍👧‍👧' => 'usapho: ibhinqa, intombazana, intombazana',
    '👱🏻‍♂' => 'indoda eneenwele ezimhlophe: ithoni yesikhumba esikhanyayo',
    '👱🏼‍♂' => 'indoda eneenwele ezimhlophe: ithoni yesikhumba esikhanyayo phakathi',
    '👱🏽‍♂' => 'indoda eneenwele ezimhlophe: ithoni yesikhumba esiphakathi',
    '👱🏾‍♂' => 'indoda eneenwele ezimhlophe: ithoni yesikhumba esiphakathi mnyama',
    '👱🏿‍♂' => 'indoda eneenwele ezimhlophe: ithoni yesikhumba emnyama',
    '👱🏻‍♀' => 'ibhinqa elineenwele ezimhlophe: ithoni yesikhumba esikhanyayo',
    '👱🏼‍♀' => 'ibhinqa elineenwele ezimhlophe: ithoni yesikhumba esikhanyayo phakathi',
    '👱🏽‍♀' => 'ibhinqa elineenwele ezimhlophe: ithoni yesikhumba esiphakathi',
    '👱🏾‍♀' => 'ibhinqa elineenwele ezimhlophe: ithoni yesikhumba esiphakathi mnyama',
    '👱🏿‍♀' => 'ibhinqa elineenwele ezimhlophe: ithoni yesikhumba emnyama',
    '🙍🏻‍♂' => 'indoda efinge iintshiya: ithoni yesikhumba esikhanyayo',
    '🙍🏼‍♂' => 'indoda efinge iintshiya: ithoni yesikhumba esikhanyayo phakathi',
    '🙍🏽‍♂' => 'indoda efinge iintshiya: ithoni yesikhumba esiphakathi',
    '🙍🏾‍♂' => 'indoda efinge iintshiya: ithoni yesikhumba esiphakathi mnyama',
    '🙍🏿‍♂' => 'indoda efinge iintshiya: ithoni yesikhumba emnyama',
    '🙍🏻‍♀' => 'ibhinqa elifinge iintshiya: ithoni yesikhumba esikhanyayo',
    '🙍🏼‍♀' => 'ibhinqa elifinge iintshiya: ithoni yesikhumba esikhanyayo phakathi',
    '🙍🏽‍♀' => 'ibhinqa elifinge iintshiya: ithoni yesikhumba esiphakathi',
    '🙍🏾‍♀' => 'ibhinqa elifinge iintshiya: ithoni yesikhumba esiphakathi mnyama',
    '🙍🏿‍♀' => 'ibhinqa elifinge iintshiya: ithoni yesikhumba emnyama',
    '🙎🏻‍♂' => 'indoda etsolisa umlomo: ithoni yesikhumba esikhanyayo',
    '🙎🏼‍♂' => 'indoda etsolisa umlomo: ithoni yesikhumba esikhanyayo phakathi',
    '🙎🏽‍♂' => 'indoda etsolisa umlomo: ithoni yesikhumba esiphakathi',
    '🙎🏾‍♂' => 'indoda etsolisa umlomo: ithoni yesikhumba esiphakathi mnyama',
    '🙎🏿‍♂' => 'indoda etsolisa umlomo: ithoni yesikhumba emnyama',
    '🙎🏻‍♀' => 'ibhinqa elitsolisa umlomo: ithoni yesikhumba esikhanyayo',
    '🙎🏼‍♀' => 'ibhinqa elitsolisa umlomo: ithoni yesikhumba esikhanyayo phakathi',
    '🙎🏽‍♀' => 'ibhinqa elitsolisa umlomo: ithoni yesikhumba esiphakathi',
    '🙎🏾‍♀' => 'ibhinqa elitsolisa umlomo: ithoni yesikhumba esiphakathi mnyama',
    '🙎🏿‍♀' => 'ibhinqa elitsolisa umlomo: ithoni yesikhumba emnyama',
    '🙅🏻‍♂' => 'indoda elijekulayo ukuthi HAYI: ithoni yesikhumba esikhanyayo',
    '🙅🏼‍♂' => 'indoda elijekulayo ukuthi HAYI: ithoni yesikhumba esikhanyayo phakathi',
    '🙅🏽‍♂' => 'indoda elijekulayo ukuthi HAYI: ithoni yesikhumba esiphakathi',
    '🙅🏾‍♂' => 'indoda elijekulayo ukuthi HAYI: ithoni yesikhumba esiphakathi mnyama',
    '🙅🏿‍♂' => 'indoda elijekulayo ukuthi HAYI: ithoni yesikhumba emnyama',
    '🙅🏻‍♀' => 'ibhinqa elijekulayo ukuthi HAYI: ithoni yesikhumba esikhanyayo',
    '🙅🏼‍♀' => 'ibhinqa elijekulayo ukuthi HAYI: ithoni yesikhumba esikhanyayo phakathi',
    '🙅🏽‍♀' => 'ibhinqa elijekulayo ukuthi HAYI: ithoni yesikhumba esiphakathi',
    '🙅🏾‍♀' => 'ibhinqa elijekulayo ukuthi HAYI: ithoni yesikhumba esiphakathi mnyama',
    '🙅🏿‍♀' => 'ibhinqa elijekulayo ukuthi HAYI: ithoni yesikhumba emnyama',
    '🙆🏻‍♂' => 'indoda ejekula ukuthi Kulungile: ithoni yesikhumba esikhanyayo',
    '🙆🏼‍♂' => 'indoda ejekula ukuthi Kulungile: ithoni yesikhumba esikhanyayo phakathi',
    '🙆🏽‍♂' => 'indoda ejekula ukuthi Kulungile: ithoni yesikhumba esiphakathi',
    '🙆🏾‍♂' => 'indoda ejekula ukuthi Kulungile: ithoni yesikhumba esiphakathi mnyama',
    '🙆🏿‍♂' => 'indoda ejekula ukuthi Kulungile: ithoni yesikhumba emnyama',
    '🙆🏻‍♀' => 'ibhinqa elijekula ukuthi Kulungile: ithoni yesikhumba esikhanyayo',
    '🙆🏼‍♀' => 'ibhinqa elijekula ukuthi Kulungile: ithoni yesikhumba esikhanyayo phakathi',
    '🙆🏽‍♀' => 'ibhinqa elijekula ukuthi Kulungile: ithoni yesikhumba esiphakathi',
    '🙆🏾‍♀' => 'ibhinqa elijekula ukuthi Kulungile: ithoni yesikhumba esiphakathi mnyama',
    '🙆🏿‍♀' => 'ibhinqa elijekula ukuthi Kulungile: ithoni yesikhumba emnyama',
    '💁🏻‍♂' => 'indoda ephethula isandla: ithoni yesikhumba esikhanyayo',
    '💁🏼‍♂' => 'indoda ephethula isandla: ithoni yesikhumba esikhanyayo phakathi',
    '💁🏽‍♂' => 'indoda ephethula isandla: ithoni yesikhumba esiphakathi',
    '💁🏾‍♂' => 'indoda ephethula isandla: ithoni yesikhumba esiphakathi mnyama',
    '💁🏿‍♂' => 'indoda ephethula isandla: ithoni yesikhumba emnyama',
    '💁🏻‍♀' => 'ibhinqa eluphethula isandla: ithoni yesikhumba esikhanyayo',
    '💁🏼‍♀' => 'ibhinqa eluphethula isandla: ithoni yesikhumba esikhanyayo phakathi',
    '💁🏽‍♀' => 'ibhinqa eluphethula isandla: ithoni yesikhumba esiphakathi',
    '💁🏾‍♀' => 'ibhinqa eluphethula isandla: ithoni yesikhumba esiphakathi mnyama',
    '💁🏿‍♀' => 'ibhinqa eluphethula isandla: ithoni yesikhumba emnyama',
    '🙋🏻‍♂' => 'indoda ephakamisa isandla: ithoni yesikhumba esikhanyayo',
    '🙋🏼‍♂' => 'indoda ephakamisa isandla: ithoni yesikhumba esikhanyayo phakathi',
    '🙋🏽‍♂' => 'indoda ephakamisa isandla: ithoni yesikhumba esiphakathi',
    '🙋🏾‍♂' => 'indoda ephakamisa isandla: ithoni yesikhumba esiphakathi mnyama',
    '🙋🏿‍♂' => 'indoda ephakamisa isandla: ithoni yesikhumba emnyama',
    '🙋🏻‍♀' => 'ibhinqa eliphakamisa isandla: ithoni yesikhumba esikhanyayo',
    '🙋🏼‍♀' => 'ibhinqa eliphakamisa isandla: ithoni yesikhumba esikhanyayo phakathi',
    '🙋🏽‍♀' => 'ibhinqa eliphakamisa isandla: ithoni yesikhumba esiphakathi',
    '🙋🏾‍♀' => 'ibhinqa eliphakamisa isandla: ithoni yesikhumba esiphakathi mnyama',
    '🙋🏿‍♀' => 'ibhinqa eliphakamisa isandla: ithoni yesikhumba emnyama',
    '🙇🏻‍♂' => 'indoda egobayo: ithoni yesikhumba esikhanyayo',
    '🙇🏼‍♂' => 'indoda egobayo: ithoni yesikhumba esikhanyayo phakathi',
    '🙇🏽‍♂' => 'indoda egobayo: ithoni yesikhumba esiphakathi',
    '🙇🏾‍♂' => 'indoda egobayo: ithoni yesikhumba esiphakathi mnyama',
    '🙇🏿‍♂' => 'indoda egobayo: ithoni yesikhumba emnyama',
    '🙇🏻‍♀' => 'ibhinqa eligobayo: ithoni yesikhumba esikhanyayo',
    '🙇🏼‍♀' => 'ibhinqa eligobayo: ithoni yesikhumba esikhanyayo phakathi',
    '🙇🏽‍♀' => 'ibhinqa eligobayo: ithoni yesikhumba esiphakathi',
    '🙇🏾‍♀' => 'ibhinqa eligobayo: ithoni yesikhumba esiphakathi mnyama',
    '🙇🏿‍♀' => 'ibhinqa eligobayo: ithoni yesikhumba emnyama',
    '🤦🏻‍♂' => 'indoda egqume ubuso ngezandla: ithoni yesikhumba esikhanyayo',
    '🤦🏼‍♂' => 'indoda egqume ubuso ngezandla: ithoni yesikhumba esikhanyayo phakathi',
    '🤦🏽‍♂' => 'indoda egqume ubuso ngezandla: ithoni yesikhumba esiphakathi',
    '🤦🏾‍♂' => 'indoda egqume ubuso ngezandla: ithoni yesikhumba esiphakathi mnyama',
    '🤦🏿‍♂' => 'indoda egqume ubuso ngezandla: ithoni yesikhumba emnyama',
    '🤦🏻‍♀' => 'ibhinqa eligqume ubuso ngezandla: ithoni yesikhumba esikhanyayo',
    '🤦🏼‍♀' => 'ibhinqa eligqume ubuso ngezandla: ithoni yesikhumba esikhanyayo phakathi',
    '🤦🏽‍♀' => 'ibhinqa eligqume ubuso ngezandla: ithoni yesikhumba esiphakathi',
    '🤦🏾‍♀' => 'ibhinqa eligqume ubuso ngezandla: ithoni yesikhumba esiphakathi mnyama',
    '🤦🏿‍♀' => 'ibhinqa eligqume ubuso ngezandla: ithoni yesikhumba emnyama',
    '🤷🏻‍♂' => 'indoda enyikinya amagxa: ithoni yesikhumba esikhanyayo',
    '🤷🏼‍♂' => 'indoda enyikinya amagxa: ithoni yesikhumba esikhanyayo phakathi',
    '🤷🏽‍♂' => 'indoda enyikinya amagxa: ithoni yesikhumba esiphakathi',
    '🤷🏾‍♂' => 'indoda enyikinya amagxa: ithoni yesikhumba esiphakathi mnyama',
    '🤷🏿‍♂' => 'indoda enyikinya amagxa: ithoni yesikhumba emnyama',
    '🤷🏻‍♀' => 'ibhinqa elinyikinya amagxa: ithoni yesikhumba esikhanyayo',
    '🤷🏼‍♀' => 'ibhinqa elinyikinya amagxa: ithoni yesikhumba esikhanyayo phakathi',
    '🤷🏽‍♀' => 'ibhinqa elinyikinya amagxa: ithoni yesikhumba esiphakathi',
    '🤷🏾‍♀' => 'ibhinqa elinyikinya amagxa: ithoni yesikhumba esiphakathi mnyama',
    '🤷🏿‍♀' => 'ibhinqa elinyikinya amagxa: ithoni yesikhumba emnyama',
    '👨🏻‍⚕' => 'umsebenzi wezonyango oyindoda: ithoni yesikhumba esikhanyayo',
    '👨🏼‍⚕' => 'umsebenzi wezonyango oyindoda: ithoni yesikhumba esikhanyayo phakathi',
    '👨🏽‍⚕' => 'umsebenzi wezonyango oyindoda: ithoni yesikhumba esiphakathi',
    '👨🏾‍⚕' => 'umsebenzi wezonyango oyindoda: ithoni yesikhumba esiphakathi mnyama',
    '👨🏿‍⚕' => 'umsebenzi wezonyango oyindoda: ithoni yesikhumba emnyama',
    '👩🏻‍⚕' => 'umsebenzi wempilo olibhinqa: ithoni yesikhumba esikhanyayo',
    '👩🏼‍⚕' => 'umsebenzi wempilo olibhinqa: ithoni yesikhumba esikhanyayo phakathi',
    '👩🏽‍⚕' => 'umsebenzi wempilo olibhinqa: ithoni yesikhumba esiphakathi',
    '👩🏾‍⚕' => 'umsebenzi wempilo olibhinqa: ithoni yesikhumba esiphakathi mnyama',
    '👩🏿‍⚕' => 'umsebenzi wempilo olibhinqa: ithoni yesikhumba emnyama',
    '👨🏻‍🎓' => 'umfundi oyindoda: ithoni yesikhumba esikhanyayo',
    '👨🏼‍🎓' => 'umfundi oyindoda: ithoni yesikhumba esikhanyayo phakathi',
    '👨🏽‍🎓' => 'umfundi oyindoda: ithoni yesikhumba esiphakathi',
    '👨🏾‍🎓' => 'umfundi oyindoda: ithoni yesikhumba esiphakathi mnyama',
    '👨🏿‍🎓' => 'umfundi oyindoda: ithoni yesikhumba emnyama',
    '👩🏻‍🎓' => 'umfundi olibhinqa: ithoni yesikhumba esikhanyayo',
    '👩🏼‍🎓' => 'umfundi olibhinqa: ithoni yesikhumba esikhanyayo phakathi',
    '👩🏽‍🎓' => 'umfundi olibhinqa: ithoni yesikhumba esiphakathi',
    '👩🏾‍🎓' => 'umfundi olibhinqa: ithoni yesikhumba esiphakathi mnyama',
    '👩🏿‍🎓' => 'umfundi olibhinqa: ithoni yesikhumba emnyama',
    '👨🏻‍🏫' => 'utitshala oyindoda: ithoni yesikhumba esikhanyayo',
    '👨🏼‍🏫' => 'utitshala oyindoda: ithoni yesikhumba esikhanyayo phakathi',
    '👨🏽‍🏫' => 'utitshala oyindoda: ithoni yesikhumba esiphakathi',
    '👨🏾‍🏫' => 'utitshala oyindoda: ithoni yesikhumba esiphakathi mnyama',
    '👨🏿‍🏫' => 'utitshala oyindoda: ithoni yesikhumba emnyama',
    '👩🏻‍🏫' => 'utitshala olibhinqa: ithoni yesikhumba esikhanyayo',
    '👩🏼‍🏫' => 'utitshala olibhinqa: ithoni yesikhumba esikhanyayo phakathi',
    '👩🏽‍🏫' => 'utitshala olibhinqa: ithoni yesikhumba esiphakathi',
    '👩🏾‍🏫' => 'utitshala olibhinqa: ithoni yesikhumba esiphakathi mnyama',
    '👩🏿‍🏫' => 'utitshala olibhinqa: ithoni yesikhumba emnyama',
    '👨🏻‍⚖' => 'umgwebi oyindoda: ithoni yesikhumba esikhanyayo',
    '👨🏼‍⚖' => 'umgwebi oyindoda: ithoni yesikhumba esikhanyayo phakathi',
    '👨🏽‍⚖' => 'umgwebi oyindoda: ithoni yesikhumba esiphakathi',
    '👨🏾‍⚖' => 'umgwebi oyindoda: ithoni yesikhumba esiphakathi mnyama',
    '👨🏿‍⚖' => 'umgwebi oyindoda: ithoni yesikhumba emnyama',
    '👩🏻‍⚖' => 'umgwebi olibhinqa: ithoni yesikhumba esikhanyayo',
    '👩🏼‍⚖' => 'umgwebi olibhinqa: ithoni yesikhumba esikhanyayo phakathi',
    '👩🏽‍⚖' => 'umgwebi olibhinqa: ithoni yesikhumba esiphakathi',
    '👩🏾‍⚖' => 'umgwebi olibhinqa: ithoni yesikhumba esiphakathi mnyama',
    '👩🏿‍⚖' => 'umgwebi olibhinqa: ithoni yesikhumba emnyama',
    '👨🏻‍🌾' => 'umfama oyindoda: ithoni yesikhumba esikhanyayo',
    '👨🏼‍🌾' => 'umfama oyindoda: ithoni yesikhumba esikhanyayo phakathi',
    '👨🏽‍🌾' => 'umfama oyindoda: ithoni yesikhumba esiphakathi',
    '👨🏾‍🌾' => 'umfama oyindoda: ithoni yesikhumba esiphakathi mnyama',
    '👨🏿‍🌾' => 'umfama oyindoda: ithoni yesikhumba emnyama',
    '👩🏻‍🌾' => 'umfama olibhinqa: ithoni yesikhumba esikhanyayo',
    '👩🏼‍🌾' => 'umfama olibhinqa: ithoni yesikhumba esikhanyayo phakathi',
    '👩🏽‍🌾' => 'umfama olibhinqa: ithoni yesikhumba esiphakathi',
    '👩🏾‍🌾' => 'umfama olibhinqa: ithoni yesikhumba esiphakathi mnyama',
    '👩🏿‍🌾' => 'umfama olibhinqa: ithoni yesikhumba emnyama',
    '👨🏻‍🍳' => 'umpheki oyindoda: ithoni yesikhumba esikhanyayo',
    '👨🏼‍🍳' => 'umpheki oyindoda: ithoni yesikhumba esikhanyayo phakathi',
    '👨🏽‍🍳' => 'umpheki oyindoda: ithoni yesikhumba esiphakathi',
    '👨🏾‍🍳' => 'umpheki oyindoda: ithoni yesikhumba esiphakathi mnyama',
    '👨🏿‍🍳' => 'umpheki oyindoda: ithoni yesikhumba emnyama',
    '👩🏻‍🍳' => 'umpheki olibhinqa: ithoni yesikhumba esikhanyayo',
    '👩🏼‍🍳' => 'umpheki olibhinqa: ithoni yesikhumba esikhanyayo phakathi',
    '👩🏽‍🍳' => 'umpheki olibhinqa: ithoni yesikhumba esiphakathi',
    '👩🏾‍🍳' => 'umpheki olibhinqa: ithoni yesikhumba esiphakathi mnyama',
    '👩🏿‍🍳' => 'umpheki olibhinqa: ithoni yesikhumba emnyama',
    '👨🏻‍🔧' => 'umkhandi oyindoda: ithoni yesikhumba esikhanyayo',
    '👨🏼‍🔧' => 'umkhandi oyindoda: ithoni yesikhumba esikhanyayo phakathi',
    '👨🏽‍🔧' => 'umkhandi oyindoda: ithoni yesikhumba esiphakathi',
    '👨🏾‍🔧' => 'umkhandi oyindoda: ithoni yesikhumba esiphakathi mnyama',
    '👨🏿‍🔧' => 'umkhandi oyindoda: ithoni yesikhumba emnyama',
    '👩🏻‍🔧' => 'umkhandi olibhinqa: ithoni yesikhumba esikhanyayo',
    '👩🏼‍🔧' => 'umkhandi olibhinqa: ithoni yesikhumba esikhanyayo phakathi',
    '👩🏽‍🔧' => 'umkhandi olibhinqa: ithoni yesikhumba esiphakathi',
    '👩🏾‍🔧' => 'umkhandi olibhinqa: ithoni yesikhumba esiphakathi mnyama',
    '👩🏿‍🔧' => 'umkhandi olibhinqa: ithoni yesikhumba emnyama',
    '👨🏻‍🏭' => 'umsebenzi wasefektri oyindoda: ithoni yesikhumba esikhanyayo',
    '👨🏼‍🏭' => 'umsebenzi wasefektri oyindoda: ithoni yesikhumba esikhanyayo phakathi',
    '👨🏽‍🏭' => 'umsebenzi wasefektri oyindoda: ithoni yesikhumba esiphakathi',
    '👨🏾‍🏭' => 'umsebenzi wasefektri oyindoda: ithoni yesikhumba esiphakathi mnyama',
    '👨🏿‍🏭' => 'umsebenzi wasefektri oyindoda: ithoni yesikhumba emnyama',
    '👩🏻‍🏭' => 'umsebenzi wasefektri olibhinqa: ithoni yesikhumba esikhanyayo',
    '👩🏼‍🏭' => 'umsebenzi wasefektri olibhinqa: ithoni yesikhumba esikhanyayo phakathi',
    '👩🏽‍🏭' => 'umsebenzi wasefektri olibhinqa: ithoni yesikhumba esiphakathi',
    '👩🏾‍🏭' => 'umsebenzi wasefektri olibhinqa: ithoni yesikhumba esiphakathi mnyama',
    '👩🏿‍🏭' => 'umsebenzi wasefektri olibhinqa: ithoni yesikhumba emnyama',
    '👨🏻‍💼' => 'umsebenzi waseofisini oyindoda: ithoni yesikhumba esikhanyayo',
    '👨🏼‍💼' => 'umsebenzi waseofisini oyindoda: ithoni yesikhumba esikhanyayo phakathi',
    '👨🏽‍💼' => 'umsebenzi waseofisini oyindoda: ithoni yesikhumba esiphakathi',
    '👨🏾‍💼' => 'umsebenzi waseofisini oyindoda: ithoni yesikhumba esiphakathi mnyama',
    '👨🏿‍💼' => 'umsebenzi waseofisini oyindoda: ithoni yesikhumba emnyama',
    '👩🏻‍💼' => 'umsebenzi waseofisini olibhinqa: ithoni yesikhumba esikhanyayo',
    '👩🏼‍💼' => 'umsebenzi waseofisini olibhinqa: ithoni yesikhumba esikhanyayo phakathi',
    '👩🏽‍💼' => 'umsebenzi waseofisini olibhinqa: ithoni yesikhumba esiphakathi',
    '👩🏾‍💼' => 'umsebenzi waseofisini olibhinqa: ithoni yesikhumba esiphakathi mnyama',
    '👩🏿‍💼' => 'umsebenzi waseofisini olibhinqa: ithoni yesikhumba emnyama',
    '👨🏻‍🔬' => 'isazinzulu esiyindoda: ithoni yesikhumba esikhanyayo',
    '👨🏼‍🔬' => 'isazinzulu esiyindoda: ithoni yesikhumba esikhanyayo phakathi',
    '👨🏽‍🔬' => 'isazinzulu esiyindoda: ithoni yesikhumba esiphakathi',
    '👨🏾‍🔬' => 'isazinzulu esiyindoda: ithoni yesikhumba esiphakathi mnyama',
    '👨🏿‍🔬' => 'isazinzulu esiyindoda: ithoni yesikhumba emnyama',
    '👩🏻‍🔬' => 'isazinzulu esilibhinqa: ithoni yesikhumba esikhanyayo',
    '👩🏼‍🔬' => 'isazinzulu esilibhinqa: ithoni yesikhumba esikhanyayo phakathi',
    '👩🏽‍🔬' => 'isazinzulu esilibhinqa: ithoni yesikhumba esiphakathi',
    '👩🏾‍🔬' => 'isazinzulu esilibhinqa: ithoni yesikhumba esiphakathi mnyama',
    '👩🏿‍🔬' => 'isazinzulu esilibhinqa: ithoni yesikhumba emnyama',
    '👨🏻‍💻' => 'ingcali eyindoda: ithoni yesikhumba esikhanyayo',
    '👨🏼‍💻' => 'ingcali eyindoda: ithoni yesikhumba esikhanyayo phakathi',
    '👨🏽‍💻' => 'ingcali eyindoda: ithoni yesikhumba esiphakathi',
    '👨🏾‍💻' => 'ingcali eyindoda: ithoni yesikhumba esiphakathi mnyama',
    '👨🏿‍💻' => 'ingcali eyindoda: ithoni yesikhumba emnyama',
    '👩🏻‍💻' => 'ingcali elilibhinqa: ithoni yesikhumba esikhanyayo',
    '👩🏼‍💻' => 'ingcali elilibhinqa: ithoni yesikhumba esikhanyayo phakathi',
    '👩🏽‍💻' => 'ingcali elilibhinqa: ithoni yesikhumba esiphakathi',
    '👩🏾‍💻' => 'ingcali elilibhinqa: ithoni yesikhumba esiphakathi mnyama',
    '👩🏿‍💻' => 'ingcali elilibhinqa: ithoni yesikhumba emnyama',
    '👨🏻‍🎤' => 'umculi oyindoda: ithoni yesikhumba esikhanyayo',
    '👨🏼‍🎤' => 'umculi oyindoda: ithoni yesikhumba esikhanyayo phakathi',
    '👨🏽‍🎤' => 'umculi oyindoda: ithoni yesikhumba esiphakathi',
    '👨🏾‍🎤' => 'umculi oyindoda: ithoni yesikhumba esiphakathi mnyama',
    '👨🏿‍🎤' => 'umculi oyindoda: ithoni yesikhumba emnyama',
    '👩🏻‍🎤' => 'umculi olibhinqa: ithoni yesikhumba esikhanyayo',
    '👩🏼‍🎤' => 'umculi olibhinqa: ithoni yesikhumba esikhanyayo phakathi',
    '👩🏽‍🎤' => 'umculi olibhinqa: ithoni yesikhumba esiphakathi',
    '👩🏾‍🎤' => 'umculi olibhinqa: ithoni yesikhumba esiphakathi mnyama',
    '👩🏿‍🎤' => 'umculi olibhinqa: ithoni yesikhumba emnyama',
    '👨🏻‍🎨' => 'iathisti eyindoda: ithoni yesikhumba esikhanyayo',
    '👨🏼‍🎨' => 'iathisti eyindoda: ithoni yesikhumba esikhanyayo phakathi',
    '👨🏽‍🎨' => 'iathisti eyindoda: ithoni yesikhumba esiphakathi',
    '👨🏾‍🎨' => 'iathisti eyindoda: ithoni yesikhumba esiphakathi mnyama',
    '👨🏿‍🎨' => 'iathisti eyindoda: ithoni yesikhumba emnyama',
    '👩🏻‍🎨' => 'igcisa elilibhinqa: ithoni yesikhumba esikhanyayo',
    '👩🏼‍🎨' => 'igcisa elilibhinqa: ithoni yesikhumba esikhanyayo phakathi',
    '👩🏽‍🎨' => 'igcisa elilibhinqa: ithoni yesikhumba esiphakathi',
    '👩🏾‍🎨' => 'igcisa elilibhinqa: ithoni yesikhumba esiphakathi mnyama',
    '👩🏿‍🎨' => 'igcisa elilibhinqa: ithoni yesikhumba emnyama',
    '👨🏻‍✈' => 'umqhubi wenqwelo-moya oyindoda: ithoni yesikhumba esikhanyayo',
    '👨🏼‍✈' => 'umqhubi wenqwelo-moya oyindoda: ithoni yesikhumba esikhanyayo phakathi',
    '👨🏽‍✈' => 'umqhubi wenqwelo-moya oyindoda: ithoni yesikhumba esiphakathi',
    '👨🏾‍✈' => 'umqhubi wenqwelo-moya oyindoda: ithoni yesikhumba esiphakathi mnyama',
    '👨🏿‍✈' => 'umqhubi wenqwelo-moya oyindoda: ithoni yesikhumba emnyama',
    '👩🏻‍✈' => 'umqhubi wenqwelo-moya olibhinqa: ithoni yesikhumba esikhanyayo',
    '👩🏼‍✈' => 'umqhubi wenqwelo-moya olibhinqa: ithoni yesikhumba esikhanyayo phakathi',
    '👩🏽‍✈' => 'umqhubi wenqwelo-moya olibhinqa: ithoni yesikhumba esiphakathi',
    '👩🏾‍✈' => 'umqhubi wenqwelo-moya olibhinqa: ithoni yesikhumba esiphakathi mnyama',
    '👩🏿‍✈' => 'umqhubi wenqwelo-moya olibhinqa: ithoni yesikhumba emnyama',
    '👨🏻‍🚀' => 'usomajukujuku oyindoda: ithoni yesikhumba esikhanyayo',
    '👨🏼‍🚀' => 'usomajukujuku oyindoda: ithoni yesikhumba esikhanyayo phakathi',
    '👨🏽‍🚀' => 'usomajukujuku oyindoda: ithoni yesikhumba esiphakathi',
    '👨🏾‍🚀' => 'usomajukujuku oyindoda: ithoni yesikhumba esiphakathi mnyama',
    '👨🏿‍🚀' => 'usomajukujuku oyindoda: ithoni yesikhumba emnyama',
    '👩🏻‍🚀' => 'usomajukujuku olubhinqa: ithoni yesikhumba esikhanyayo',
    '👩🏼‍🚀' => 'usomajukujuku olubhinqa: ithoni yesikhumba esikhanyayo phakathi',
    '👩🏽‍🚀' => 'usomajukujuku olubhinqa: ithoni yesikhumba esiphakathi',
    '👩🏾‍🚀' => 'usomajukujuku olubhinqa: ithoni yesikhumba esiphakathi mnyama',
    '👩🏿‍🚀' => 'usomajukujuku olubhinqa: ithoni yesikhumba emnyama',
    '👨🏻‍🚒' => 'umcimi-mlilo oyindoda: ithoni yesikhumba esikhanyayo',
    '👨🏼‍🚒' => 'umcimi-mlilo oyindoda: ithoni yesikhumba esikhanyayo phakathi',
    '👨🏽‍🚒' => 'umcimi-mlilo oyindoda: ithoni yesikhumba esiphakathi',
    '👨🏾‍🚒' => 'umcimi-mlilo oyindoda: ithoni yesikhumba esiphakathi mnyama',
    '👨🏿‍🚒' => 'umcimi-mlilo oyindoda: ithoni yesikhumba emnyama',
    '👩🏻‍🚒' => 'umcimi-mlilo olibhinqa: ithoni yesikhumba esikhanyayo',
    '👩🏼‍🚒' => 'umcimi-mlilo olibhinqa: ithoni yesikhumba esikhanyayo phakathi',
    '👩🏽‍🚒' => 'umcimi-mlilo olibhinqa: ithoni yesikhumba esiphakathi',
    '👩🏾‍🚒' => 'umcimi-mlilo olibhinqa: ithoni yesikhumba esiphakathi mnyama',
    '👩🏿‍🚒' => 'umcimi-mlilo olibhinqa: ithoni yesikhumba emnyama',
    '👮🏻‍♂' => 'igosa lepolisa eliyindoda: ithoni yesikhumba esikhanyayo',
    '👮🏼‍♂' => 'igosa lepolisa eliyindoda: ithoni yesikhumba esikhanyayo phakathi',
    '👮🏽‍♂' => 'igosa lepolisa eliyindoda: ithoni yesikhumba esiphakathi',
    '👮🏾‍♂' => 'igosa lepolisa eliyindoda: ithoni yesikhumba esiphakathi mnyama',
    '👮🏿‍♂' => 'igosa lepolisa eliyindoda: ithoni yesikhumba emnyama',
    '👮🏻‍♀' => 'igosa lepolisa elilibhinqa: ithoni yesikhumba esikhanyayo',
    '👮🏼‍♀' => 'igosa lepolisa elilibhinqa: ithoni yesikhumba esikhanyayo phakathi',
    '👮🏽‍♀' => 'igosa lepolisa elilibhinqa: ithoni yesikhumba esiphakathi',
    '👮🏾‍♀' => 'igosa lepolisa elilibhinqa: ithoni yesikhumba esiphakathi mnyama',
    '👮🏿‍♀' => 'igosa lepolisa elilibhinqa: ithoni yesikhumba emnyama',
    '🕵🏻‍♂' => 'umcuphi oyindoda: ithoni yesikhumba esikhanyayo',
    '🕵🏼‍♂' => 'umcuphi oyindoda: ithoni yesikhumba esikhanyayo phakathi',
    '🕵🏽‍♂' => 'umcuphi oyindoda: ithoni yesikhumba esiphakathi',
    '🕵🏾‍♂' => 'umcuphi oyindoda: ithoni yesikhumba esiphakathi mnyama',
    '🕵🏿‍♂' => 'umcuphi oyindoda: ithoni yesikhumba emnyama',
    '🕵🏻‍♀' => 'umcuphi olibhinqa: ithoni yesikhumba esikhanyayo',
    '🕵🏼‍♀' => 'umcuphi olibhinqa: ithoni yesikhumba esikhanyayo phakathi',
    '🕵🏽‍♀' => 'umcuphi olibhinqa: ithoni yesikhumba esiphakathi',
    '🕵🏾‍♀' => 'umcuphi olibhinqa: ithoni yesikhumba esiphakathi mnyama',
    '🕵🏿‍♀' => 'umcuphi olibhinqa: ithoni yesikhumba emnyama',
    '💂🏻‍♂' => 'unogada oyindoda: ithoni yesikhumba esikhanyayo',
    '💂🏼‍♂' => 'unogada oyindoda: ithoni yesikhumba esikhanyayo phakathi',
    '💂🏽‍♂' => 'unogada oyindoda: ithoni yesikhumba esiphakathi',
    '💂🏾‍♂' => 'unogada oyindoda: ithoni yesikhumba esiphakathi mnyama',
    '💂🏿‍♂' => 'unogada oyindoda: ithoni yesikhumba emnyama',
    '💂🏻‍♀' => 'unogada olibhinqa: ithoni yesikhumba esikhanyayo',
    '💂🏼‍♀' => 'unogada olibhinqa: ithoni yesikhumba esikhanyayo phakathi',
    '💂🏽‍♀' => 'unogada olibhinqa: ithoni yesikhumba esiphakathi',
    '💂🏾‍♀' => 'unogada olibhinqa: ithoni yesikhumba esiphakathi mnyama',
    '💂🏿‍♀' => 'unogada olibhinqa: ithoni yesikhumba emnyama',
    '👷🏻‍♂' => 'umsebenzi wolwakhiwo oyindoda: ithoni yesikhumba esikhanyayo',
    '👷🏼‍♂' => 'umsebenzi wolwakhiwo oyindoda: ithoni yesikhumba esikhanyayo phakathi',
    '👷🏽‍♂' => 'umsebenzi wolwakhiwo oyindoda: ithoni yesikhumba esiphakathi',
    '👷🏾‍♂' => 'umsebenzi wolwakhiwo oyindoda: ithoni yesikhumba esiphakathi mnyama',
    '👷🏿‍♂' => 'umsebenzi wolwakhiwo oyindoda: ithoni yesikhumba emnyama',
    '👷🏻‍♀' => 'umsebenzi wolwakhiwo olibhinqa: ithoni yesikhumba esikhanyayo',
    '👷🏼‍♀' => 'umsebenzi wolwakhiwo olibhinqa: ithoni yesikhumba esikhanyayo phakathi',
    '👷🏽‍♀' => 'umsebenzi wolwakhiwo olibhinqa: ithoni yesikhumba esiphakathi',
    '👷🏾‍♀' => 'umsebenzi wolwakhiwo olibhinqa: ithoni yesikhumba esiphakathi mnyama',
    '👷🏿‍♀' => 'umsebenzi wolwakhiwo olibhinqa: ithoni yesikhumba emnyama',
    '👳🏻‍♂' => 'indoda ethwele unkontsho: ithoni yesikhumba esikhanyayo',
    '👳🏼‍♂' => 'indoda ethwele unkontsho: ithoni yesikhumba esikhanyayo phakathi',
    '👳🏽‍♂' => 'indoda ethwele unkontsho: ithoni yesikhumba esiphakathi',
    '👳🏾‍♂' => 'indoda ethwele unkontsho: ithoni yesikhumba esiphakathi mnyama',
    '👳🏿‍♂' => 'indoda ethwele unkontsho: ithoni yesikhumba emnyama',
    '👳🏻‍♀' => 'ibhinqa elithwele unkontsho: ithoni yesikhumba esikhanyayo',
    '👳🏼‍♀' => 'ibhinqa elithwele unkontsho: ithoni yesikhumba esikhanyayo phakathi',
    '👳🏽‍♀' => 'ibhinqa elithwele unkontsho: ithoni yesikhumba esiphakathi',
    '👳🏾‍♀' => 'ibhinqa elithwele unkontsho: ithoni yesikhumba esiphakathi mnyama',
    '👳🏿‍♀' => 'ibhinqa elithwele unkontsho: ithoni yesikhumba emnyama',
    '🧙🏻‍♂' => 'i-mage eyindoda: ithoni yesikhumba esikhanyayo',
    '🧙🏼‍♂' => 'i-mage eyindoda: ithoni yesikhumba esikhanyayo phakathi',
    '🧙🏽‍♂' => 'i-mage eyindoda: ithoni yesikhumba esiphakathi',
    '🧙🏾‍♂' => 'i-mage eyindoda: ithoni yesikhumba esiphakathi mnyama',
    '🧙🏿‍♂' => 'i-mage eyindoda: ithoni yesikhumba emnyama',
    '🧙🏻‍♀' => 'i-mage elibhinqa: ithoni yesikhumba esikhanyayo',
    '🧙🏼‍♀' => 'i-mage elibhinqa: ithoni yesikhumba esikhanyayo phakathi',
    '🧙🏽‍♀' => 'i-mage elibhinqa: ithoni yesikhumba esiphakathi',
    '🧙🏾‍♀' => 'i-mage elibhinqa: ithoni yesikhumba esiphakathi mnyama',
    '🧙🏿‍♀' => 'i-mage elibhinqa: ithoni yesikhumba emnyama',
    '🧚🏻‍♂' => 'umkholonjane oyindoda: ithoni yesikhumba esikhanyayo',
    '🧚🏼‍♂' => 'umkholonjane oyindoda: ithoni yesikhumba esikhanyayo phakathi',
    '🧚🏽‍♂' => 'umkholonjane oyindoda: ithoni yesikhumba esiphakathi',
    '🧚🏾‍♂' => 'umkholonjane oyindoda: ithoni yesikhumba esiphakathi mnyama',
    '🧚🏿‍♂' => 'umkholonjane oyindoda: ithoni yesikhumba emnyama',
    '🧚🏻‍♀' => 'umkholonjane olibhinqa: ithoni yesikhumba esikhanyayo',
    '🧚🏼‍♀' => 'umkholonjane olibhinqa: ithoni yesikhumba esikhanyayo phakathi',
    '🧚🏽‍♀' => 'umkholonjane olibhinqa: ithoni yesikhumba esiphakathi',
    '🧚🏾‍♀' => 'umkholonjane olibhinqa: ithoni yesikhumba esiphakathi mnyama',
    '🧚🏿‍♀' => 'umkholonjane olibhinqa: ithoni yesikhumba emnyama',
    '🧛🏻‍♂' => 'i-vampire eyindoda: ithoni yesikhumba esikhanyayo',
    '🧛🏼‍♂' => 'i-vampire eyindoda: ithoni yesikhumba esikhanyayo phakathi',
    '🧛🏽‍♂' => 'i-vampire eyindoda: ithoni yesikhumba esiphakathi',
    '🧛🏾‍♂' => 'i-vampire eyindoda: ithoni yesikhumba esiphakathi mnyama',
    '🧛🏿‍♂' => 'i-vampire eyindoda: ithoni yesikhumba emnyama',
    '🧛🏻‍♀' => 'i-vampire elibhinqa: ithoni yesikhumba esikhanyayo',
    '🧛🏼‍♀' => 'i-vampire elibhinqa: ithoni yesikhumba esikhanyayo phakathi',
    '🧛🏽‍♀' => 'i-vampire elibhinqa: ithoni yesikhumba esiphakathi',
    '🧛🏾‍♀' => 'i-vampire elibhinqa: ithoni yesikhumba esiphakathi mnyama',
    '🧛🏿‍♀' => 'i-vampire elibhinqa: ithoni yesikhumba emnyama',
    '🧜🏻‍♂' => 'i-merman: ithoni yesikhumba esikhanyayo',
    '🧜🏼‍♂' => 'i-merman: ithoni yesikhumba esikhanyayo phakathi',
    '🧜🏽‍♂' => 'i-merman: ithoni yesikhumba esiphakathi',
    '🧜🏾‍♂' => 'i-merman: ithoni yesikhumba esiphakathi mnyama',
    '🧜🏿‍♂' => 'i-merman: ithoni yesikhumba emnyama',
    '🧜🏻‍♀' => 'intombi-ntlanzi yasentsomini: ithoni yesikhumba esikhanyayo',
    '🧜🏼‍♀' => 'intombi-ntlanzi yasentsomini: ithoni yesikhumba esikhanyayo phakathi',
    '🧜🏽‍♀' => 'intombi-ntlanzi yasentsomini: ithoni yesikhumba esiphakathi',
    '🧜🏾‍♀' => 'intombi-ntlanzi yasentsomini: ithoni yesikhumba esiphakathi mnyama',
    '🧜🏿‍♀' => 'intombi-ntlanzi yasentsomini: ithoni yesikhumba emnyama',
    '🧝🏻‍♂' => 'uhili oyindoda: ithoni yesikhumba esikhanyayo',
    '🧝🏼‍♂' => 'uhili oyindoda: ithoni yesikhumba esikhanyayo phakathi',
    '🧝🏽‍♂' => 'uhili oyindoda: ithoni yesikhumba esiphakathi',
    '🧝🏾‍♂' => 'uhili oyindoda: ithoni yesikhumba esiphakathi mnyama',
    '🧝🏿‍♂' => 'uhili oyindoda: ithoni yesikhumba emnyama',
    '🧝🏻‍♀' => 'uhili olibhinqa: ithoni yesikhumba esikhanyayo',
    '🧝🏼‍♀' => 'uhili olibhinqa: ithoni yesikhumba esikhanyayo phakathi',
    '🧝🏽‍♀' => 'uhili olibhinqa: ithoni yesikhumba esiphakathi',
    '🧝🏾‍♀' => 'uhili olibhinqa: ithoni yesikhumba esiphakathi mnyama',
    '🧝🏿‍♀' => 'uhili olibhinqa: ithoni yesikhumba emnyama',
    '💆🏻‍♂' => 'indoda eliphululwayo: ithoni yesikhumba esikhanyayo',
    '💆🏼‍♂' => 'indoda eliphululwayo: ithoni yesikhumba esikhanyayo phakathi',
    '💆🏽‍♂' => 'indoda eliphululwayo: ithoni yesikhumba esiphakathi',
    '💆🏾‍♂' => 'indoda eliphululwayo: ithoni yesikhumba esiphakathi mnyama',
    '💆🏿‍♂' => 'indoda eliphululwayo: ithoni yesikhumba emnyama',
    '💆🏻‍♀' => 'ibhinqa eliphululwayo: ithoni yesikhumba esikhanyayo',
    '💆🏼‍♀' => 'ibhinqa eliphululwayo: ithoni yesikhumba esikhanyayo phakathi',
    '💆🏽‍♀' => 'ibhinqa eliphululwayo: ithoni yesikhumba esiphakathi',
    '💆🏾‍♀' => 'ibhinqa eliphululwayo: ithoni yesikhumba esiphakathi mnyama',
    '💆🏿‍♀' => 'ibhinqa eliphululwayo: ithoni yesikhumba emnyama',
    '💇🏻‍♂' => 'indoda echeba iinwele: ithoni yesikhumba esikhanyayo',
    '💇🏼‍♂' => 'indoda echeba iinwele: ithoni yesikhumba esikhanyayo phakathi',
    '💇🏽‍♂' => 'indoda echeba iinwele: ithoni yesikhumba esiphakathi',
    '💇🏾‍♂' => 'indoda echeba iinwele: ithoni yesikhumba esiphakathi mnyama',
    '💇🏿‍♂' => 'indoda echeba iinwele: ithoni yesikhumba emnyama',
    '💇🏻‍♀' => 'ibhinqa elicheba iinwele: ithoni yesikhumba esikhanyayo',
    '💇🏼‍♀' => 'ibhinqa elicheba iinwele: ithoni yesikhumba esikhanyayo phakathi',
    '💇🏽‍♀' => 'ibhinqa elicheba iinwele: ithoni yesikhumba esiphakathi',
    '💇🏾‍♀' => 'ibhinqa elicheba iinwele: ithoni yesikhumba esiphakathi mnyama',
    '💇🏿‍♀' => 'ibhinqa elicheba iinwele: ithoni yesikhumba emnyama',
    '🚶🏻‍♂' => 'indoda ehambayo: ithoni yesikhumba esikhanyayo',
    '🚶🏼‍♂' => 'indoda ehambayo: ithoni yesikhumba esikhanyayo phakathi',
    '🚶🏽‍♂' => 'indoda ehambayo: ithoni yesikhumba esiphakathi',
    '🚶🏾‍♂' => 'indoda ehambayo: ithoni yesikhumba esiphakathi mnyama',
    '🚶🏿‍♂' => 'indoda ehambayo: ithoni yesikhumba emnyama',
    '🚶🏻‍♀' => 'ibhinqa elihambayo: ithoni yesikhumba esikhanyayo',
    '🚶🏼‍♀' => 'ibhinqa elihambayo: ithoni yesikhumba esikhanyayo phakathi',
    '🚶🏽‍♀' => 'ibhinqa elihambayo: ithoni yesikhumba esiphakathi',
    '🚶🏾‍♀' => 'ibhinqa elihambayo: ithoni yesikhumba esiphakathi mnyama',
    '🚶🏿‍♀' => 'ibhinqa elihambayo: ithoni yesikhumba emnyama',
    '🏃🏻‍♂' => 'indoda ebalekayo: ithoni yesikhumba esikhanyayo',
    '🏃🏼‍♂' => 'indoda ebalekayo: ithoni yesikhumba esikhanyayo phakathi',
    '🏃🏽‍♂' => 'indoda ebalekayo: ithoni yesikhumba esiphakathi',
    '🏃🏾‍♂' => 'indoda ebalekayo: ithoni yesikhumba esiphakathi mnyama',
    '🏃🏿‍♂' => 'indoda ebalekayo: ithoni yesikhumba emnyama',
    '🏃🏻‍♀' => 'ibhinqa elibhalekayo: ithoni yesikhumba esikhanyayo',
    '🏃🏼‍♀' => 'ibhinqa elibhalekayo: ithoni yesikhumba esikhanyayo phakathi',
    '🏃🏽‍♀' => 'ibhinqa elibhalekayo: ithoni yesikhumba esiphakathi',
    '🏃🏾‍♀' => 'ibhinqa elibhalekayo: ithoni yesikhumba esiphakathi mnyama',
    '🏃🏿‍♀' => 'ibhinqa elibhalekayo: ithoni yesikhumba emnyama',
    '👯🏻‍♀' => 'ibhinqa elineendlebe zomvundla elikwitheko: ithoni yesikhumba esikhanyayo',
    '👯🏼‍♀' => 'ibhinqa elineendlebe zomvundla elikwitheko: ithoni yesikhumba esikhanyayo phakathi',
    '👯🏽‍♀' => 'ibhinqa elineendlebe zomvundla elikwitheko: ithoni yesikhumba esiphakathi',
    '👯🏾‍♀' => 'ibhinqa elineendlebe zomvundla elikwitheko: ithoni yesikhumba esiphakathi mnyama',
    '👯🏿‍♀' => 'ibhinqa elineendlebe zomvundla elikwitheko: ithoni yesikhumba emnyama',
    '👯🏻‍♂' => 'amadoda aneneendlebe zomvundla akwitheko: ithoni yesikhumba esikhanyayo',
    '👯🏼‍♂' => 'amadoda aneneendlebe zomvundla akwitheko: ithoni yesikhumba esikhanyayo phakathi',
    '👯🏽‍♂' => 'amadoda aneneendlebe zomvundla akwitheko: ithoni yesikhumba esiphakathi',
    '👯🏾‍♂' => 'amadoda aneneendlebe zomvundla akwitheko: ithoni yesikhumba esiphakathi mnyama',
    '👯🏿‍♂' => 'amadoda aneneendlebe zomvundla akwitheko: ithoni yesikhumba emnyama',
    '🧖🏻‍♂' => 'indoda ekwigumbi lomphunga: ithoni yesikhumba esikhanyayo',
    '🧖🏼‍♂' => 'indoda ekwigumbi lomphunga: ithoni yesikhumba esikhanyayo phakathi',
    '🧖🏽‍♂' => 'indoda ekwigumbi lomphunga: ithoni yesikhumba esiphakathi',
    '🧖🏾‍♂' => 'indoda ekwigumbi lomphunga: ithoni yesikhumba esiphakathi mnyama',
    '🧖🏿‍♂' => 'indoda ekwigumbi lomphunga: ithoni yesikhumba emnyama',
    '🧖🏻‍♀' => 'ibhinqa elikwigumbi lomphunga: ithoni yesikhumba esikhanyayo',
    '🧖🏼‍♀' => 'ibhinqa elikwigumbi lomphunga: ithoni yesikhumba esikhanyayo phakathi',
    '🧖🏽‍♀' => 'ibhinqa elikwigumbi lomphunga: ithoni yesikhumba esiphakathi',
    '🧖🏾‍♀' => 'ibhinqa elikwigumbi lomphunga: ithoni yesikhumba esiphakathi mnyama',
    '🧖🏿‍♀' => 'ibhinqa elikwigumbi lomphunga: ithoni yesikhumba emnyama',
    '🧗🏻‍♂' => 'indoda enyukayo: ithoni yesikhumba esikhanyayo',
    '🧗🏼‍♂' => 'indoda enyukayo: ithoni yesikhumba esikhanyayo phakathi',
    '🧗🏽‍♂' => 'indoda enyukayo: ithoni yesikhumba esiphakathi',
    '🧗🏾‍♂' => 'indoda enyukayo: ithoni yesikhumba esiphakathi mnyama',
    '🧗🏿‍♂' => 'indoda enyukayo: ithoni yesikhumba emnyama',
    '🧗🏻‍♀' => 'ibhinqa elinyukayo: ithoni yesikhumba esikhanyayo',
    '🧗🏼‍♀' => 'ibhinqa elinyukayo: ithoni yesikhumba esikhanyayo phakathi',
    '🧗🏽‍♀' => 'ibhinqa elinyukayo: ithoni yesikhumba esiphakathi',
    '🧗🏾‍♀' => 'ibhinqa elinyukayo: ithoni yesikhumba esiphakathi mnyama',
    '🧗🏿‍♀' => 'ibhinqa elinyukayo: ithoni yesikhumba emnyama',
    '🏌🏻‍♂' => 'indoda edlala igalufa: ithoni yesikhumba esikhanyayo',
    '🏌🏼‍♂' => 'indoda edlala igalufa: ithoni yesikhumba esikhanyayo phakathi',
    '🏌🏽‍♂' => 'indoda edlala igalufa: ithoni yesikhumba esiphakathi',
    '🏌🏾‍♂' => 'indoda edlala igalufa: ithoni yesikhumba esiphakathi mnyama',
    '🏌🏿‍♂' => 'indoda edlala igalufa: ithoni yesikhumba emnyama',
    '🏌🏻‍♀' => 'ibhinqa elidlala igalufa: ithoni yesikhumba esikhanyayo',
    '🏌🏼‍♀' => 'ibhinqa elidlala igalufa: ithoni yesikhumba esikhanyayo phakathi',
    '🏌🏽‍♀' => 'ibhinqa elidlala igalufa: ithoni yesikhumba esiphakathi',
    '🏌🏾‍♀' => 'ibhinqa elidlala igalufa: ithoni yesikhumba esiphakathi mnyama',
    '🏌🏿‍♀' => 'ibhinqa elidlala igalufa: ithoni yesikhumba emnyama',
    '🏄🏻‍♂' => 'indoda etyibiliza emanzini: ithoni yesikhumba esikhanyayo',
    '🏄🏼‍♂' => 'indoda etyibiliza emanzini: ithoni yesikhumba esikhanyayo phakathi',
    '🏄🏽‍♂' => 'indoda etyibiliza emanzini: ithoni yesikhumba esiphakathi',
    '🏄🏾‍♂' => 'indoda etyibiliza emanzini: ithoni yesikhumba esiphakathi mnyama',
    '🏄🏿‍♂' => 'indoda etyibiliza emanzini: ithoni yesikhumba emnyama',
    '🏄🏻‍♀' => 'ibhinqa elityibiliza emanzini: ithoni yesikhumba esikhanyayo',
    '🏄🏼‍♀' => 'ibhinqa elityibiliza emanzini: ithoni yesikhumba esikhanyayo phakathi',
    '🏄🏽‍♀' => 'ibhinqa elityibiliza emanzini: ithoni yesikhumba esiphakathi',
    '🏄🏾‍♀' => 'ibhinqa elityibiliza emanzini: ithoni yesikhumba esiphakathi mnyama',
    '🏄🏿‍♀' => 'ibhinqa elityibiliza emanzini: ithoni yesikhumba emnyama',
    '🚣🏻‍♂' => 'indoda ebheqa iphenyana: ithoni yesikhumba esikhanyayo',
    '🚣🏼‍♂' => 'indoda ebheqa iphenyana: ithoni yesikhumba esikhanyayo phakathi',
    '🚣🏽‍♂' => 'indoda ebheqa iphenyana: ithoni yesikhumba esiphakathi',
    '🚣🏾‍♂' => 'indoda ebheqa iphenyana: ithoni yesikhumba esiphakathi mnyama',
    '🚣🏿‍♂' => 'indoda ebheqa iphenyana: ithoni yesikhumba emnyama',
    '🚣🏻‍♀' => 'ibhinqa elibheqa iphenyana: ithoni yesikhumba esikhanyayo',
    '🚣🏼‍♀' => 'ibhinqa elibheqa iphenyana: ithoni yesikhumba esikhanyayo phakathi',
    '🚣🏽‍♀' => 'ibhinqa elibheqa iphenyana: ithoni yesikhumba esiphakathi',
    '🚣🏾‍♀' => 'ibhinqa elibheqa iphenyana: ithoni yesikhumba esiphakathi mnyama',
    '🚣🏿‍♀' => 'ibhinqa elibheqa iphenyana: ithoni yesikhumba emnyama',
    '🏊🏻‍♂' => 'indoda equbhayo: ithoni yesikhumba esikhanyayo',
    '🏊🏼‍♂' => 'indoda equbhayo: ithoni yesikhumba esikhanyayo phakathi',
    '🏊🏽‍♂' => 'indoda equbhayo: ithoni yesikhumba esiphakathi',
    '🏊🏾‍♂' => 'indoda equbhayo: ithoni yesikhumba esiphakathi mnyama',
    '🏊🏿‍♂' => 'indoda equbhayo: ithoni yesikhumba emnyama',
    '🏊🏻‍♀' => 'ibhinqa eliqubhayo: ithoni yesikhumba esikhanyayo',
    '🏊🏼‍♀' => 'ibhinqa eliqubhayo: ithoni yesikhumba esikhanyayo phakathi',
    '🏊🏽‍♀' => 'ibhinqa eliqubhayo: ithoni yesikhumba esiphakathi',
    '🏊🏾‍♀' => 'ibhinqa eliqubhayo: ithoni yesikhumba esiphakathi mnyama',
    '🏊🏿‍♀' => 'ibhinqa eliqubhayo: ithoni yesikhumba emnyama',
    '⛹🏻‍♂' => 'indoda egqampisa ibhola: ithoni yesikhumba esikhanyayo',
    '⛹🏼‍♂' => 'indoda egqampisa ibhola: ithoni yesikhumba esikhanyayo phakathi',
    '⛹🏽‍♂' => 'indoda egqampisa ibhola: ithoni yesikhumba esiphakathi',
    '⛹🏾‍♂' => 'indoda egqampisa ibhola: ithoni yesikhumba esiphakathi mnyama',
    '⛹🏿‍♂' => 'indoda egqampisa ibhola: ithoni yesikhumba emnyama',
    '⛹🏻‍♀' => 'ibhinqa eligqampisa ibhola: ithoni yesikhumba esikhanyayo',
    '⛹🏼‍♀' => 'ibhinqa eligqampisa ibhola: ithoni yesikhumba esikhanyayo phakathi',
    '⛹🏽‍♀' => 'ibhinqa eligqampisa ibhola: ithoni yesikhumba esiphakathi',
    '⛹🏾‍♀' => 'ibhinqa eligqampisa ibhola: ithoni yesikhumba esiphakathi mnyama',
    '⛹🏿‍♀' => 'ibhinqa eligqampisa ibhola: ithoni yesikhumba emnyama',
    '🏋🏻‍♂' => 'indoda ephakamisa iintsimbi: ithoni yesikhumba esikhanyayo',
    '🏋🏼‍♂' => 'indoda ephakamisa iintsimbi: ithoni yesikhumba esikhanyayo phakathi',
    '🏋🏽‍♂' => 'indoda ephakamisa iintsimbi: ithoni yesikhumba esiphakathi',
    '🏋🏾‍♂' => 'indoda ephakamisa iintsimbi: ithoni yesikhumba esiphakathi mnyama',
    '🏋🏿‍♂' => 'indoda ephakamisa iintsimbi: ithoni yesikhumba emnyama',
    '🏋🏻‍♀' => 'ibhinqa eliphakamisa iintsimbi: ithoni yesikhumba esikhanyayo',
    '🏋🏼‍♀' => 'ibhinqa eliphakamisa iintsimbi: ithoni yesikhumba esikhanyayo phakathi',
    '🏋🏽‍♀' => 'ibhinqa eliphakamisa iintsimbi: ithoni yesikhumba esiphakathi',
    '🏋🏾‍♀' => 'ibhinqa eliphakamisa iintsimbi: ithoni yesikhumba esiphakathi mnyama',
    '🏋🏿‍♀' => 'ibhinqa eliphakamisa iintsimbi: ithoni yesikhumba emnyama',
    '🚴🏻‍♂' => 'indoda eqhuba ibhayisekile: ithoni yesikhumba esikhanyayo',
    '🚴🏼‍♂' => 'indoda eqhuba ibhayisekile: ithoni yesikhumba esikhanyayo phakathi',
    '🚴🏽‍♂' => 'indoda eqhuba ibhayisekile: ithoni yesikhumba esiphakathi',
    '🚴🏾‍♂' => 'indoda eqhuba ibhayisekile: ithoni yesikhumba esiphakathi mnyama',
    '🚴🏿‍♂' => 'indoda eqhuba ibhayisekile: ithoni yesikhumba emnyama',
    '🚴🏻‍♀' => 'ibhinqa eliqhuba ibhayisekile: ithoni yesikhumba esikhanyayo',
    '🚴🏼‍♀' => 'ibhinqa eliqhuba ibhayisekile: ithoni yesikhumba esikhanyayo phakathi',
    '🚴🏽‍♀' => 'ibhinqa eliqhuba ibhayisekile: ithoni yesikhumba esiphakathi',
    '🚴🏾‍♀' => 'ibhinqa eliqhuba ibhayisekile: ithoni yesikhumba esiphakathi mnyama',
    '🚴🏿‍♀' => 'ibhinqa eliqhuba ibhayisekile: ithoni yesikhumba emnyama',
    '🚵🏻‍♂' => 'indoda eqhuba ibhayisekile entabeni: ithoni yesikhumba esikhanyayo',
    '🚵🏼‍♂' => 'indoda eqhuba ibhayisekile entabeni: ithoni yesikhumba esikhanyayo phakathi',
    '🚵🏽‍♂' => 'indoda eqhuba ibhayisekile entabeni: ithoni yesikhumba esiphakathi',
    '🚵🏾‍♂' => 'indoda eqhuba ibhayisekile entabeni: ithoni yesikhumba esiphakathi mnyama',
    '🚵🏿‍♂' => 'indoda eqhuba ibhayisekile entabeni: ithoni yesikhumba emnyama',
    '🚵🏻‍♀' => 'ibhinqa eliqhuba ibhayisekile entabeni: ithoni yesikhumba esikhanyayo',
    '🚵🏼‍♀' => 'ibhinqa eliqhuba ibhayisekile entabeni: ithoni yesikhumba esikhanyayo phakathi',
    '🚵🏽‍♀' => 'ibhinqa eliqhuba ibhayisekile entabeni: ithoni yesikhumba esiphakathi',
    '🚵🏾‍♀' => 'ibhinqa eliqhuba ibhayisekile entabeni: ithoni yesikhumba esiphakathi mnyama',
    '🚵🏿‍♀' => 'ibhinqa eliqhuba ibhayisekile entabeni: ithoni yesikhumba emnyama',
    '🤸🏻‍♂' => 'indoda eyenza uqilikibhode ngecala: ithoni yesikhumba esikhanyayo',
    '🤸🏼‍♂' => 'indoda eyenza uqilikibhode ngecala: ithoni yesikhumba esikhanyayo phakathi',
    '🤸🏽‍♂' => 'indoda eyenza uqilikibhode ngecala: ithoni yesikhumba esiphakathi',
    '🤸🏾‍♂' => 'indoda eyenza uqilikibhode ngecala: ithoni yesikhumba esiphakathi mnyama',
    '🤸🏿‍♂' => 'indoda eyenza uqilikibhode ngecala: ithoni yesikhumba emnyama',
    '🤸🏻‍♀' => 'ibhinqa elenza uqilikibhode ngecala: ithoni yesikhumba esikhanyayo',
    '🤸🏼‍♀' => 'ibhinqa elenza uqilikibhode ngecala: ithoni yesikhumba esikhanyayo phakathi',
    '🤸🏽‍♀' => 'ibhinqa elenza uqilikibhode ngecala: ithoni yesikhumba esiphakathi',
    '🤸🏾‍♀' => 'ibhinqa elenza uqilikibhode ngecala: ithoni yesikhumba esiphakathi mnyama',
    '🤸🏿‍♀' => 'ibhinqa elenza uqilikibhode ngecala: ithoni yesikhumba emnyama',
    '🤼🏻‍♀' => 'amabhinqa angqulanayo: ithoni yesikhumba esikhanyayo',
    '🤼🏼‍♀' => 'amabhinqa angqulanayo: ithoni yesikhumba esikhanyayo phakathi',
    '🤼🏽‍♀' => 'amabhinqa angqulanayo: ithoni yesikhumba esiphakathi',
    '🤼🏾‍♀' => 'amabhinqa angqulanayo: ithoni yesikhumba esiphakathi mnyama',
    '🤼🏿‍♀' => 'amabhinqa angqulanayo: ithoni yesikhumba emnyama',
    '🤼🏻‍♂' => 'amadoda angqulanayo: ithoni yesikhumba esikhanyayo',
    '🤼🏼‍♂' => 'amadoda angqulanayo: ithoni yesikhumba esikhanyayo phakathi',
    '🤼🏽‍♂' => 'amadoda angqulanayo: ithoni yesikhumba esiphakathi',
    '🤼🏾‍♂' => 'amadoda angqulanayo: ithoni yesikhumba esiphakathi mnyama',
    '🤼🏿‍♂' => 'amadoda angqulanayo: ithoni yesikhumba emnyama',
    '🤽🏻‍♂' => 'indoda edlala i-polo yasemanzini: ithoni yesikhumba esikhanyayo',
    '🤽🏼‍♂' => 'indoda edlala i-polo yasemanzini: ithoni yesikhumba esikhanyayo phakathi',
    '🤽🏽‍♂' => 'indoda edlala i-polo yasemanzini: ithoni yesikhumba esiphakathi',
    '🤽🏾‍♂' => 'indoda edlala i-polo yasemanzini: ithoni yesikhumba esiphakathi mnyama',
    '🤽🏿‍♂' => 'indoda edlala i-polo yasemanzini: ithoni yesikhumba emnyama',
    '🤽🏻‍♀' => 'ibhinqa elidlala i-polo yasemanzini: ithoni yesikhumba esikhanyayo',
    '🤽🏼‍♀' => 'ibhinqa elidlala i-polo yasemanzini: ithoni yesikhumba esikhanyayo phakathi',
    '🤽🏽‍♀' => 'ibhinqa elidlala i-polo yasemanzini: ithoni yesikhumba esiphakathi',
    '🤽🏾‍♀' => 'ibhinqa elidlala i-polo yasemanzini: ithoni yesikhumba esiphakathi mnyama',
    '🤽🏿‍♀' => 'ibhinqa elidlala i-polo yasemanzini: ithoni yesikhumba emnyama',
    '🤾🏻‍♂' => 'indoda edlala ibhola yesandla: ithoni yesikhumba esikhanyayo',
    '🤾🏼‍♂' => 'indoda edlala ibhola yesandla: ithoni yesikhumba esikhanyayo phakathi',
    '🤾🏽‍♂' => 'indoda edlala ibhola yesandla: ithoni yesikhumba esiphakathi',
    '🤾🏾‍♂' => 'indoda edlala ibhola yesandla: ithoni yesikhumba esiphakathi mnyama',
    '🤾🏿‍♂' => 'indoda edlala ibhola yesandla: ithoni yesikhumba emnyama',
    '🤾🏻‍♀' => 'ibhinqa elidlala ibhola yesandla: ithoni yesikhumba esikhanyayo',
    '🤾🏼‍♀' => 'ibhinqa elidlala ibhola yesandla: ithoni yesikhumba esikhanyayo phakathi',
    '🤾🏽‍♀' => 'ibhinqa elidlala ibhola yesandla: ithoni yesikhumba esiphakathi',
    '🤾🏾‍♀' => 'ibhinqa elidlala ibhola yesandla: ithoni yesikhumba esiphakathi mnyama',
    '🤾🏿‍♀' => 'ibhinqa elidlala ibhola yesandla: ithoni yesikhumba emnyama',
    '🤹🏻‍♂' => 'indoda eqhathayo: ithoni yesikhumba esikhanyayo',
    '🤹🏼‍♂' => 'indoda eqhathayo: ithoni yesikhumba esikhanyayo phakathi',
    '🤹🏽‍♂' => 'indoda eqhathayo: ithoni yesikhumba esiphakathi',
    '🤹🏾‍♂' => 'indoda eqhathayo: ithoni yesikhumba esiphakathi mnyama',
    '🤹🏿‍♂' => 'indoda eqhathayo: ithoni yesikhumba emnyama',
    '🤹🏻‍♀' => 'ibhinqa eliqhathayo: ithoni yesikhumba esikhanyayo',
    '🤹🏼‍♀' => 'ibhinqa eliqhathayo: ithoni yesikhumba esikhanyayo phakathi',
    '🤹🏽‍♀' => 'ibhinqa eliqhathayo: ithoni yesikhumba esiphakathi',
    '🤹🏾‍♀' => 'ibhinqa eliqhathayo: ithoni yesikhumba esiphakathi mnyama',
    '🤹🏿‍♀' => 'ibhinqa eliqhathayo: ithoni yesikhumba emnyama',
    '🧘🏻‍♂' => 'indoda ekwimo ye-lotus: ithoni yesikhumba esikhanyayo',
    '🧘🏼‍♂' => 'indoda ekwimo ye-lotus: ithoni yesikhumba esikhanyayo phakathi',
    '🧘🏽‍♂' => 'indoda ekwimo ye-lotus: ithoni yesikhumba esiphakathi',
    '🧘🏾‍♂' => 'indoda ekwimo ye-lotus: ithoni yesikhumba esiphakathi mnyama',
    '🧘🏿‍♂' => 'indoda ekwimo ye-lotus: ithoni yesikhumba emnyama',
    '🧘🏻‍♀' => 'ibhinqa elikwimo ye-lotus: ithoni yesikhumba esikhanyayo',
    '🧘🏼‍♀' => 'ibhinqa elikwimo ye-lotus: ithoni yesikhumba esikhanyayo phakathi',
    '🧘🏽‍♀' => 'ibhinqa elikwimo ye-lotus: ithoni yesikhumba esiphakathi',
    '🧘🏾‍♀' => 'ibhinqa elikwimo ye-lotus: ithoni yesikhumba esiphakathi mnyama',
    '🧘🏿‍♀' => 'ibhinqa elikwimo ye-lotus: ithoni yesikhumba emnyama',
    '👨‍👦' => 'usapho: indoda, inkwenkwe',
    '👨‍👧' => 'usapho: indoda, intombazana',
    '👩‍👦' => 'usapho: ibhinqa, inkwenkwe',
    '👩‍👧' => 'usapho: ibhinqa, intombazana',
    '👁‍🗨' => 'iliso elikwiqhamza lentetho',
    '👱‍♂' => 'indoda eneenwele ezimhlophe',
    '👱‍♀' => 'ibhinqa elineenwele ezimhlophe',
    '🙍‍♂' => 'indoda efinge iintshiya',
    '🙍‍♀' => 'ibhinqa elifinge iintshiya',
    '🙎‍♂' => 'indoda etsolisa umlomo',
    '🙎‍♀' => 'ibhinqa elitsolisa umlomo',
    '🙅‍♂' => 'indoda elijekulayo ukuthi HAYI',
    '🙅‍♀' => 'ibhinqa elijekulayo ukuthi HAYI',
    '🙆‍♂' => 'indoda ejekula ukuthi Kulungile',
    '🙆‍♀' => 'ibhinqa elijekula ukuthi Kulungile',
    '💁‍♂' => 'indoda ephethula isandla',
    '💁‍♀' => 'ibhinqa eluphethula isandla',
    '🙋‍♂' => 'indoda ephakamisa isandla',
    '🙋‍♀' => 'ibhinqa eliphakamisa isandla',
    '🙇‍♂' => 'indoda egobayo',
    '🙇‍♀' => 'ibhinqa eligobayo',
    '🤦‍♂' => 'indoda egqume ubuso ngezandla',
    '🤦‍♀' => 'ibhinqa eligqume ubuso ngezandla',
    '🤷‍♂' => 'indoda enyikinya amagxa',
    '🤷‍♀' => 'ibhinqa elinyikinya amagxa',
    '👨‍⚕' => 'umsebenzi wezonyango oyindoda',
    '👩‍⚕' => 'umsebenzi wempilo olibhinqa',
    '👨‍🎓' => 'umfundi oyindoda',
    '👩‍🎓' => 'umfundi olibhinqa',
    '👨‍🏫' => 'utitshala oyindoda',
    '👩‍🏫' => 'utitshala olibhinqa',
    '👨‍⚖' => 'umgwebi oyindoda',
    '👩‍⚖' => 'umgwebi olibhinqa',
    '👨‍🌾' => 'umfama oyindoda',
    '👩‍🌾' => 'umfama olibhinqa',
    '👨‍🍳' => 'umpheki oyindoda',
    '👩‍🍳' => 'umpheki olibhinqa',
    '👨‍🔧' => 'umkhandi oyindoda',
    '👩‍🔧' => 'umkhandi olibhinqa',
    '👨‍🏭' => 'umsebenzi wasefektri oyindoda',
    '👩‍🏭' => 'umsebenzi wasefektri olibhinqa',
    '👨‍💼' => 'umsebenzi waseofisini oyindoda',
    '👩‍💼' => 'umsebenzi waseofisini olibhinqa',
    '👨‍🔬' => 'isazinzulu esiyindoda',
    '👩‍🔬' => 'isazinzulu esilibhinqa',
    '👨‍💻' => 'ingcali eyindoda',
    '👩‍💻' => 'ingcali elilibhinqa',
    '👨‍🎤' => 'umculi oyindoda',
    '👩‍🎤' => 'umculi olibhinqa',
    '👨‍🎨' => 'iathisti eyindoda',
    '👩‍🎨' => 'igcisa elilibhinqa',
    '👨‍✈' => 'umqhubi wenqwelo-moya oyindoda',
    '👩‍✈' => 'umqhubi wenqwelo-moya olibhinqa',
    '👨‍🚀' => 'usomajukujuku oyindoda',
    '👩‍🚀' => 'usomajukujuku olubhinqa',
    '👨‍🚒' => 'umcimi-mlilo oyindoda',
    '👩‍🚒' => 'umcimi-mlilo olibhinqa',
    '👮‍♂' => 'igosa lepolisa eliyindoda',
    '👮‍♀' => 'igosa lepolisa elilibhinqa',
    '🕵‍♂' => 'umcuphi oyindoda',
    '🕵‍♀' => 'umcuphi olibhinqa',
    '💂‍♂' => 'unogada oyindoda',
    '💂‍♀' => 'unogada olibhinqa',
    '👷‍♂' => 'umsebenzi wolwakhiwo oyindoda',
    '👷‍♀' => 'umsebenzi wolwakhiwo olibhinqa',
    '👳‍♂' => 'indoda ethwele unkontsho',
    '👳‍♀' => 'ibhinqa elithwele unkontsho',
    '🧙‍♂' => 'i-mage eyindoda',
    '🧙‍♀' => 'i-mage elibhinqa',
    '🧚‍♂' => 'umkholonjane oyindoda',
    '🧚‍♀' => 'umkholonjane olibhinqa',
    '🧛‍♂' => 'i-vampire eyindoda',
    '🧛‍♀' => 'i-vampire elibhinqa',
    '🧜‍♂' => 'i-merman',
    '🧜‍♀' => 'intombi-ntlanzi yasentsomini',
    '🧝‍♂' => 'uhili oyindoda',
    '🧝‍♀' => 'uhili olibhinqa',
    '🧞‍♂' => 'indoda ye-genie',
    '🧞‍♀' => 'ibhinqa le-genie',
    '🧟‍♂' => 'isithunzela esiyindoda',
    '🧟‍♀' => 'isithunzela esilibhinqa',
    '💆‍♂' => 'indoda eliphululwayo',
    '💆‍♀' => 'ibhinqa eliphululwayo',
    '💇‍♂' => 'indoda echeba iinwele',
    '💇‍♀' => 'ibhinqa elicheba iinwele',
    '🚶‍♂' => 'indoda ehambayo',
    '🚶‍♀' => 'ibhinqa elihambayo',
    '🏃‍♂' => 'indoda ebalekayo',
    '🏃‍♀' => 'ibhinqa elibhalekayo',
    '👯‍♂' => 'amadoda aneneendlebe zomvundla akwitheko',
    '👯‍♀' => 'ibhinqa elineendlebe zomvundla elikwitheko',
    '🧖‍♂' => 'indoda ekwigumbi lomphunga',
    '🧖‍♀' => 'ibhinqa elikwigumbi lomphunga',
    '🧗‍♂' => 'indoda enyukayo',
    '🧗‍♀' => 'ibhinqa elinyukayo',
    '🏌‍♂' => 'indoda edlala igalufa',
    '🏌‍♀' => 'ibhinqa elidlala igalufa',
    '🏄‍♂' => 'indoda etyibiliza emanzini',
    '🏄‍♀' => 'ibhinqa elityibiliza emanzini',
    '🚣‍♂' => 'indoda ebheqa iphenyana',
    '🚣‍♀' => 'ibhinqa elibheqa iphenyana',
    '🏊‍♂' => 'indoda equbhayo',
    '🏊‍♀' => 'ibhinqa eliqubhayo',
    '⛹‍♂' => 'indoda egqampisa ibhola',
    '⛹‍♀' => 'ibhinqa eligqampisa ibhola',
    '🏋‍♂' => 'indoda ephakamisa iintsimbi',
    '🏋‍♀' => 'ibhinqa eliphakamisa iintsimbi',
    '🚴‍♂' => 'indoda eqhuba ibhayisekile',
    '🚴‍♀' => 'ibhinqa eliqhuba ibhayisekile',
    '🚵‍♂' => 'indoda eqhuba ibhayisekile entabeni',
    '🚵‍♀' => 'ibhinqa eliqhuba ibhayisekile entabeni',
    '🤸‍♂' => 'indoda eyenza uqilikibhode ngecala',
    '🤸‍♀' => 'ibhinqa elenza uqilikibhode ngecala',
    '🤼‍♂' => 'amadoda angqulanayo',
    '🤼‍♀' => 'amabhinqa angqulanayo',
    '🤽‍♂' => 'indoda edlala i-polo yasemanzini',
    '🤽‍♀' => 'ibhinqa elidlala i-polo yasemanzini',
    '🤾‍♂' => 'indoda edlala ibhola yesandla',
    '🤾‍♀' => 'ibhinqa elidlala ibhola yesandla',
    '🤹‍♂' => 'indoda eqhathayo',
    '🤹‍♀' => 'ibhinqa eliqhathayo',
    '🧘‍♂' => 'indoda ekwimo ye-lotus',
    '🧘‍♀' => 'ibhinqa elikwimo ye-lotus',
    '🏳‍🌈' => 'iflegi yomnyama',
    '👋🏻' => 'ukuwangawangisa isandla: ithoni yesikhumba esikhanyayo',
    '👋🏼' => 'ukuwangawangisa isandla: ithoni yesikhumba esikhanyayo phakathi',
    '👋🏽' => 'ukuwangawangisa isandla: ithoni yesikhumba esiphakathi',
    '👋🏾' => 'ukuwangawangisa isandla: ithoni yesikhumba esiphakathi mnyama',
    '👋🏿' => 'ukuwangawangisa isandla: ithoni yesikhumba emnyama',
    '🤚🏻' => 'umva wesandla onyusiweyo: ithoni yesikhumba esikhanyayo',
    '🤚🏼' => 'umva wesandla onyusiweyo: ithoni yesikhumba esikhanyayo phakathi',
    '🤚🏽' => 'umva wesandla onyusiweyo: ithoni yesikhumba esiphakathi',
    '🤚🏾' => 'umva wesandla onyusiweyo: ithoni yesikhumba esiphakathi mnyama',
    '🤚🏿' => 'umva wesandla onyusiweyo: ithoni yesikhumba emnyama',
    '🖐🏻' => 'isandla esiphakanyisiweyo esineminwe ethe saa: ithoni yesikhumba esikhanyayo',
    '🖐🏼' => 'isandla esiphakanyisiweyo esineminwe ethe saa: ithoni yesikhumba esikhanyayo phakathi',
    '🖐🏽' => 'isandla esiphakanyisiweyo esineminwe ethe saa: ithoni yesikhumba esiphakathi',
    '🖐🏾' => 'isandla esiphakanyisiweyo esineminwe ethe saa: ithoni yesikhumba esiphakathi mnyama',
    '🖐🏿' => 'isandla esiphakanyisiweyo esineminwe ethe saa: ithoni yesikhumba emnyama',
    '✋🏻' => 'isandla esinyusiweyo: ithoni yesikhumba esikhanyayo',
    '✋🏼' => 'isandla esinyusiweyo: ithoni yesikhumba esikhanyayo phakathi',
    '✋🏽' => 'isandla esinyusiweyo: ithoni yesikhumba esiphakathi',
    '✋🏾' => 'isandla esinyusiweyo: ithoni yesikhumba esiphakathi mnyama',
    '✋🏿' => 'isandla esinyusiweyo: ithoni yesikhumba emnyama',
    '🖖🏻' => 'umbuliso we-vulcan: ithoni yesikhumba esikhanyayo',
    '🖖🏼' => 'umbuliso we-vulcan: ithoni yesikhumba esikhanyayo phakathi',
    '🖖🏽' => 'umbuliso we-vulcan: ithoni yesikhumba esiphakathi',
    '🖖🏾' => 'umbuliso we-vulcan: ithoni yesikhumba esiphakathi mnyama',
    '🖖🏿' => 'umbuliso we-vulcan: ithoni yesikhumba emnyama',
    '👌🏻' => 'isandla esithi Kulungile: ithoni yesikhumba esikhanyayo',
    '👌🏼' => 'isandla esithi Kulungile: ithoni yesikhumba esikhanyayo phakathi',
    '👌🏽' => 'isandla esithi Kulungile: ithoni yesikhumba esiphakathi',
    '👌🏾' => 'isandla esithi Kulungile: ithoni yesikhumba esiphakathi mnyama',
    '👌🏿' => 'isandla esithi Kulungile: ithoni yesikhumba emnyama',
    '✌🏻' => 'isandla sempumelelo: ithoni yesikhumba esikhanyayo',
    '✌🏼' => 'isandla sempumelelo: ithoni yesikhumba esikhanyayo phakathi',
    '✌🏽' => 'isandla sempumelelo: ithoni yesikhumba esiphakathi',
    '✌🏾' => 'isandla sempumelelo: ithoni yesikhumba esiphakathi mnyama',
    '✌🏿' => 'isandla sempumelelo: ithoni yesikhumba emnyama',
    '🤞🏻' => 'iminwe enqamlezeneyo: ithoni yesikhumba esikhanyayo',
    '🤞🏼' => 'iminwe enqamlezeneyo: ithoni yesikhumba esikhanyayo phakathi',
    '🤞🏽' => 'iminwe enqamlezeneyo: ithoni yesikhumba esiphakathi',
    '🤞🏾' => 'iminwe enqamlezeneyo: ithoni yesikhumba esiphakathi mnyama',
    '🤞🏿' => 'iminwe enqamlezeneyo: ithoni yesikhumba emnyama',
    '🤟🏻' => 'umjekulo othi ndiyakuthanda: ithoni yesikhumba esikhanyayo',
    '🤟🏼' => 'umjekulo othi ndiyakuthanda: ithoni yesikhumba esikhanyayo phakathi',
    '🤟🏽' => 'umjekulo othi ndiyakuthanda: ithoni yesikhumba esiphakathi',
    '🤟🏾' => 'umjekulo othi ndiyakuthanda: ithoni yesikhumba esiphakathi mnyama',
    '🤟🏿' => 'umjekulo othi ndiyakuthanda: ithoni yesikhumba emnyama',
    '🤘🏻' => 'uphawu lweempondo: ithoni yesikhumba esikhanyayo',
    '🤘🏼' => 'uphawu lweempondo: ithoni yesikhumba esikhanyayo phakathi',
    '🤘🏽' => 'uphawu lweempondo: ithoni yesikhumba esiphakathi',
    '🤘🏾' => 'uphawu lweempondo: ithoni yesikhumba esiphakathi mnyama',
    '🤘🏿' => 'uphawu lweempondo: ithoni yesikhumba emnyama',
    '🤙🏻' => 'isandla esithi ndifowunele: ithoni yesikhumba esikhanyayo',
    '🤙🏼' => 'isandla esithi ndifowunele: ithoni yesikhumba esikhanyayo phakathi',
    '🤙🏽' => 'isandla esithi ndifowunele: ithoni yesikhumba esiphakathi',
    '🤙🏾' => 'isandla esithi ndifowunele: ithoni yesikhumba esiphakathi mnyama',
    '🤙🏿' => 'isandla esithi ndifowunele: ithoni yesikhumba emnyama',
    '👈🏻' => 'isalathiso somva wesandla esalatha ekhohlo: ithoni yesikhumba esikhanyayo',
    '👈🏼' => 'isalathiso somva wesandla esalatha ekhohlo: ithoni yesikhumba esikhanyayo phakathi',
    '👈🏽' => 'isalathiso somva wesandla esalatha ekhohlo: ithoni yesikhumba esiphakathi',
    '👈🏾' => 'isalathiso somva wesandla esalatha ekhohlo: ithoni yesikhumba esiphakathi mnyama',
    '👈🏿' => 'isalathiso somva wesandla esalatha ekhohlo: ithoni yesikhumba emnyama',
    '👉🏻' => 'isalathiso somva wesandla esalatha ekunene: ithoni yesikhumba esikhanyayo',
    '👉🏼' => 'isalathiso somva wesandla esalatha ekunene: ithoni yesikhumba esikhanyayo phakathi',
    '👉🏽' => 'isalathiso somva wesandla esalatha ekunene: ithoni yesikhumba esiphakathi',
    '👉🏾' => 'isalathiso somva wesandla esalatha ekunene: ithoni yesikhumba esiphakathi mnyama',
    '👉🏿' => 'isalathiso somva wesandla esalatha ekunene: ithoni yesikhumba emnyama',
    '👆🏻' => 'isalathiso somva wesandla esalatha phezulu: ithoni yesikhumba esikhanyayo',
    '👆🏼' => 'isalathiso somva wesandla esalatha phezulu: ithoni yesikhumba esikhanyayo phakathi',
    '👆🏽' => 'isalathiso somva wesandla esalatha phezulu: ithoni yesikhumba esiphakathi',
    '👆🏾' => 'isalathiso somva wesandla esalatha phezulu: ithoni yesikhumba esiphakathi mnyama',
    '👆🏿' => 'isalathiso somva wesandla esalatha phezulu: ithoni yesikhumba emnyama',
    '🖕🏻' => 'umnwe ophakathi: ithoni yesikhumba esikhanyayo',
    '🖕🏼' => 'umnwe ophakathi: ithoni yesikhumba esikhanyayo phakathi',
    '🖕🏽' => 'umnwe ophakathi: ithoni yesikhumba esiphakathi',
    '🖕🏾' => 'umnwe ophakathi: ithoni yesikhumba esiphakathi mnyama',
    '🖕🏿' => 'umnwe ophakathi: ithoni yesikhumba emnyama',
    '👇🏻' => 'isalathiso somva wesandla esalatha ezantsi: ithoni yesikhumba esikhanyayo',
    '👇🏼' => 'isalathiso somva wesandla esalatha ezantsi: ithoni yesikhumba esikhanyayo phakathi',
    '👇🏽' => 'isalathiso somva wesandla esalatha ezantsi: ithoni yesikhumba esiphakathi',
    '👇🏾' => 'isalathiso somva wesandla esalatha ezantsi: ithoni yesikhumba esiphakathi mnyama',
    '👇🏿' => 'isalathiso somva wesandla esalatha ezantsi: ithoni yesikhumba emnyama',
    '☝🏻' => 'isalathiso esalatha phezulu: ithoni yesikhumba esikhanyayo',
    '☝🏼' => 'isalathiso esalatha phezulu: ithoni yesikhumba esikhanyayo phakathi',
    '☝🏽' => 'isalathiso esalatha phezulu: ithoni yesikhumba esiphakathi',
    '☝🏾' => 'isalathiso esalatha phezulu: ithoni yesikhumba esiphakathi mnyama',
    '☝🏿' => 'isalathiso esalatha phezulu: ithoni yesikhumba emnyama',
    '👍🏻' => 'ubhontsi ojonge phezulu: ithoni yesikhumba esikhanyayo',
    '👍🏼' => 'ubhontsi ojonge phezulu: ithoni yesikhumba esikhanyayo phakathi',
    '👍🏽' => 'ubhontsi ojonge phezulu: ithoni yesikhumba esiphakathi',
    '👍🏾' => 'ubhontsi ojonge phezulu: ithoni yesikhumba esiphakathi mnyama',
    '👍🏿' => 'ubhontsi ojonge phezulu: ithoni yesikhumba emnyama',
    '👎🏻' => 'ubhontsi ojonge ezantsi: ithoni yesikhumba esikhanyayo',
    '👎🏼' => 'ubhontsi ojonge ezantsi: ithoni yesikhumba esikhanyayo phakathi',
    '👎🏽' => 'ubhontsi ojonge ezantsi: ithoni yesikhumba esiphakathi',
    '👎🏾' => 'ubhontsi ojonge ezantsi: ithoni yesikhumba esiphakathi mnyama',
    '👎🏿' => 'ubhontsi ojonge ezantsi: ithoni yesikhumba emnyama',
    '✊🏻' => 'inqindi elinyusiweyo: ithoni yesikhumba esikhanyayo',
    '✊🏼' => 'inqindi elinyusiweyo: ithoni yesikhumba esikhanyayo phakathi',
    '✊🏽' => 'inqindi elinyusiweyo: ithoni yesikhumba esiphakathi',
    '✊🏾' => 'inqindi elinyusiweyo: ithoni yesikhumba esiphakathi mnyama',
    '✊🏿' => 'inqindi elinyusiweyo: ithoni yesikhumba emnyama',
    '👊🏻' => 'inqindi elizayo: ithoni yesikhumba esikhanyayo',
    '👊🏼' => 'inqindi elizayo: ithoni yesikhumba esikhanyayo phakathi',
    '👊🏽' => 'inqindi elizayo: ithoni yesikhumba esiphakathi',
    '👊🏾' => 'inqindi elizayo: ithoni yesikhumba esiphakathi mnyama',
    '👊🏿' => 'inqindi elizayo: ithoni yesikhumba emnyama',
    '🤛🏻' => 'inqindi elijonge ekhohlo: ithoni yesikhumba esikhanyayo',
    '🤛🏼' => 'inqindi elijonge ekhohlo: ithoni yesikhumba esikhanyayo phakathi',
    '🤛🏽' => 'inqindi elijonge ekhohlo: ithoni yesikhumba esiphakathi',
    '🤛🏾' => 'inqindi elijonge ekhohlo: ithoni yesikhumba esiphakathi mnyama',
    '🤛🏿' => 'inqindi elijonge ekhohlo: ithoni yesikhumba emnyama',
    '🤜🏻' => 'inqindi elijonge ekunene: ithoni yesikhumba esikhanyayo',
    '🤜🏼' => 'inqindi elijonge ekunene: ithoni yesikhumba esikhanyayo phakathi',
    '🤜🏽' => 'inqindi elijonge ekunene: ithoni yesikhumba esiphakathi',
    '🤜🏾' => 'inqindi elijonge ekunene: ithoni yesikhumba esiphakathi mnyama',
    '🤜🏿' => 'inqindi elijonge ekunene: ithoni yesikhumba emnyama',
    '👏🏻' => 'izandla eziqhwabayo: ithoni yesikhumba esikhanyayo',
    '👏🏼' => 'izandla eziqhwabayo: ithoni yesikhumba esikhanyayo phakathi',
    '👏🏽' => 'izandla eziqhwabayo: ithoni yesikhumba esiphakathi',
    '👏🏾' => 'izandla eziqhwabayo: ithoni yesikhumba esiphakathi mnyama',
    '👏🏿' => 'izandla eziqhwabayo: ithoni yesikhumba emnyama',
    '🙌🏻' => 'ukunyusa izandla: ithoni yesikhumba esikhanyayo',
    '🙌🏼' => 'ukunyusa izandla: ithoni yesikhumba esikhanyayo phakathi',
    '🙌🏽' => 'ukunyusa izandla: ithoni yesikhumba esiphakathi',
    '🙌🏾' => 'ukunyusa izandla: ithoni yesikhumba esiphakathi mnyama',
    '🙌🏿' => 'ukunyusa izandla: ithoni yesikhumba emnyama',
    '👐🏻' => 'izandla ezivulekileyo: ithoni yesikhumba esikhanyayo',
    '👐🏼' => 'izandla ezivulekileyo: ithoni yesikhumba esikhanyayo phakathi',
    '👐🏽' => 'izandla ezivulekileyo: ithoni yesikhumba esiphakathi',
    '👐🏾' => 'izandla ezivulekileyo: ithoni yesikhumba esiphakathi mnyama',
    '👐🏿' => 'izandla ezivulekileyo: ithoni yesikhumba emnyama',
    '🤲🏻' => 'iintende zesandla ezikunye: ithoni yesikhumba esikhanyayo',
    '🤲🏼' => 'iintende zesandla ezikunye: ithoni yesikhumba esikhanyayo phakathi',
    '🤲🏽' => 'iintende zesandla ezikunye: ithoni yesikhumba esiphakathi',
    '🤲🏾' => 'iintende zesandla ezikunye: ithoni yesikhumba esiphakathi mnyama',
    '🤲🏿' => 'iintende zesandla ezikunye: ithoni yesikhumba emnyama',
    '🤝🏻' => 'ukubamba isandla: ithoni yesikhumba esikhanyayo',
    '🤝🏼' => 'ukubamba isandla: ithoni yesikhumba esikhanyayo phakathi',
    '🤝🏽' => 'ukubamba isandla: ithoni yesikhumba esiphakathi',
    '🤝🏾' => 'ukubamba isandla: ithoni yesikhumba esiphakathi mnyama',
    '🤝🏿' => 'ukubamba isandla: ithoni yesikhumba emnyama',
    '🙏🏻' => 'izandla ezisongiweyo: ithoni yesikhumba esikhanyayo',
    '🙏🏼' => 'izandla ezisongiweyo: ithoni yesikhumba esikhanyayo phakathi',
    '🙏🏽' => 'izandla ezisongiweyo: ithoni yesikhumba esiphakathi',
    '🙏🏾' => 'izandla ezisongiweyo: ithoni yesikhumba esiphakathi mnyama',
    '🙏🏿' => 'izandla ezisongiweyo: ithoni yesikhumba emnyama',
    '✍🏻' => 'isandla esibhalayo: ithoni yesikhumba esikhanyayo',
    '✍🏼' => 'isandla esibhalayo: ithoni yesikhumba esikhanyayo phakathi',
    '✍🏽' => 'isandla esibhalayo: ithoni yesikhumba esiphakathi',
    '✍🏾' => 'isandla esibhalayo: ithoni yesikhumba esiphakathi mnyama',
    '✍🏿' => 'isandla esibhalayo: ithoni yesikhumba emnyama',
    '💅🏻' => 'ipolishi yeenzipho: ithoni yesikhumba esikhanyayo',
    '💅🏼' => 'ipolishi yeenzipho: ithoni yesikhumba esikhanyayo phakathi',
    '💅🏽' => 'ipolishi yeenzipho: ithoni yesikhumba esiphakathi',
    '💅🏾' => 'ipolishi yeenzipho: ithoni yesikhumba esiphakathi mnyama',
    '💅🏿' => 'ipolishi yeenzipho: ithoni yesikhumba emnyama',
    '🤳🏻' => 'iselfi: ithoni yesikhumba esikhanyayo',
    '🤳🏼' => 'iselfi: ithoni yesikhumba esikhanyayo phakathi',
    '🤳🏽' => 'iselfi: ithoni yesikhumba esiphakathi',
    '🤳🏾' => 'iselfi: ithoni yesikhumba esiphakathi mnyama',
    '🤳🏿' => 'iselfi: ithoni yesikhumba emnyama',
    '💪🏻' => 'amankonyana agotyiweyo: ithoni yesikhumba esikhanyayo',
    '💪🏼' => 'amankonyana agotyiweyo: ithoni yesikhumba esikhanyayo phakathi',
    '💪🏽' => 'amankonyana agotyiweyo: ithoni yesikhumba esiphakathi',
    '💪🏾' => 'amankonyana agotyiweyo: ithoni yesikhumba esiphakathi mnyama',
    '💪🏿' => 'amankonyana agotyiweyo: ithoni yesikhumba emnyama',
    '👂🏻' => 'indlebe: ithoni yesikhumba esikhanyayo',
    '👂🏼' => 'indlebe: ithoni yesikhumba esikhanyayo phakathi',
    '👂🏽' => 'indlebe: ithoni yesikhumba esiphakathi',
    '👂🏾' => 'indlebe: ithoni yesikhumba esiphakathi mnyama',
    '👂🏿' => 'indlebe: ithoni yesikhumba emnyama',
    '👃🏻' => 'impumlo: ithoni yesikhumba esikhanyayo',
    '👃🏼' => 'impumlo: ithoni yesikhumba esikhanyayo phakathi',
    '👃🏽' => 'impumlo: ithoni yesikhumba esiphakathi',
    '👃🏾' => 'impumlo: ithoni yesikhumba esiphakathi mnyama',
    '👃🏿' => 'impumlo: ithoni yesikhumba emnyama',
    '👶🏻' => 'usana: ithoni yesikhumba esikhanyayo',
    '👶🏼' => 'usana: ithoni yesikhumba esikhanyayo phakathi',
    '👶🏽' => 'usana: ithoni yesikhumba esiphakathi',
    '👶🏾' => 'usana: ithoni yesikhumba esiphakathi mnyama',
    '👶🏿' => 'usana: ithoni yesikhumba emnyama',
    '🧒🏻' => 'umntwana: ithoni yesikhumba esikhanyayo',
    '🧒🏼' => 'umntwana: ithoni yesikhumba esikhanyayo phakathi',
    '🧒🏽' => 'umntwana: ithoni yesikhumba esiphakathi',
    '🧒🏾' => 'umntwana: ithoni yesikhumba esiphakathi mnyama',
    '🧒🏿' => 'umntwana: ithoni yesikhumba emnyama',
    '👦🏻' => 'inkwenkwe: ithoni yesikhumba esikhanyayo',
    '👦🏼' => 'inkwenkwe: ithoni yesikhumba esikhanyayo phakathi',
    '👦🏽' => 'inkwenkwe: ithoni yesikhumba esiphakathi',
    '👦🏾' => 'inkwenkwe: ithoni yesikhumba esiphakathi mnyama',
    '👦🏿' => 'inkwenkwe: ithoni yesikhumba emnyama',
    '👧🏻' => 'intombazana: ithoni yesikhumba esikhanyayo',
    '👧🏼' => 'intombazana: ithoni yesikhumba esikhanyayo phakathi',
    '👧🏽' => 'intombazana: ithoni yesikhumba esiphakathi',
    '👧🏾' => 'intombazana: ithoni yesikhumba esiphakathi mnyama',
    '👧🏿' => 'intombazana: ithoni yesikhumba emnyama',
    '🧑🏻' => 'umntu omdala: ithoni yesikhumba esikhanyayo',
    '🧑🏼' => 'umntu omdala: ithoni yesikhumba esikhanyayo phakathi',
    '🧑🏽' => 'umntu omdala: ithoni yesikhumba esiphakathi',
    '🧑🏾' => 'umntu omdala: ithoni yesikhumba esiphakathi mnyama',
    '🧑🏿' => 'umntu omdala: ithoni yesikhumba emnyama',
    '👱🏻' => 'umntu oneenwele ezimhlophe: ithoni yesikhumba esikhanyayo',
    '👱🏼' => 'umntu oneenwele ezimhlophe: ithoni yesikhumba esikhanyayo phakathi',
    '👱🏽' => 'umntu oneenwele ezimhlophe: ithoni yesikhumba esiphakathi',
    '👱🏾' => 'umntu oneenwele ezimhlophe: ithoni yesikhumba esiphakathi mnyama',
    '👱🏿' => 'umntu oneenwele ezimhlophe: ithoni yesikhumba emnyama',
    '👨🏻' => 'indoda: ithoni yesikhumba esikhanyayo',
    '👨🏼' => 'indoda: ithoni yesikhumba esikhanyayo phakathi',
    '👨🏽' => 'indoda: ithoni yesikhumba esiphakathi',
    '👨🏾' => 'indoda: ithoni yesikhumba esiphakathi mnyama',
    '👨🏿' => 'indoda: ithoni yesikhumba emnyama',
    '🧔🏻' => 'umntu oneentshebe: ithoni yesikhumba esikhanyayo',
    '🧔🏼' => 'umntu oneentshebe: ithoni yesikhumba esikhanyayo phakathi',
    '🧔🏽' => 'umntu oneentshebe: ithoni yesikhumba esiphakathi',
    '🧔🏾' => 'umntu oneentshebe: ithoni yesikhumba esiphakathi mnyama',
    '🧔🏿' => 'umntu oneentshebe: ithoni yesikhumba emnyama',
    '👩🏻' => 'ibhinqa: ithoni yesikhumba esikhanyayo',
    '👩🏼' => 'ibhinqa: ithoni yesikhumba esikhanyayo phakathi',
    '👩🏽' => 'ibhinqa: ithoni yesikhumba esiphakathi',
    '👩🏾' => 'ibhinqa: ithoni yesikhumba esiphakathi mnyama',
    '👩🏿' => 'ibhinqa: ithoni yesikhumba emnyama',
    '🧓🏻' => 'umntu omdala ngakumbi: ithoni yesikhumba esikhanyayo',
    '🧓🏼' => 'umntu omdala ngakumbi: ithoni yesikhumba esikhanyayo phakathi',
    '🧓🏽' => 'umntu omdala ngakumbi: ithoni yesikhumba esiphakathi',
    '🧓🏾' => 'umntu omdala ngakumbi: ithoni yesikhumba esiphakathi mnyama',
    '🧓🏿' => 'umntu omdala ngakumbi: ithoni yesikhumba emnyama',
    '👴🏻' => 'indoda endala: ithoni yesikhumba esikhanyayo',
    '👴🏼' => 'indoda endala: ithoni yesikhumba esikhanyayo phakathi',
    '👴🏽' => 'indoda endala: ithoni yesikhumba esiphakathi',
    '👴🏾' => 'indoda endala: ithoni yesikhumba esiphakathi mnyama',
    '👴🏿' => 'indoda endala: ithoni yesikhumba emnyama',
    '👵🏻' => 'ibhinqa elidala: ithoni yesikhumba esikhanyayo',
    '👵🏼' => 'ibhinqa elidala: ithoni yesikhumba esikhanyayo phakathi',
    '👵🏽' => 'ibhinqa elidala: ithoni yesikhumba esiphakathi',
    '👵🏾' => 'ibhinqa elidala: ithoni yesikhumba esiphakathi mnyama',
    '👵🏿' => 'ibhinqa elidala: ithoni yesikhumba emnyama',
    '🙍🏻' => 'umntu ofinge iintshiya: ithoni yesikhumba esikhanyayo',
    '🙍🏼' => 'umntu ofinge iintshiya: ithoni yesikhumba esikhanyayo phakathi',
    '🙍🏽' => 'umntu ofinge iintshiya: ithoni yesikhumba esiphakathi',
    '🙍🏾' => 'umntu ofinge iintshiya: ithoni yesikhumba esiphakathi mnyama',
    '🙍🏿' => 'umntu ofinge iintshiya: ithoni yesikhumba emnyama',
    '🙎🏻' => 'umntu otsalisa umlomo: ithoni yesikhumba esikhanyayo',
    '🙎🏼' => 'umntu otsalisa umlomo: ithoni yesikhumba esikhanyayo phakathi',
    '🙎🏽' => 'umntu otsalisa umlomo: ithoni yesikhumba esiphakathi',
    '🙎🏾' => 'umntu otsalisa umlomo: ithoni yesikhumba esiphakathi mnyama',
    '🙎🏿' => 'umntu otsalisa umlomo: ithoni yesikhumba emnyama',
    '🙅🏻' => 'umntu ojekulayo ukuthi HAYI: ithoni yesikhumba esikhanyayo',
    '🙅🏼' => 'umntu ojekulayo ukuthi HAYI: ithoni yesikhumba esikhanyayo phakathi',
    '🙅🏽' => 'umntu ojekulayo ukuthi HAYI: ithoni yesikhumba esiphakathi',
    '🙅🏾' => 'umntu ojekulayo ukuthi HAYI: ithoni yesikhumba esiphakathi mnyama',
    '🙅🏿' => 'umntu ojekulayo ukuthi HAYI: ithoni yesikhumba emnyama',
    '🙆🏻' => 'umntu ojekula ukuthi Kulungile: ithoni yesikhumba esikhanyayo',
    '🙆🏼' => 'umntu ojekula ukuthi Kulungile: ithoni yesikhumba esikhanyayo phakathi',
    '🙆🏽' => 'umntu ojekula ukuthi Kulungile: ithoni yesikhumba esiphakathi',
    '🙆🏾' => 'umntu ojekula ukuthi Kulungile: ithoni yesikhumba esiphakathi mnyama',
    '🙆🏿' => 'umntu ojekula ukuthi Kulungile: ithoni yesikhumba emnyama',
    '💁🏻' => 'umntu ophethule isandla: ithoni yesikhumba esikhanyayo',
    '💁🏼' => 'umntu ophethule isandla: ithoni yesikhumba esikhanyayo phakathi',
    '💁🏽' => 'umntu ophethule isandla: ithoni yesikhumba esiphakathi',
    '💁🏾' => 'umntu ophethule isandla: ithoni yesikhumba esiphakathi mnyama',
    '💁🏿' => 'umntu ophethule isandla: ithoni yesikhumba emnyama',
    '🙋🏻' => 'umntu ophakamisa isandla: ithoni yesikhumba esikhanyayo',
    '🙋🏼' => 'umntu ophakamisa isandla: ithoni yesikhumba esikhanyayo phakathi',
    '🙋🏽' => 'umntu ophakamisa isandla: ithoni yesikhumba esiphakathi',
    '🙋🏾' => 'umntu ophakamisa isandla: ithoni yesikhumba esiphakathi mnyama',
    '🙋🏿' => 'umntu ophakamisa isandla: ithoni yesikhumba emnyama',
    '🙇🏻' => 'umntu ogobayo: ithoni yesikhumba esikhanyayo',
    '🙇🏼' => 'umntu ogobayo: ithoni yesikhumba esikhanyayo phakathi',
    '🙇🏽' => 'umntu ogobayo: ithoni yesikhumba esiphakathi',
    '🙇🏾' => 'umntu ogobayo: ithoni yesikhumba esiphakathi mnyama',
    '🙇🏿' => 'umntu ogobayo: ithoni yesikhumba emnyama',
    '🤦🏻' => 'umntu ogqume ubuso ngezandla: ithoni yesikhumba esikhanyayo',
    '🤦🏼' => 'umntu ogqume ubuso ngezandla: ithoni yesikhumba esikhanyayo phakathi',
    '🤦🏽' => 'umntu ogqume ubuso ngezandla: ithoni yesikhumba esiphakathi',
    '🤦🏾' => 'umntu ogqume ubuso ngezandla: ithoni yesikhumba esiphakathi mnyama',
    '🤦🏿' => 'umntu ogqume ubuso ngezandla: ithoni yesikhumba emnyama',
    '🤷🏻' => 'umntu onyikinya amagxa: ithoni yesikhumba esikhanyayo',
    '🤷🏼' => 'umntu onyikinya amagxa: ithoni yesikhumba esikhanyayo phakathi',
    '🤷🏽' => 'umntu onyikinya amagxa: ithoni yesikhumba esiphakathi',
    '🤷🏾' => 'umntu onyikinya amagxa: ithoni yesikhumba esiphakathi mnyama',
    '🤷🏿' => 'umntu onyikinya amagxa: ithoni yesikhumba emnyama',
    '👮🏻' => 'igosa lamapolisa: ithoni yesikhumba esikhanyayo',
    '👮🏼' => 'igosa lamapolisa: ithoni yesikhumba esikhanyayo phakathi',
    '👮🏽' => 'igosa lamapolisa: ithoni yesikhumba esiphakathi',
    '👮🏾' => 'igosa lamapolisa: ithoni yesikhumba esiphakathi mnyama',
    '👮🏿' => 'igosa lamapolisa: ithoni yesikhumba emnyama',
    '🕵🏻' => 'umcuphi: ithoni yesikhumba esikhanyayo',
    '🕵🏼' => 'umcuphi: ithoni yesikhumba esikhanyayo phakathi',
    '🕵🏽' => 'umcuphi: ithoni yesikhumba esiphakathi',
    '🕵🏾' => 'umcuphi: ithoni yesikhumba esiphakathi mnyama',
    '🕵🏿' => 'umcuphi: ithoni yesikhumba emnyama',
    '💂🏻' => 'unogada: ithoni yesikhumba esikhanyayo',
    '💂🏼' => 'unogada: ithoni yesikhumba esikhanyayo phakathi',
    '💂🏽' => 'unogada: ithoni yesikhumba esiphakathi',
    '💂🏾' => 'unogada: ithoni yesikhumba esiphakathi mnyama',
    '💂🏿' => 'unogada: ithoni yesikhumba emnyama',
    '👷🏻' => 'umsebenzi wolwakhiwo: ithoni yesikhumba esikhanyayo',
    '👷🏼' => 'umsebenzi wolwakhiwo: ithoni yesikhumba esikhanyayo phakathi',
    '👷🏽' => 'umsebenzi wolwakhiwo: ithoni yesikhumba esiphakathi',
    '👷🏾' => 'umsebenzi wolwakhiwo: ithoni yesikhumba esiphakathi mnyama',
    '👷🏿' => 'umsebenzi wolwakhiwo: ithoni yesikhumba emnyama',
    '🤴🏻' => 'inkosana: ithoni yesikhumba esikhanyayo',
    '🤴🏼' => 'inkosana: ithoni yesikhumba esikhanyayo phakathi',
    '🤴🏽' => 'inkosana: ithoni yesikhumba esiphakathi',
    '🤴🏾' => 'inkosana: ithoni yesikhumba esiphakathi mnyama',
    '🤴🏿' => 'inkosana: ithoni yesikhumba emnyama',
    '👸🏻' => 'inkosazana: ithoni yesikhumba esikhanyayo',
    '👸🏼' => 'inkosazana: ithoni yesikhumba esikhanyayo phakathi',
    '👸🏽' => 'inkosazana: ithoni yesikhumba esiphakathi',
    '👸🏾' => 'inkosazana: ithoni yesikhumba esiphakathi mnyama',
    '👸🏿' => 'inkosazana: ithoni yesikhumba emnyama',
    '👳🏻' => 'umntu othwele unkontsho: ithoni yesikhumba esikhanyayo',
    '👳🏼' => 'umntu othwele unkontsho: ithoni yesikhumba esikhanyayo phakathi',
    '👳🏽' => 'umntu othwele unkontsho: ithoni yesikhumba esiphakathi',
    '👳🏾' => 'umntu othwele unkontsho: ithoni yesikhumba esiphakathi mnyama',
    '👳🏿' => 'umntu othwele unkontsho: ithoni yesikhumba emnyama',
    '👲🏻' => 'indoda enxibe ikepusi: ithoni yesikhumba esikhanyayo',
    '👲🏼' => 'indoda enxibe ikepusi: ithoni yesikhumba esikhanyayo phakathi',
    '👲🏽' => 'indoda enxibe ikepusi: ithoni yesikhumba esiphakathi',
    '👲🏾' => 'indoda enxibe ikepusi: ithoni yesikhumba esiphakathi mnyama',
    '👲🏿' => 'indoda enxibe ikepusi: ithoni yesikhumba emnyama',
    '🧕🏻' => 'ibhinqa elineqhiya: ithoni yesikhumba esikhanyayo',
    '🧕🏼' => 'ibhinqa elineqhiya: ithoni yesikhumba esikhanyayo phakathi',
    '🧕🏽' => 'ibhinqa elineqhiya: ithoni yesikhumba esiphakathi',
    '🧕🏾' => 'ibhinqa elineqhiya: ithoni yesikhumba esiphakathi mnyama',
    '🧕🏿' => 'ibhinqa elineqhiya: ithoni yesikhumba emnyama',
    '🤵🏻' => 'indoda enxibe i-tuxedo: ithoni yesikhumba esikhanyayo',
    '🤵🏼' => 'indoda enxibe i-tuxedo: ithoni yesikhumba esikhanyayo phakathi',
    '🤵🏽' => 'indoda enxibe i-tuxedo: ithoni yesikhumba esiphakathi',
    '🤵🏾' => 'indoda enxibe i-tuxedo: ithoni yesikhumba esiphakathi mnyama',
    '🤵🏿' => 'indoda enxibe i-tuxedo: ithoni yesikhumba emnyama',
    '👰🏻' => 'umtshakazi nesigubungelo: ithoni yesikhumba esikhanyayo',
    '👰🏼' => 'umtshakazi nesigubungelo: ithoni yesikhumba esikhanyayo phakathi',
    '👰🏽' => 'umtshakazi nesigubungelo: ithoni yesikhumba esiphakathi',
    '👰🏾' => 'umtshakazi nesigubungelo: ithoni yesikhumba esiphakathi mnyama',
    '👰🏿' => 'umtshakazi nesigubungelo: ithoni yesikhumba emnyama',
    '🤰🏻' => 'ibhinqa elikhulelweyo: ithoni yesikhumba esikhanyayo',
    '🤰🏼' => 'ibhinqa elikhulelweyo: ithoni yesikhumba esikhanyayo phakathi',
    '🤰🏽' => 'ibhinqa elikhulelweyo: ithoni yesikhumba esiphakathi',
    '🤰🏾' => 'ibhinqa elikhulelweyo: ithoni yesikhumba esiphakathi mnyama',
    '🤰🏿' => 'ibhinqa elikhulelweyo: ithoni yesikhumba emnyama',
    '🤱🏻' => 'ukuncancisa: ithoni yesikhumba esikhanyayo',
    '🤱🏼' => 'ukuncancisa: ithoni yesikhumba esikhanyayo phakathi',
    '🤱🏽' => 'ukuncancisa: ithoni yesikhumba esiphakathi',
    '🤱🏾' => 'ukuncancisa: ithoni yesikhumba esiphakathi mnyama',
    '🤱🏿' => 'ukuncancisa: ithoni yesikhumba emnyama',
    '👼🏻' => 'ingelosi elusana: ithoni yesikhumba esikhanyayo',
    '👼🏼' => 'ingelosi elusana: ithoni yesikhumba esikhanyayo phakathi',
    '👼🏽' => 'ingelosi elusana: ithoni yesikhumba esiphakathi',
    '👼🏾' => 'ingelosi elusana: ithoni yesikhumba esiphakathi mnyama',
    '👼🏿' => 'ingelosi elusana: ithoni yesikhumba emnyama',
    '🎅🏻' => 'U-Santa Claus: ithoni yesikhumba esikhanyayo',
    '🎅🏼' => 'U-Santa Claus: ithoni yesikhumba esikhanyayo phakathi',
    '🎅🏽' => 'U-Santa Claus: ithoni yesikhumba esiphakathi',
    '🎅🏾' => 'U-Santa Claus: ithoni yesikhumba esiphakathi mnyama',
    '🎅🏿' => 'U-Santa Claus: ithoni yesikhumba emnyama',
    '🤶🏻' => 'UNksz. Claus: ithoni yesikhumba esikhanyayo',
    '🤶🏼' => 'UNksz. Claus: ithoni yesikhumba esikhanyayo phakathi',
    '🤶🏽' => 'UNksz. Claus: ithoni yesikhumba esiphakathi',
    '🤶🏾' => 'UNksz. Claus: ithoni yesikhumba esiphakathi mnyama',
    '🤶🏿' => 'UNksz. Claus: ithoni yesikhumba emnyama',
    '🧙🏻' => 'i-mage: ithoni yesikhumba esikhanyayo',
    '🧙🏼' => 'i-mage: ithoni yesikhumba esikhanyayo phakathi',
    '🧙🏽' => 'i-mage: ithoni yesikhumba esiphakathi',
    '🧙🏾' => 'i-mage: ithoni yesikhumba esiphakathi mnyama',
    '🧙🏿' => 'i-mage: ithoni yesikhumba emnyama',
    '🧚🏻' => 'umkholonjane: ithoni yesikhumba esikhanyayo',
    '🧚🏼' => 'umkholonjane: ithoni yesikhumba esikhanyayo phakathi',
    '🧚🏽' => 'umkholonjane: ithoni yesikhumba esiphakathi',
    '🧚🏾' => 'umkholonjane: ithoni yesikhumba esiphakathi mnyama',
    '🧚🏿' => 'umkholonjane: ithoni yesikhumba emnyama',
    '🧛🏻' => 'i-vampire: ithoni yesikhumba esikhanyayo',
    '🧛🏼' => 'i-vampire: ithoni yesikhumba esikhanyayo phakathi',
    '🧛🏽' => 'i-vampire: ithoni yesikhumba esiphakathi',
    '🧛🏾' => 'i-vampire: ithoni yesikhumba esiphakathi mnyama',
    '🧛🏿' => 'i-vampire: ithoni yesikhumba emnyama',
    '🧜🏻' => 'i-merperson: ithoni yesikhumba esikhanyayo',
    '🧜🏼' => 'i-merperson: ithoni yesikhumba esikhanyayo phakathi',
    '🧜🏽' => 'i-merperson: ithoni yesikhumba esiphakathi',
    '🧜🏾' => 'i-merperson: ithoni yesikhumba esiphakathi mnyama',
    '🧜🏿' => 'i-merperson: ithoni yesikhumba emnyama',
    '🧝🏻' => 'uhili: ithoni yesikhumba esikhanyayo',
    '🧝🏼' => 'uhili: ithoni yesikhumba esikhanyayo phakathi',
    '🧝🏽' => 'uhili: ithoni yesikhumba esiphakathi',
    '🧝🏾' => 'uhili: ithoni yesikhumba esiphakathi mnyama',
    '🧝🏿' => 'uhili: ithoni yesikhumba emnyama',
    '💆🏻' => 'umntu ophululwayo: ithoni yesikhumba esikhanyayo',
    '💆🏼' => 'umntu ophululwayo: ithoni yesikhumba esikhanyayo phakathi',
    '💆🏽' => 'umntu ophululwayo: ithoni yesikhumba esiphakathi',
    '💆🏾' => 'umntu ophululwayo: ithoni yesikhumba esiphakathi mnyama',
    '💆🏿' => 'umntu ophululwayo: ithoni yesikhumba emnyama',
    '💇🏻' => 'umntu ocheba iinwele: ithoni yesikhumba esikhanyayo',
    '💇🏼' => 'umntu ocheba iinwele: ithoni yesikhumba esikhanyayo phakathi',
    '💇🏽' => 'umntu ocheba iinwele: ithoni yesikhumba esiphakathi',
    '💇🏾' => 'umntu ocheba iinwele: ithoni yesikhumba esiphakathi mnyama',
    '💇🏿' => 'umntu ocheba iinwele: ithoni yesikhumba emnyama',
    '🚶🏻' => 'umntu ohambayo: ithoni yesikhumba esikhanyayo',
    '🚶🏼' => 'umntu ohambayo: ithoni yesikhumba esikhanyayo phakathi',
    '🚶🏽' => 'umntu ohambayo: ithoni yesikhumba esiphakathi',
    '🚶🏾' => 'umntu ohambayo: ithoni yesikhumba esiphakathi mnyama',
    '🚶🏿' => 'umntu ohambayo: ithoni yesikhumba emnyama',
    '🏃🏻' => 'umntu obalekayo: ithoni yesikhumba esikhanyayo',
    '🏃🏼' => 'umntu obalekayo: ithoni yesikhumba esikhanyayo phakathi',
    '🏃🏽' => 'umntu obalekayo: ithoni yesikhumba esiphakathi',
    '🏃🏾' => 'umntu obalekayo: ithoni yesikhumba esiphakathi mnyama',
    '🏃🏿' => 'umntu obalekayo: ithoni yesikhumba emnyama',
    '💃🏻' => 'ibhinqa elidanisayo: ithoni yesikhumba esikhanyayo',
    '💃🏼' => 'ibhinqa elidanisayo: ithoni yesikhumba esikhanyayo phakathi',
    '💃🏽' => 'ibhinqa elidanisayo: ithoni yesikhumba esiphakathi',
    '💃🏾' => 'ibhinqa elidanisayo: ithoni yesikhumba esiphakathi mnyama',
    '💃🏿' => 'ibhinqa elidanisayo: ithoni yesikhumba emnyama',
    '🕺🏻' => 'indoda edanisayo: ithoni yesikhumba esikhanyayo',
    '🕺🏼' => 'indoda edanisayo: ithoni yesikhumba esikhanyayo phakathi',
    '🕺🏽' => 'indoda edanisayo: ithoni yesikhumba esiphakathi',
    '🕺🏾' => 'indoda edanisayo: ithoni yesikhumba esiphakathi mnyama',
    '🕺🏿' => 'indoda edanisayo: ithoni yesikhumba emnyama',
    '🕴🏻' => 'indoda enxibe isuti yeshishini endandayo: ithoni yesikhumba esikhanyayo',
    '🕴🏼' => 'indoda enxibe isuti yeshishini endandayo: ithoni yesikhumba esikhanyayo phakathi',
    '🕴🏽' => 'indoda enxibe isuti yeshishini endandayo: ithoni yesikhumba esiphakathi',
    '🕴🏾' => 'indoda enxibe isuti yeshishini endandayo: ithoni yesikhumba esiphakathi mnyama',
    '🕴🏿' => 'indoda enxibe isuti yeshishini endandayo: ithoni yesikhumba emnyama',
    '👯🏻' => 'abantu abaneendlebe zomvundla abakwitheko: ithoni yesikhumba esikhanyayo',
    '👯🏼' => 'abantu abaneendlebe zomvundla abakwitheko: ithoni yesikhumba esikhanyayo phakathi',
    '👯🏽' => 'abantu abaneendlebe zomvundla abakwitheko: ithoni yesikhumba esiphakathi',
    '👯🏾' => 'abantu abaneendlebe zomvundla abakwitheko: ithoni yesikhumba esiphakathi mnyama',
    '👯🏿' => 'abantu abaneendlebe zomvundla abakwitheko: ithoni yesikhumba emnyama',
    '🧖🏻' => 'umntu okwigumbi lomphunga: ithoni yesikhumba esikhanyayo',
    '🧖🏼' => 'umntu okwigumbi lomphunga: ithoni yesikhumba esikhanyayo phakathi',
    '🧖🏽' => 'umntu okwigumbi lomphunga: ithoni yesikhumba esiphakathi',
    '🧖🏾' => 'umntu okwigumbi lomphunga: ithoni yesikhumba esiphakathi mnyama',
    '🧖🏿' => 'umntu okwigumbi lomphunga: ithoni yesikhumba emnyama',
    '🧗🏻' => 'umntu onyukayo: ithoni yesikhumba esikhanyayo',
    '🧗🏼' => 'umntu onyukayo: ithoni yesikhumba esikhanyayo phakathi',
    '🧗🏽' => 'umntu onyukayo: ithoni yesikhumba esiphakathi',
    '🧗🏾' => 'umntu onyukayo: ithoni yesikhumba esiphakathi mnyama',
    '🧗🏿' => 'umntu onyukayo: ithoni yesikhumba emnyama',
    '🏇🏻' => 'ihashe elikumdyarho: ithoni yesikhumba esikhanyayo',
    '🏇🏼' => 'ihashe elikumdyarho: ithoni yesikhumba esikhanyayo phakathi',
    '🏇🏽' => 'ihashe elikumdyarho: ithoni yesikhumba esiphakathi',
    '🏇🏾' => 'ihashe elikumdyarho: ithoni yesikhumba esiphakathi mnyama',
    '🏇🏿' => 'ihashe elikumdyarho: ithoni yesikhumba emnyama',
    '🏂🏻' => 'umtyibilizi kwikhephu: ithoni yesikhumba esikhanyayo',
    '🏂🏼' => 'umtyibilizi kwikhephu: ithoni yesikhumba esikhanyayo phakathi',
    '🏂🏽' => 'umtyibilizi kwikhephu: ithoni yesikhumba esiphakathi',
    '🏂🏾' => 'umtyibilizi kwikhephu: ithoni yesikhumba esiphakathi mnyama',
    '🏂🏿' => 'umtyibilizi kwikhephu: ithoni yesikhumba emnyama',
    '🏌🏻' => 'umntu odlala igalufa: ithoni yesikhumba esikhanyayo',
    '🏌🏼' => 'umntu odlala igalufa: ithoni yesikhumba esikhanyayo phakathi',
    '🏌🏽' => 'umntu odlala igalufa: ithoni yesikhumba esiphakathi',
    '🏌🏾' => 'umntu odlala igalufa: ithoni yesikhumba esiphakathi mnyama',
    '🏌🏿' => 'umntu odlala igalufa: ithoni yesikhumba emnyama',
    '🏄🏻' => 'umntu otyibiliza phezu kwamaza: ithoni yesikhumba esikhanyayo',
    '🏄🏼' => 'umntu otyibiliza phezu kwamaza: ithoni yesikhumba esikhanyayo phakathi',
    '🏄🏽' => 'umntu otyibiliza phezu kwamaza: ithoni yesikhumba esiphakathi',
    '🏄🏾' => 'umntu otyibiliza phezu kwamaza: ithoni yesikhumba esiphakathi mnyama',
    '🏄🏿' => 'umntu otyibiliza phezu kwamaza: ithoni yesikhumba emnyama',
    '🚣🏻' => 'umntu obheqa iphenyane: ithoni yesikhumba esikhanyayo',
    '🚣🏼' => 'umntu obheqa iphenyane: ithoni yesikhumba esikhanyayo phakathi',
    '🚣🏽' => 'umntu obheqa iphenyane: ithoni yesikhumba esiphakathi',
    '🚣🏾' => 'umntu obheqa iphenyane: ithoni yesikhumba esiphakathi mnyama',
    '🚣🏿' => 'umntu obheqa iphenyane: ithoni yesikhumba emnyama',
    '🏊🏻' => 'umntu oqubhayo: ithoni yesikhumba esikhanyayo',
    '🏊🏼' => 'umntu oqubhayo: ithoni yesikhumba esikhanyayo phakathi',
    '🏊🏽' => 'umntu oqubhayo: ithoni yesikhumba esiphakathi',
    '🏊🏾' => 'umntu oqubhayo: ithoni yesikhumba esiphakathi mnyama',
    '🏊🏿' => 'umntu oqubhayo: ithoni yesikhumba emnyama',
    '⛹🏻' => 'umntu ogqampisa ibhola: ithoni yesikhumba esikhanyayo',
    '⛹🏼' => 'umntu ogqampisa ibhola: ithoni yesikhumba esikhanyayo phakathi',
    '⛹🏽' => 'umntu ogqampisa ibhola: ithoni yesikhumba esiphakathi',
    '⛹🏾' => 'umntu ogqampisa ibhola: ithoni yesikhumba esiphakathi mnyama',
    '⛹🏿' => 'umntu ogqampisa ibhola: ithoni yesikhumba emnyama',
    '🏋🏻' => 'umntu ophakamisa iintsimbi: ithoni yesikhumba esikhanyayo',
    '🏋🏼' => 'umntu ophakamisa iintsimbi: ithoni yesikhumba esikhanyayo phakathi',
    '🏋🏽' => 'umntu ophakamisa iintsimbi: ithoni yesikhumba esiphakathi',
    '🏋🏾' => 'umntu ophakamisa iintsimbi: ithoni yesikhumba esiphakathi mnyama',
    '🏋🏿' => 'umntu ophakamisa iintsimbi: ithoni yesikhumba emnyama',
    '🚴🏻' => 'umntu oqhuba ibhayisekile: ithoni yesikhumba esikhanyayo',
    '🚴🏼' => 'umntu oqhuba ibhayisekile: ithoni yesikhumba esikhanyayo phakathi',
    '🚴🏽' => 'umntu oqhuba ibhayisekile: ithoni yesikhumba esiphakathi',
    '🚴🏾' => 'umntu oqhuba ibhayisekile: ithoni yesikhumba esiphakathi mnyama',
    '🚴🏿' => 'umntu oqhuba ibhayisekile: ithoni yesikhumba emnyama',
    '🚵🏻' => 'umntu oqhuba ibhayisekile entabeni: ithoni yesikhumba esikhanyayo',
    '🚵🏼' => 'umntu oqhuba ibhayisekile entabeni: ithoni yesikhumba esikhanyayo phakathi',
    '🚵🏽' => 'umntu oqhuba ibhayisekile entabeni: ithoni yesikhumba esiphakathi',
    '🚵🏾' => 'umntu oqhuba ibhayisekile entabeni: ithoni yesikhumba esiphakathi mnyama',
    '🚵🏿' => 'umntu oqhuba ibhayisekile entabeni: ithoni yesikhumba emnyama',
    '🤸🏻' => 'umntu owenza uqilikibhode ngecala: ithoni yesikhumba esikhanyayo',
    '🤸🏼' => 'umntu owenza uqilikibhode ngecala: ithoni yesikhumba esikhanyayo phakathi',
    '🤸🏽' => 'umntu owenza uqilikibhode ngecala: ithoni yesikhumba esiphakathi',
    '🤸🏾' => 'umntu owenza uqilikibhode ngecala: ithoni yesikhumba esiphakathi mnyama',
    '🤸🏿' => 'umntu owenza uqilikibhode ngecala: ithoni yesikhumba emnyama',
    '🤼🏻' => 'abantu abangqulanayo: ithoni yesikhumba esikhanyayo',
    '🤼🏼' => 'abantu abangqulanayo: ithoni yesikhumba esikhanyayo phakathi',
    '🤼🏽' => 'abantu abangqulanayo: ithoni yesikhumba esiphakathi',
    '🤼🏾' => 'abantu abangqulanayo: ithoni yesikhumba esiphakathi mnyama',
    '🤼🏿' => 'abantu abangqulanayo: ithoni yesikhumba emnyama',
    '🤽🏻' => 'umntu odlala i-polo yasemanzini: ithoni yesikhumba esikhanyayo',
    '🤽🏼' => 'umntu odlala i-polo yasemanzini: ithoni yesikhumba esikhanyayo phakathi',
    '🤽🏽' => 'umntu odlala i-polo yasemanzini: ithoni yesikhumba esiphakathi',
    '🤽🏾' => 'umntu odlala i-polo yasemanzini: ithoni yesikhumba esiphakathi mnyama',
    '🤽🏿' => 'umntu odlala i-polo yasemanzini: ithoni yesikhumba emnyama',
    '🤾🏻' => 'umntu odlala ibhola yesandla: ithoni yesikhumba esikhanyayo',
    '🤾🏼' => 'umntu odlala ibhola yesandla: ithoni yesikhumba esikhanyayo phakathi',
    '🤾🏽' => 'umntu odlala ibhola yesandla: ithoni yesikhumba esiphakathi',
    '🤾🏾' => 'umntu odlala ibhola yesandla: ithoni yesikhumba esiphakathi mnyama',
    '🤾🏿' => 'umntu odlala ibhola yesandla: ithoni yesikhumba emnyama',
    '🤹🏻' => 'umntu oqhathayo: ithoni yesikhumba esikhanyayo',
    '🤹🏼' => 'umntu oqhathayo: ithoni yesikhumba esikhanyayo phakathi',
    '🤹🏽' => 'umntu oqhathayo: ithoni yesikhumba esiphakathi',
    '🤹🏾' => 'umntu oqhathayo: ithoni yesikhumba esiphakathi mnyama',
    '🤹🏿' => 'umntu oqhathayo: ithoni yesikhumba emnyama',
    '🧘🏻' => 'umntu okwimo ye-lotus: ithoni yesikhumba esikhanyayo',
    '🧘🏼' => 'umntu okwimo ye-lotus: ithoni yesikhumba esikhanyayo phakathi',
    '🧘🏽' => 'umntu okwimo ye-lotus: ithoni yesikhumba esiphakathi',
    '🧘🏾' => 'umntu okwimo ye-lotus: ithoni yesikhumba esiphakathi mnyama',
    '🧘🏿' => 'umntu okwimo ye-lotus: ithoni yesikhumba emnyama',
    '🛀🏻' => 'umntu ohlambayo: ithoni yesikhumba esikhanyayo',
    '🛀🏼' => 'umntu ohlambayo: ithoni yesikhumba esikhanyayo phakathi',
    '🛀🏽' => 'umntu ohlambayo: ithoni yesikhumba esiphakathi',
    '🛀🏾' => 'umntu ohlambayo: ithoni yesikhumba esiphakathi mnyama',
    '🛀🏿' => 'umntu ohlambayo: ithoni yesikhumba emnyama',
    '🛌🏻' => 'umntu osebhedini: ithoni yesikhumba esikhanyayo',
    '🛌🏼' => 'umntu osebhedini: ithoni yesikhumba esikhanyayo phakathi',
    '🛌🏽' => 'umntu osebhedini: ithoni yesikhumba esiphakathi',
    '🛌🏾' => 'umntu osebhedini: ithoni yesikhumba esiphakathi mnyama',
    '🛌🏿' => 'umntu osebhedini: ithoni yesikhumba emnyama',
    '👭🏻' => 'amabhinqa amabini abambene ngezandla: ithoni yesikhumba esikhanyayo',
    '👭🏼' => 'amabhinqa amabini abambene ngezandla: ithoni yesikhumba esikhanyayo phakathi',
    '👭🏽' => 'amabhinqa amabini abambene ngezandla: ithoni yesikhumba esiphakathi',
    '👭🏾' => 'amabhinqa amabini abambene ngezandla: ithoni yesikhumba esiphakathi mnyama',
    '👭🏿' => 'amabhinqa amabini abambene ngezandla: ithoni yesikhumba emnyama',
    '👫🏻' => 'indoda nebhinqa abambe izandla: ithoni yesikhumba esikhanyayo',
    '👫🏼' => 'indoda nebhinqa abambe izandla: ithoni yesikhumba esikhanyayo phakathi',
    '👫🏽' => 'indoda nebhinqa abambe izandla: ithoni yesikhumba esiphakathi',
    '👫🏾' => 'indoda nebhinqa abambe izandla: ithoni yesikhumba esiphakathi mnyama',
    '👫🏿' => 'indoda nebhinqa abambe izandla: ithoni yesikhumba emnyama',
    '👬🏻' => 'amadoda amabini abambene ngezandla: ithoni yesikhumba esikhanyayo',
    '👬🏼' => 'amadoda amabini abambene ngezandla: ithoni yesikhumba esikhanyayo phakathi',
    '👬🏽' => 'amadoda amabini abambene ngezandla: ithoni yesikhumba esiphakathi',
    '👬🏾' => 'amadoda amabini abambene ngezandla: ithoni yesikhumba esiphakathi mnyama',
    '👬🏿' => 'amadoda amabini abambene ngezandla: ithoni yesikhumba emnyama',
    '💏🏻' => 'phuza: ithoni yesikhumba esikhanyayo',
    '💏🏼' => 'phuza: ithoni yesikhumba esikhanyayo phakathi',
    '💏🏽' => 'phuza: ithoni yesikhumba esiphakathi',
    '💏🏾' => 'phuza: ithoni yesikhumba esiphakathi mnyama',
    '💏🏿' => 'phuza: ithoni yesikhumba emnyama',
    '💑🏻' => 'isibini esinentliziyo: ithoni yesikhumba esikhanyayo',
    '💑🏼' => 'isibini esinentliziyo: ithoni yesikhumba esikhanyayo phakathi',
    '💑🏽' => 'isibini esinentliziyo: ithoni yesikhumba esiphakathi',
    '💑🏾' => 'isibini esinentliziyo: ithoni yesikhumba esiphakathi mnyama',
    '💑🏿' => 'isibini esinentliziyo: ithoni yesikhumba emnyama',
    '🏻' => 'ithoni yesikhumba esikhanyayo',
    '🏼' => 'ithoni yesikhumba esikhanyayo phakathi',
    '🏽' => 'ithoni yesikhumba esiphakathi',
    '🏾' => 'ithoni yesikhumba esiphakathi mnyama',
    '🏿' => 'ithoni yesikhumba emnyama',
    '😀' => 'ubuso obuhlekayo',
    '😃' => 'ubuso obuncumileyo obunomlomo ovulekileyo',
    '😄' => 'ubuso obuncumileyo obunomlomo ovulekileyo namehlo ancumileyo',
    '😁' => 'ubuso obuhlekayo obunamehlo ancumileyo',
    '😆' => 'ubuso obuncumileyo obunomlomo ovulekileyo namehlo avalekileyo',
    '😅' => 'ubuso obuncumileyo obunomlomo ovulekileyo nombilo obandayo',
    '🤣' => 'ukugigitheka phantsi',
    '😂' => 'ubuso obuneenyembezi zovuyo',
    '🙂' => 'ubuso obuncumileyo kancinane',
    '🙃' => 'ubuso obuphethukileyo',
    '😉' => 'ubuso obuqoba iliso',
    '😊' => 'ubuso obuncumileyo obunamehlo ancumileyo',
    '😇' => 'ubuso obuncumileyo obunesangqa entloko',
    '😍' => 'ubuso obuncumileyo obunamehlo anentliziyo',
    '🤩' => 'ukothuka',
    '😘' => 'ubuso obuvuthela umncamiso',
    '😗' => 'ubuso obuphuzayo',
    '☺' => 'ubuso obuncumileyo',
    '😚' => 'ubuso obuphuzayo obuvale amehlo',
    '😙' => 'ubuso obuphuzayo obunamehlo ancumileyo',
    '😋' => 'ubuso obunandipha ukutya okumnandi',
    '😛' => 'ubuso obunyonyoza ulwimi',
    '😜' => 'ubuso obunyonyoza ulwimi nobuqwabaza iliso',
    '🤪' => 'ubuso obugulayo',
    '😝' => 'ubuso obunyonyoza ulwimi namehlo acimeleyo',
    '🤑' => 'ubuso obunemali emlonyeni',
    '🤗' => 'ubuso obangayo',
    '🤭' => 'ubuso obubekwe isandla emlonyeni',
    '🤫' => 'ubuso obuthulisayo',
    '🤔' => 'ubuso obucingayo',
    '🤐' => 'ubuso obuvalwe umlomo ngoziphu',
    '🤨' => 'ubuso obuneentshiya ezinyusiweyo',
    '😐' => 'ubuso obunyutrali',
    '😑' => 'ubuso obungena mvakalelo',
    '😶' => 'ubuso obungenamlomo',
    '😏' => 'ubuso obusinekileyo',
    '😒' => 'ubuso obungahlekiyo',
    '🙄' => 'ubuso obunamehlo ajikelezayo',
    '😬' => 'ubuso obujamileyo',
    '🤥' => 'ubuso obuxokayo',
    '😌' => 'ubuso obuqabukileyo',
    '😔' => 'ubuso obucamngcayo',
    '😪' => 'ubuso obozelayo',
    '🤤' => 'ubuso obuvuz’ uluchwe',
    '😴' => 'ubuso obuleleyo',
    '😷' => 'ubuso obunesigqubuthelo sonyango',
    '🤒' => 'ubuso obune-thermometer',
    '🤕' => 'ubuso obunebhandeji elisentloko',
    '🤢' => 'ubuso obonyanyileyo',
    '🤮' => 'ubuso obugabhayo',
    '🤧' => 'ubuso obuthimlayo',
    '😵' => 'ubuso obunesiyezi',
    '🤯' => 'intloko edubulayo',
    '🤠' => 'ubuso bomnqwazi we-cowboy',
    '😎' => 'ubuso obuncumileyo obuneendondo',
    '🤓' => 'ubuso benkcuba-buchopho',
    '🧐' => 'ubuso obune-monocle',
    '😕' => 'ubuso obuxakiweyo',
    '😟' => 'ubuso obuxhalabileyo',
    '🙁' => 'ubuso obujayileyo kancinane',
    '☹' => 'ubuso obufinge iintshiya',
    '😮' => 'ubuso obunomlomo ovulekileyo',
    '😯' => 'ubuso obuthuleyo',
    '😲' => 'ubuso obuthe manga',
    '😳' => 'ubuso obuneentloni',
    '😦' => 'ubuso obufinge iintshiya obuvule umlomo',
    '😧' => 'ubuso obulusizi',
    '😨' => 'ubuso oboyikayo',
    '😰' => 'ubuso obunomlomo ovulekileyo nombilo obandayo',
    '😥' => 'ubuso obudanileyo kodwa obuqabukileyo',
    '😢' => 'ubuso obulilayo',
    '😭' => 'ubuso obulilayo ngokuvakalayo',
    '😱' => 'ubuso obutswinayo luloyiko',
    '😖' => 'ubuso obubhidekileyo',
    '😣' => 'ubuso bokunyamezela',
    '😞' => 'ubuso obuphoxekileyo',
    '😓' => 'ubuso obunombilo obandayo',
    '😩' => 'ubuso obudiniweyo kakhulu',
    '😫' => 'ubuso obudiniweyo',
    '😤' => 'ubuso obunomphunga ophuma empumlweni',
    '😡' => 'ubuso obutsolise umlomo',
    '😠' => 'ubuso obunomsindo',
    '🤬' => 'ubuso uboneesimboli emlonyeni',
    '😈' => 'ubuso obuncumileyo obuneempondo',
    '👿' => 'ubuso obunomsindo obuneempondo',
    '💀' => 'ukakayi',
    '☠' => 'ukakayi namathambo anqamlezileyo',
    '💩' => 'imfumba yelindle',
    '🤡' => 'ubuso bomhlekisi',
    '👹' => 'izim',
    '👺' => 'uthikoloshe',
    '👻' => 'isiporho',
    '👽' => 'engaqhelekanga',
    '👾' => 'irhamncwa elingaqhelekanga',
    '🤖' => 'ubuso berobhothi',
    '😺' => 'ubuso bekati encumileyo enamehlo anentliziyo',
    '😸' => 'ubuso bekati obuhlekayo obunamehlo ancumileyo',
    '😹' => 'ubuso bekati obuneenyembezi',
    '😻' => 'ubuso obuncumileyo bekati obunamehlo anentliziyo',
    '😼' => 'ubuso bekati obunoncumo olugoso',
    '😽' => 'ubuso bekati encamisayo evale amehlo',
    '🙀' => 'ubuso bekati ediniweyo',
    '😿' => 'ubuso bekati elilayo',
    '😾' => 'ubuso bekati etsolise umlomo',
    '🙈' => 'inkawu evale amehlo',
    '🙉' => 'inkawu evale iindlebe',
    '🙊' => 'inkawu evale umlomo',
    '💌' => 'ileta yothando',
    '💘' => 'intliziyo enotolo',
    '💝' => 'intliziyo eneribhoni',
    '💖' => 'intliziyo ekhazimlayo',
    '💗' => 'intliziyo ekhulayo',
    '💓' => 'intliziyo ebethayo',
    '💞' => 'iintliziyo ejikelezayo',
    '💕' => 'iintliziyo ezimbini',
    '💟' => 'umhombiso wentliziyo',
    '❣' => 'isikhuzo sentliziyo enzima',
    '💔' => 'intliziyo eyaphukileyo',
    '❤' => 'intliziyo ebomvu',
    '🧡' => 'intliziyo eorenji',
    '💛' => 'intliziyo emthubi',
    '💚' => 'intliziyo eluhlaza',
    '💙' => 'intliziyo ebhlowu',
    '💜' => 'intliziyo emfusa',
    '🖤' => 'intliziyo emnyama',
    '💋' => 'uphawu lokuphuza',
    '💯' => 'amanqaku alikhulu',
    '💢' => 'isimboli yomsindo',
    '💥' => 'ukungqubana',
    '💫' => 'isiyezi',
    '💦' => 'amathontsi ombilo',
    '💨' => 'ukubaleka',
    '🕳' => 'umngxuma',
    '💬' => 'ibhaloni yentetho',
    '🗨' => 'iqhamza lentetho elisekhohlo',
    '🗯' => 'iqhamza lomsindo elisekunene',
    '💭' => 'ibhaluni yokucinga',
    '💤' => 'zzz',
    '👋' => 'ukuwangawangisa isandla',
    '🤚' => 'umva wesandla onyusiweyo',
    '🖐' => 'isandla esiphakanyisiweyo esineminwe ethe saa',
    '✋' => 'isandla esinyusiweyo',
    '🖖' => 'umbuliso we-vulcan',
    '👌' => 'isandla esithi Kulungile',
    '✌' => 'isandla sempumelelo',
    '🤞' => 'iminwe enqamlezeneyo',
    '🤟' => 'umjekulo othi ndiyakuthanda',
    '🤘' => 'uphawu lweempondo',
    '🤙' => 'isandla esithi ndifowunele',
    '👈' => 'isalathiso somva wesandla esalatha ekhohlo',
    '👉' => 'isalathiso somva wesandla esalatha ekunene',
    '👆' => 'isalathiso somva wesandla esalatha phezulu',
    '🖕' => 'umnwe ophakathi',
    '👇' => 'isalathiso somva wesandla esalatha ezantsi',
    '☝' => 'isalathiso esalatha phezulu',
    '👍' => 'ubhontsi ojonge phezulu',
    '👎' => 'ubhontsi ojonge ezantsi',
    '✊' => 'inqindi elinyusiweyo',
    '👊' => 'inqindi elizayo',
    '🤛' => 'inqindi elijonge ekhohlo',
    '🤜' => 'inqindi elijonge ekunene',
    '👏' => 'izandla eziqhwabayo',
    '🙌' => 'ukunyusa izandla',
    '👐' => 'izandla ezivulekileyo',
    '🤲' => 'iintende zesandla ezikunye',
    '🤝' => 'ukubamba isandla',
    '🙏' => 'izandla ezisongiweyo',
    '✍' => 'isandla esibhalayo',
    '💅' => 'ipolishi yeenzipho',
    '🤳' => 'iselfi',
    '💪' => 'amankonyana agotyiweyo',
    '👂' => 'indlebe',
    '👃' => 'impumlo',
    '🧠' => 'ubuchopho',
    '👀' => 'amehlo',
    '👁' => 'iliso',
    '👅' => 'ulwimi',
    '👄' => 'umlomo',
    '👶' => 'usana',
    '🧒' => 'umntwana',
    '👦' => 'inkwenkwe',
    '👧' => 'intombazana',
    '🧑' => 'umntu omdala',
    '👱' => 'umntu oneenwele ezimhlophe',
    '👨' => 'indoda',
    '🧔' => 'umntu oneentshebe',
    '👩' => 'ibhinqa',
    '🧓' => 'umntu omdala ngakumbi',
    '👴' => 'indoda endala',
    '👵' => 'ibhinqa elidala',
    '🙍' => 'umntu ofinge iintshiya',
    '🙎' => 'umntu otsalisa umlomo',
    '🙅' => 'umntu ojekulayo ukuthi HAYI',
    '🙆' => 'umntu ojekula ukuthi Kulungile',
    '💁' => 'umntu ophethule isandla',
    '🙋' => 'umntu ophakamisa isandla',
    '🙇' => 'umntu ogobayo',
    '🤦' => 'umntu ogqume ubuso ngezandla',
    '🤷' => 'umntu onyikinya amagxa',
    '👮' => 'igosa lamapolisa',
    '🕵' => 'umcuphi',
    '💂' => 'unogada',
    '👷' => 'umsebenzi wolwakhiwo',
    '🤴' => 'inkosana',
    '👸' => 'inkosazana',
    '👳' => 'umntu othwele unkontsho',
    '👲' => 'indoda enxibe ikepusi',
    '🧕' => 'ibhinqa elineqhiya',
    '🤵' => 'indoda enxibe i-tuxedo',
    '👰' => 'umtshakazi nesigubungelo',
    '🤰' => 'ibhinqa elikhulelweyo',
    '🤱' => 'ukuncancisa',
    '👼' => 'ingelosi elusana',
    '🎅' => 'U-Santa Claus',
    '🤶' => 'UNksz. Claus',
    '🧙' => 'i-mage',
    '🧚' => 'umkholonjane',
    '🧛' => 'i-vampire',
    '🧜' => 'i-merperson',
    '🧝' => 'uhili',
    '🧞' => 'i-genie',
    '🧟' => 'isithunzela',
    '💆' => 'umntu ophululwayo',
    '💇' => 'umntu ocheba iinwele',
    '🚶' => 'umntu ohambayo',
    '🏃' => 'umntu obalekayo',
    '💃' => 'ibhinqa elidanisayo',
    '🕺' => 'indoda edanisayo',
    '🕴' => 'indoda enxibe isuti yeshishini endandayo',
    '👯' => 'abantu abaneendlebe zomvundla abakwitheko',
    '🧖' => 'umntu okwigumbi lomphunga',
    '🧗' => 'umntu onyukayo',
    '🤺' => 'umntu olwa ngesabile',
    '🏇' => 'ihashe elikumdyarho',
    '⛷' => 'umntu otyibilika kwikhephu',
    '🏂' => 'umtyibilizi kwikhephu',
    '🏌' => 'umntu odlala igalufa',
    '🏄' => 'umntu otyibiliza phezu kwamaza',
    '🚣' => 'umntu obheqa iphenyane',
    '🏊' => 'umntu oqubhayo',
    '⛹' => 'umntu ogqampisa ibhola',
    '🏋' => 'umntu ophakamisa iintsimbi',
    '🚴' => 'umntu oqhuba ibhayisekile',
    '🚵' => 'umntu oqhuba ibhayisekile entabeni',
    '🤸' => 'umntu owenza uqilikibhode ngecala',
    '🤼' => 'abantu abangqulanayo',
    '🤽' => 'umntu odlala i-polo yasemanzini',
    '🤾' => 'umntu odlala ibhola yesandla',
    '🤹' => 'umntu oqhathayo',
    '🧘' => 'umntu okwimo ye-lotus',
    '🛀' => 'umntu ohlambayo',
    '🛌' => 'umntu osebhedini',
    '👭' => 'amabhinqa amabini abambene ngezandla',
    '👫' => 'indoda nebhinqa abambe izandla',
    '👬' => 'amadoda amabini abambene ngezandla',
    '💏' => 'phuza',
    '💑' => 'isibini esinentliziyo',
    '🗣' => 'intloko ethethayo',
    '👤' => 'umfanekiso oqingqiweyo wentloko namagxa',
    '👥' => 'imifanekiso eqingqiweyo yentloko namagxa',
    '👪' => 'usapho',
    '👣' => 'imizila yeenyawo',
    '🐵' => 'ubuso benkawu',
    '🐒' => 'inkawu',
    '🦍' => 'igorila',
    '🐶' => 'ubuso benja',
    '🐕' => 'inja',
    '🐩' => 'i-poodle',
    '🐺' => 'ubuso bengcuka',
    '🦊' => 'ubuso bempungutye',
    '🐱' => 'ubuso bekati',
    '🐈' => 'ikati',
    '🦁' => 'ubuso bengonyama',
    '🐯' => 'ubuso bengwe',
    '🐅' => 'ingwe',
    '🐆' => 'ihlosi',
    '🐴' => 'ubuso behashe',
    '🐎' => 'ihashe',
    '🦄' => 'ubuso bophondo-lunye',
    '🦓' => 'iqhwarhashe',
    '🦌' => 'ixhama',
    '🐮' => 'ubuso benkomo',
    '🐂' => 'inkunzi yenkomo',
    '🐃' => 'inyathi yamanzi',
    '🐄' => 'inkomo',
    '🐷' => 'ubuso behagu',
    '🐖' => 'ihagu',
    '🐗' => 'inkunzi yehagu',
    '🐽' => 'impumlo yehagu',
    '🐏' => 'inkunzi yegusha',
    '🐑' => 'imazi yegusha',
    '🐐' => 'ibhokhwe',
    '🐪' => 'inkamela',
    '🐫' => 'inkamela enamalunda amabini',
    '🦒' => 'indlulamthi',
    '🐘' => 'indlovu',
    '🦏' => 'umkhombe',
    '🐭' => 'ubuso bempuku',
    '🐁' => 'impuku',
    '🐀' => 'ibuzi',
    '🐹' => 'ubuso be-hamster',
    '🐰' => 'ubuso bomvundla',
    '🐇' => 'umvundla',
    '🐿' => 'i-chipmunk',
    '🦔' => 'i-hedgehog',
    '🦇' => 'ilulwane',
    '🐻' => 'ubuso bebhere',
    '🐨' => 'i-koala',
    '🐼' => 'ubuso bepanda',
    '🐾' => 'imizila yethupha',
    '🦃' => 'i-turkey',
    '🐔' => 'inkuku',
    '🐓' => 'inkunzi yenkuku',
    '🐣' => 'intshontsho eliqanduselayo',
    '🐤' => 'intshontsho',
    '🐥' => 'intshontsho elijonge ngaphambili',
    '🐦' => 'intaka',
    '🐧' => 'iphengwini',
    '🕊' => 'ihobe',
    '🦅' => 'ukhozi',
    '🦆' => 'idada',
    '🦉' => 'isikhova',
    '🐸' => 'ubuso besele',
    '🐊' => 'ingwenya',
    '🐢' => 'ufudo',
    '🦎' => 'icikilishe',
    '🐍' => 'inyoka',
    '🐲' => 'ubuso be-dragon',
    '🐉' => 'i-dragon',
    '🦕' => 'i-sauropod',
    '🦖' => 'I-T-Rex',
    '🐳' => 'umnenge otsazisa amanzi',
    '🐋' => 'umnenge',
    '🐬' => 'ihlengesi',
    '🐟' => 'intlanzi',
    '🐠' => 'intlanzi yetropiki',
    '🐡' => 'i-blowfish',
    '🦈' => 'ukrebe',
    '🐙' => 'ingwane',
    '🐚' => 'iqokobhe elijikelezayo',
    '🦀' => 'unonkala',
    '🦐' => 'inqonci',
    '🦑' => 'i-squid',
    '🐌' => 'inkumba',
    '🦋' => 'ibhabhathane',
    '🐛' => 'incukuthu',
    '🐜' => 'imbovane',
    '🐝' => 'inyosi yobusi',
    '🐞' => 'uqongqothwane',
    '🦗' => 'iqakamba',
    '🕷' => 'isigcawu',
    '🕸' => 'indlu yesigcawu',
    '🦂' => 'unomadudwane',
    '💐' => 'i-bouquet',
    '🌸' => 'intyatyambo ye-cherry',
    '💮' => 'intyatyambo emhlophe',
    '🏵' => 'i-rosette',
    '🌹' => 'i-rose',
    '🥀' => 'intyatyambo ebunileyo',
    '🌺' => 'umlolwa',
    '🌻' => 'ujongilanga',
    '🌼' => 'i-blossom',
    '🌷' => 'i-tulip',
    '🌱' => 'imbewana',
    '🌲' => 'umthi ohlala uluhlaza',
    '🌳' => 'umthi ovuthulukayo',
    '🌴' => 'umthi wesundu',
    '🌵' => 'i-cactus',
    '🌾' => 'isithungu serayisi',
    '🌿' => 'isityalo',
    '☘' => 'i-shamrock',
    '🍀' => 'ifula elinamagqabi amane',
    '🍁' => 'umthi we-maple',
    '🍂' => 'igqabi eliwileyo',
    '🍃' => 'igqabi eliphaphathekayo emoyeni',
    '🍄' => 'ikhowa',
    '🍇' => 'idiliya',
    '🍈' => 'umxoxozi',
    '🍉' => 'ivatala',
    '🍊' => 'inartyisi',
    '🍋' => 'i-lemon',
    '🍌' => 'ibhanana',
    '🍍' => 'ipayinapile',
    '🍎' => 'iapile elibomvu',
    '🍏' => 'iapile eliluhlaza',
    '🍐' => 'ipere',
    '🍑' => 'ipesika',
    '🍒' => 'i-cherries',
    '🍓' => 'iqunube',
    '🥝' => 'isiqhamo sekiwi',
    '🍅' => 'itumato',
    '🥥' => 'ikhokhonathi',
    '🥑' => 'i-avocado',
    '🍆' => 'i-eggplant',
    '🥔' => 'itapile',
    '🥕' => 'umnqathe',
    '🌽' => 'isikhwebu sombona',
    '🌶' => 'ipepile eshushu',
    '🥒' => 'inkonkomire',
    '🥦' => 'i-broccoli',
    '🥜' => 'amandongomane',
    '🌰' => 'i-chestnut',
    '🍞' => 'isonka',
    '🥐' => 'i-croissant',
    '🥖' => 'isonka se-baguette',
    '🥨' => 'i-pretzel',
    '🥞' => 'i-pancakes',
    '🧀' => 'iverhe yetshizi',
    '🍖' => 'inyama esethanjeni',
    '🍗' => 'umlenze wehagu',
    '🥩' => 'umsiko wenyama',
    '🥓' => 'ispeke',
    '🍔' => 'i-hamburger',
    '🍟' => 'i-french fries',
    '🍕' => 'i-pizza',
    '🌭' => 'i-hot dog',
    '🥪' => 'i-sandwich',
    '🌮' => 'i-taco',
    '🌯' => 'i-burrito',
    '🥙' => 'isonka esimcaba esihlohliweyo',
    '🥚' => 'iqanda',
    '🍳' => 'ukupheka',
    '🥘' => 'ipani elinganzulwanga lokutya',
    '🍲' => 'imbiza yokutya',
    '🥣' => 'isitya esinecephe',
    '🥗' => 'isaladi eluhlaza',
    '🍿' => 'umbona oqhashumbayo',
    '🥫' => 'ukutya okusetotini',
    '🍱' => 'ibhokisi ye-bento',
    '🍘' => 'i-rice cracker',
    '🍙' => 'ibhola yerayisi',
    '🍚' => 'irayisi ephekiweyo',
    '🍛' => 'irayisi yekheri',
    '🍜' => 'isitya esiqhumayo',
    '🍝' => 'i-spaghetti',
    '🍠' => 'ibhatata ekroqiweyo',
    '🍢' => 'i-oden',
    '🍣' => 'i-sushi',
    '🍤' => 'inqonci eqhotsiweyo',
    '🍥' => 'i-fish cake enokujikeleza',
    '🍡' => 'i-dango',
    '🥟' => 'imbulanga yentlama',
    '🥠' => 'iqebengwane lethamsanqa',
    '🥡' => 'ibhokisi ye-takeout',
    '🍦' => 'iayiskrim ethambileyo',
    '🍧' => 'umkhenkce osikiweyo',
    '🍨' => 'iayiskrim',
    '🍩' => 'idonathi',
    '🍪' => 'iqebengwane',
    '🎂' => 'ikeyiki yomhla wokuzalwa',
    '🍰' => 'i-shortcake',
    '🥧' => 'ipayi',
    '🍫' => 'isixwexwe setshokolethi',
    '🍬' => 'ilekese',
    '🍭' => 'i-lollipop',
    '🍮' => 'ikhastadi',
    '🍯' => 'imbiza yobusi',
    '🍼' => 'ibhotile yosana',
    '🥛' => 'iglasi yobisi',
    '☕' => 'isiselo esishushu',
    '🍵' => 'ikomityi engenamqheba',
    '🍶' => 'i-sake',
    '🍾' => 'ibhotile enesiciko esitsibayo',
    '🍷' => 'iglasi yewayine',
    '🍸' => 'iglasi ye-cocktail',
    '🍹' => 'isiselo setropiki',
    '🍺' => 'imagi yebhiya',
    '🍻' => 'iimagi zebhiya ezingqubanayo',
    '🥂' => 'iiglasi ezingqubanayo',
    '🥃' => 'iglasi engenamqheba',
    '🥤' => 'ikomityi enestro',
    '🥢' => 'i-chopsticks',
    '🍽' => 'ifolokhwe nemela nepleyiti',
    '🍴' => 'imela nefolokhwe',
    '🥄' => 'icephe',
    '🔪' => 'imela yasekhitshini',
    '🏺' => 'i-amphora',
    '🌍' => 'iglobhu ebonisa iYurophu-Afrika',
    '🌎' => 'iglobhu ebonisa i-America',
    '🌏' => 'iglobhu ebonisa i-Asia-Ostreliya',
    '🌐' => 'iglobhu enemeridian',
    '🗺' => 'imaphu yehlabathi',
    '🗾' => 'imaphu yaseJapan',
    '🏔' => 'intyaba egcwele ikhephu',
    '⛰' => 'intaba',
    '🌋' => 'intabamlilo',
    '🗻' => 'intaba i-fuji',
    '🏕' => 'ukuhlala ententeni',
    '🏖' => 'unxweme kunye nesambreli',
    '🏜' => 'intlango',
    '🏝' => 'isiqithi sentlango',
    '🏞' => 'ipaki yelizwe',
    '🏟' => 'isitediyam',
    '🏛' => 'isakhiwo sakudala',
    '🏗' => 'ulwakhiwo lwesakhiwo',
    '🏘' => 'izindlu',
    '🏚' => 'indlu eyekiweyo',
    '🏠' => 'indlu',
    '🏡' => 'indlu enegadi',
    '🏢' => 'isakhiwo seofisi',
    '🏣' => 'iposofi yaseJapan',
    '🏤' => 'iposofi',
    '🏥' => 'isibhedlele',
    '🏦' => 'ibhanki',
    '🏨' => 'ihotele',
    '🏩' => 'ihotele yothando',
    '🏪' => 'ivenkile yoncedo',
    '🏫' => 'isikolo',
    '🏬' => 'ivenkile yecandelo',
    '🏭' => 'ifekri',
    '🏯' => 'inqaba yaseJapan',
    '🏰' => 'inqaba',
    '💒' => 'umtshato',
    '🗼' => 'inqaba yase-Tokyo',
    '🗽' => 'Umfanekiso oqingqiweyo Wenkululeko',
    '⛪' => 'icawe',
    '🕌' => 'i-mosque',
    '🕍' => 'isinagoga',
    '⛩' => 'itempilo ye-shinto',
    '🕋' => 'i-kaaba',
    '⛲' => 'ingxangxasi',
    '⛺' => 'intente',
    '🌁' => 'kunenkungu',
    '🌃' => 'ubusuku obuneenkwenkwezi',
    '🏙' => 'i-cityscape',
    '🌄' => 'ukuphuma kwelanga phezu kweentaba',
    '🌅' => 'ukuphuma kwelanga',
    '🌆' => 'i-cityscape ngorhatya',
    '🌇' => 'intshona langa',
    '🌉' => 'ibrorho ebusuku',
    '♨' => 'i-hot springs',
    '🎠' => 'ihashe lomthayi',
    '🎡' => 'ivili le-ferris',
    '🎢' => 'umahla-ndeyuka',
    '💈' => 'ipali yomchebi weenwele',
    '🎪' => 'intente yesekisi',
    '🚂' => 'intloko kaloliwe',
    '🚃' => 'imoto yesiporo',
    '🚄' => 'uloliwe obalekayo',
    '🚅' => 'uloliwe obalekayo onempumlo yembumbulu',
    '🚆' => 'uloliwe',
    '🚇' => 'i-metro',
    '🚈' => 'intonga yokukhanya',
    '🚉' => 'isitishi',
    '🚊' => 'utramu',
    '🚝' => 'isiporo esinenkasayiya enye',
    '🚞' => 'isiporo sentaba',
    '🚋' => 'imoto katramu',
    '🚌' => 'ibhasi',
    '🚍' => 'ibhasi ezayo',
    '🚎' => 'ibhasi yombane',
    '🚐' => 'ibhasi encinci',
    '🚑' => 'iambulensi',
    '🚒' => 'injini yomlilo',
    '🚓' => 'imoto yamapolisa',
    '🚔' => 'imoto yamapolisa ezayo',
    '🚕' => 'iteksi',
    '🚖' => 'iteksi ezayo',
    '🚗' => 'inqwelo-mafutha',
    '🚘' => 'imoto ezayo',
    '🚙' => 'inqwelo-mafutha yoncedo yomdlalo',
    '🚚' => 'itraka yomthwalo',
    '🚛' => 'itraka edityanisiweyo',
    '🚜' => 'itrekta',
    '🏎' => 'imoto yomdyarho',
    '🏍' => 'i-motorcycle',
    '🛵' => 'isithuthuthu semoto',
    '🚲' => 'ibhayisikile',
    '🛴' => 'isithuthuthu esikhatywayo',
    '🚏' => 'indawo yokuma ibhasi',
    '🛣' => 'isitrato esikhulu',
    '🛤' => 'indlela yesiporo',
    '🛢' => 'igubu leoli',
    '⛽' => 'impompo yepetroli',
    '🚨' => 'isibane semoto yamapolisa',
    '🚥' => 'isibane setrafiki esithe tyaba',
    '🚦' => 'isibane setrafiki esithe nkqo',
    '🛑' => 'umqondiso wokumisa',
    '🚧' => 'ulwakhiwo',
    '⚓' => 'i-ankile',
    '⛵' => 'iphenyana',
    '🛶' => 'iphenyane',
    '🚤' => 'iphenyana lesantya',
    '🛳' => 'inqanawa yepasenja',
    '⛴' => 'isikhitshana',
    '🛥' => 'i-motor boat',
    '🚢' => 'inqanawa',
    '✈' => 'inqwelo-moya',
    '🛩' => 'inqwelo-moya encinane',
    '🛫' => 'ukunduluka kwenqwelo-moya',
    '🛬' => 'ukufika kwenqwelo-moya',
    '💺' => 'isihlalo',
    '🚁' => 'ihelikopta',
    '🚟' => 'isiporo esixhonyiweyo',
    '🚠' => 'indlela yeentsontela yentaba',
    '🚡' => 'umgaqo katramu womoya',
    '🛰' => 'i-satellite',
    '🚀' => 'isiphekepheke',
    '🛸' => 'isosa ebhabhayo',
    '🛎' => 'intsimbi ye-bellhop',
    '⌛' => 'i-hourglass',
    '⏳' => 'i-hourglass enesanti ehlayo',
    '⌚' => 'bukela',
    '⏰' => 'iwotshi yealam',
    '⏱' => 'istophu-wotshi',
    '⏲' => 'iwotshi yesibali-xesha',
    '🕰' => 'iwotshi ye-mantelpiece',
    '🕛' => 'intsimbi yeshumi elinesibini',
    '🕧' => 'icala emva kwentsimbi yeshumi elinesibini',
    '🕐' => 'intsimbi yokuqala',
    '🕜' => 'icala emva kwentsimbi yokuqala',
    '🕑' => 'intsimbi yesibini',
    '🕝' => 'icala emva kwentsimbi yesibini',
    '🕒' => 'intsimbi yesithathu',
    '🕞' => 'icala emva kwentsimbi yesithathu',
    '🕓' => 'intsimbi yesine',
    '🕟' => 'icala emva kwentsimbi yesine',
    '🕔' => 'intsimbi yesihlanu',
    '🕠' => 'icala emva kwentsimbi yesihlanu',
    '🕕' => 'intsimbi yesithandathu',
    '🕡' => 'icala emva kwentsimbi yesithandathu',
    '🕖' => 'intsimbi yesixhenxe',
    '🕢' => 'icala emva kwentsimbi yesixhenxe',
    '🕗' => 'intsimbi yesibhozo',
    '🕣' => 'icala emva kwentsimbi yesibhozo',
    '🕘' => 'intsimbi yethoba',
    '🕤' => 'icala emva kwentsimbi yethoba',
    '🕙' => 'intsimbi yeshumi',
    '🕥' => 'icala emva kwentsimbi yeshumi',
    '🕚' => 'intsimbi yeshumi elinanye',
    '🕦' => 'icala emva kwentsimbi yeshumi elinanye',
    '🌑' => 'inyanga entsha',
    '🌒' => 'inyanga elicala efayo',
    '🌓' => 'inyanga yekota yokuqala',
    '🌔' => 'inyanga eliceba efayo',
    '🌕' => 'inyanga epheleleyo',
    '🌖' => 'inyanga eliceba ethwasayo',
    '🌗' => 'inyanga yekota yokugqibela',
    '🌘' => 'inyanga elicala ethwasayo',
    '🌙' => 'inyanga elicala',
    '🌚' => 'ubuso benyanga entsha',
    '🌛' => 'inyanga yekota yokuqala enobuso',
    '🌜' => 'inyanga yekota yokugqibela enobuso',
    '🌡' => 'i-thermometer',
    '☀' => 'ilanga',
    '🌝' => 'inyanga epheleleyo enobuso',
    '🌞' => 'ilanga elinobuso',
    '⭐' => 'inkwenkwezi ephakathi emhlophe',
    '🌟' => 'inkwenkwezi ekhanyayo',
    '🌠' => 'inkwenkwezi edubulayo',
    '🌌' => 'umnyele wezulu',
    '☁' => 'ilifu',
    '⛅' => 'ilanga elisemva kwamafu',
    '⛈' => 'ilifu elinombane nemvula',
    '🌤' => 'ilanga elisemva kwelifu elincinane',
    '🌥' => 'ilanga elisemva kwelifu elikhulu',
    '🌦' => 'ilanga elisemva kwelifu lemvula',
    '🌧' => 'ilifu elinemvula',
    '🌨' => 'ilifu elinekhephu',
    '🌩' => 'ilifu elinombane',
    '🌪' => 'isaqhwithi',
    '🌫' => 'inkungu',
    '🌬' => 'ubuso bomoya',
    '🌀' => 'inkanyamba',
    '🌈' => 'umnyama',
    '🌂' => 'isambrela esivaliweyo',
    '☂' => 'isambreli',
    '☔' => 'isambreli esinamathontsi emvula',
    '⛱' => 'isambreli esisemgangathweni',
    '⚡' => 'amandla ombane aphezulu',
    '❄' => 'ihlwantsi lekhephu',
    '☃' => 'umntu wekhephu',
    '⛄' => 'umntu wekhephu ngaphandle kwekhephu',
    '☄' => 'i-comet',
    '🔥' => 'umlilo',
    '💧' => 'iqabaza',
    '🌊' => 'iliza lamanzi',
    '🎃' => 'i-Jack-o-lantern',
    '🎄' => 'umthi wekrismesi',
    '🎆' => 'iziqhushumbi',
    '🎇' => 'isikhazimli',
    '✨' => 'izikhazimli',
    '🎈' => 'ibhaloni',
    '🎉' => 'isidubuli setheko',
    '🎊' => 'ibhola enamaphepha amahle',
    '🎋' => 'umthi we-tanabata',
    '🎍' => 'umhombiso wompayini',
    '🎎' => 'oonodoli baseJapan',
    '🎏' => 'i-carp streamer',
    '🎐' => 'iintsimbi zomoya',
    '🎑' => 'umsitho wokubukela inyanga',
    '🎀' => 'iribhoni',
    '🎁' => 'isipho esibotshiweyo',
    '🎗' => 'iribhoni yesikhumbuzi',
    '🎟' => 'itikiti lamangeno',
    '🎫' => 'itikiti',
    '🎖' => 'imbasa yasebukhosini',
    '🏆' => 'imbasa',
    '🏅' => 'imbasa yezemidlalo',
    '🥇' => 'imbasa yendawo yoku-1',
    '🥈' => 'imbasa yendawo yesi-2',
    '🥉' => 'imbasa yendawo yesi-3',
    '⚽' => 'ibhola yesoka',
    '⚾' => 'i-baseball',
    '🏀' => 'i-basketball',
    '🏐' => 'i-volleyball',
    '🏈' => 'i-american football',
    '🏉' => 'umbhoxo',
    '🎾' => 'intenetya',
    '🎳' => 'umdlalo ngeebhola zomthi',
    '🏏' => 'umdlalo weqakamba',
    '🏑' => 'i-hockey yasebaleni',
    '🏒' => 'i-ice hockey',
    '🏓' => 'i-ping pong',
    '🏸' => 'i-badminton',
    '🥊' => 'iglavu yamanqindi',
    '🥋' => 'iyunifomu ye-martial arts',
    '🥅' => 'umnatha wenqaku',
    '⛳' => 'iflegi ekwintongo',
    '⛸' => 'ukutyibiliza kwiayisi',
    '🎣' => 'intonga yokuloba',
    '🎽' => 'ihempe yokubaleka',
    '🎿' => 'i-skis',
    '🛷' => 'isileyi',
    '🥌' => 'ilitye lokugoba',
    '🎯' => 'ukuchana ngokuthe ngqo',
    '🔫' => 'umpu',
    '🎱' => 'i-pool 8 ball',
    '🔮' => 'ibhola yekristale',
    '🎮' => 'umdlalo wevidiyo',
    '🕹' => 'i-joystick',
    '🎰' => 'umatshini wokuthengisa',
    '🎲' => 'idayisi lomdlalo',
    '♠' => 'i-spade suit',
    '♥' => 'isuti yentliziyo',
    '♦' => 'isuti yedayimani',
    '♣' => 'isuti yeklabhu',
    '🃏' => 'umhlekisi',
    '🀄' => 'i-mahjong red dragon',
    '🎴' => 'amakhasi okudlala entatyambo',
    '🎭' => 'ukudlala ubugcisa',
    '🖼' => 'umfanekiso onasekhelo',
    '🎨' => 'iplanga lepeyinti legcisa',
    '👓' => 'iiglasi',
    '🕶' => 'iindondo',
    '👔' => 'iqhina',
    '👕' => 'isikipa',
    '👖' => 'iijini',
    '🧣' => 'isikhafu',
    '🧤' => 'iiglavu',
    '🧥' => 'idyasi',
    '🧦' => 'iikawusi',
    '👗' => 'ilokhwe',
    '👘' => 'i-kimono',
    '👙' => 'i-bikini',
    '👚' => 'iimpahla zamabhinqa',
    '👛' => 'isipaji',
    '👜' => 'ingxowa yamakhosikazi',
    '👝' => 'ibhegi ephathwayo',
    '🛍' => 'iibhegi zokuthenga',
    '🎒' => 'ubhaka wesikolo',
    '👞' => 'isihlangu sendoda',
    '👟' => 'isihlangu sokubaleka',
    '👠' => 'isihlangu esinesithende esiphakamileyo',
    '👡' => 'imbadada yebhinqa',
    '👢' => 'ibhutsi yebhinqa',
    '👑' => 'isithsaba',
    '👒' => 'umnqwazi webhinqa',
    '🎩' => 'i-top hat',
    '🎓' => 'umnqwazi wothweso-zidanga',
    '🧢' => 'umnqwazi ohlawulelweyo',
    '⛑' => 'isigcina-ntloko somsebenzi womncedo',
    '📿' => 'amaso omthandazo',
    '💄' => 'i-lipstick',
    '💍' => 'umsesane',
    '💎' => 'ilitye elixabisekileyo',
    '🔇' => 'ispikha esicuthiweyo',
    '🔈' => 'ivolyum esezantsi yespikha',
    '🔉' => 'ivolyum ephakathi yespikha',
    '🔊' => 'ivolyum ephezulu yespikha',
    '📢' => 'isandisi-zwi',
    '📣' => 'i-megaphone',
    '📯' => 'uphondo lweposi',
    '🔔' => 'intsimbi',
    '🔕' => 'intsimbi ehlatyiweyo',
    '🎼' => 'inqaku lomculo',
    '🎵' => 'inowuthi yomculo',
    '🎶' => 'iinowuthi zomculo',
    '🎙' => 'i-microphone yestudiyo',
    '🎚' => 'islayida seqondo',
    '🎛' => 'amaqhosha olawulo',
    '🎤' => 'imayikhrofowuni',
    '🎧' => 'i-headphone',
    '📻' => 'irediyo',
    '🎷' => 'i-saxophone',
    '🎺' => 'ixolongo',
    '🎸' => 'ikatala',
    '🎹' => 'ikhibhodi yomculo',
    '🎻' => 'i-violin',
    '🥁' => 'igubu',
    '📱' => 'iselfowuni',
    '📲' => 'iselfowuni enotolo',
    '☎' => 'ifowuni',
    '📞' => 'umqheba wefowuni',
    '📟' => 'ipheyija',
    '📠' => 'umatshani wefeksi',
    '🔋' => 'ibhetri',
    '🔌' => 'iplagi yombane',
    '💻' => 'ikhompyutha ye-laptop',
    '🖥' => 'ikhompyutha yedesktophu',
    '🖨' => 'iprinta',
    '⌨' => 'ikhibhodi',
    '🖱' => 'imawusi yekhompyutha',
    '🖲' => 'i-trackball',
    '💽' => 'idiski yekhompyutha',
    '💾' => 'idiski ye-floppy',
    '💿' => 'idiksi yeliso',
    '📀' => 'i-dvd',
    '🎥' => 'ikhamera yemuvi',
    '🎞' => 'izakhelo zefilimu',
    '📽' => 'iprojektha yefilimu',
    '🎬' => 'ibhodi yemuvi',
    '📺' => 'umabonakude',
    '📷' => 'ikhamera',
    '📸' => 'ikhamera enefleshi',
    '📹' => 'ikhamera yevidiyo',
    '📼' => 'ikhasethi levidiyo',
    '🔍' => 'iglasi yokwandisa ekhombe ekhohlo',
    '🔎' => 'iglasi yokwandisa eyalathe ekunene',
    '🕯' => 'ikhandlela',
    '💡' => 'ibhalbhu yesibane',
    '🔦' => 'isibane',
    '🏮' => 'isibane sephepha elibomvu',
    '📔' => 'incwadi yamanqaku enomphandle ohonjisiweyo',
    '📕' => 'incwadi evaliweyo',
    '📖' => 'incwadi evulekileyo',
    '📗' => 'incwadi eluhlaza',
    '📘' => 'incwadi ebhlowu',
    '📙' => 'incwadi eorenji',
    '📚' => 'iincwadi',
    '📓' => 'incwadi yamanqaku',
    '📒' => 'ileja',
    '📃' => 'iphepha elinomjiko',
    '📜' => 'skrola',
    '📄' => 'iphepha elijonge phezulu',
    '📰' => 'iphephandaba',
    '🗞' => 'iphephandaba elisongiweyo',
    '📑' => 'iithebhu zebhukmakhi',
    '🔖' => 'ibhukmakhi',
    '🏷' => 'ileyibhuli',
    '💰' => 'ibhegi yemali',
    '💴' => 'imali eliphepha yase-yen',
    '💵' => 'imali yephepha ye-dollar',
    '💶' => 'imali eliphepha ye-euro',
    '💷' => 'imali eliphepha ye-pound',
    '💸' => 'imali eneempiko',
    '💳' => 'ikhadi letyala',
    '💹' => 'itshati iyanda nge-yen',
    '✉' => 'imvulophu',
    '📧' => 'i-imeyile',
    '📨' => 'imvulophu engenayo',
    '📩' => 'imvulophu enotolo',
    '📤' => 'itreyi yeziphumayo',
    '📥' => 'itreyi yezingenayo',
    '📦' => 'iphakheji',
    '📫' => 'ibhokisi yeposi evaliweyo eneflegi enyusiweyo',
    '📪' => 'ibhokisi yeposi evaliweyo eneflegi ehlisiweyo',
    '📬' => 'vula ibhokisi yeposi eneflegi enyusiweyo',
    '📭' => 'vula ibhokisi yeposi eneflegi ehlisiweyo',
    '📮' => 'ibhokisi yeposi',
    '🗳' => 'ibhokisi yebhalothi enebhalothi',
    '✏' => 'ipensile',
    '✒' => 'incam yosiba emnyama',
    '🖋' => 'usiba lwengxangxasi',
    '🖊' => 'usiba',
    '🖌' => 'ibhrasi yokupeyinta',
    '🖍' => 'ikhrayoni',
    '📝' => 'imemo',
    '💼' => 'ibrifkheyisi',
    '📁' => 'ifolda yefayile',
    '📂' => 'ifolda yefayile evulekileyo',
    '🗂' => 'izahluli zeindeksi yekhadi',
    '📅' => 'ikhalenda',
    '📆' => 'krazula ikhalenda',
    '🗒' => 'iphedi yamanqaku ejikelezayo',
    '🗓' => 'ikhalenda ejikelezayo',
    '📇' => 'ikhadi leindeksi',
    '📈' => 'itshati iyanda',
    '📉' => 'itshati iyehla',
    '📊' => 'itshati yebha',
    '📋' => 'iklipbhodi',
    '📌' => 'i-pushpin',
    '📍' => 'unotaka otyhalwayo ongqukuva',
    '📎' => 'ikliphu yephepha',
    '🖇' => 'ikliphu yephepha edityanisiweyo',
    '📏' => 'irula ethe tye',
    '📐' => 'irula engunxantathu',
    '✂' => 'izikere',
    '🗃' => 'ibhokisi yefayile yamakhadi',
    '🗄' => 'ikhabhathi yefayile',
    '🗑' => 'ibhaskithi yenkunkuma',
    '🔒' => 'itshixiwe',
    '🔓' => 'ayitshixwanga',
    '🔏' => 'itshixwe ngosiba',
    '🔐' => 'itshixwe ngesitshixo',
    '🔑' => 'iqhosha',
    '🗝' => 'iqhosha elidala',
    '🔨' => 'ihamile',
    '⛏' => 'ipeki',
    '⚒' => 'ihamile nepeki',
    '🛠' => 'ihamile nebhobhotyana',
    '🗡' => 'isinkempe',
    '⚔' => 'amakrele anqamlezileyo',
    '💣' => 'ibhombu',
    '🏹' => 'isaphetha notolo',
    '🛡' => 'ikhaka',
    '🔧' => 'ibhobhotyane',
    '🔩' => 'imortyisi nesikhonkwane',
    '⚙' => 'igiyeri',
    '🗜' => 'isibambi',
    '⚖' => 'iskali sokulinganisa',
    '🔗' => 'ikhonkco',
    '⛓' => 'amatsheyina',
    '⚗' => 'i-alembic',
    '🔬' => 'i-microscope',
    '🔭' => 'i-telescope',
    '📡' => 'intonga yesathelayithi',
    '💉' => 'isirinji',
    '💊' => 'ipilisi',
    '🚪' => 'ucango',
    '🛏' => 'ibhedi',
    '🛋' => 'isofa nesibane',
    '🚽' => 'ithoyilethi',
    '🚿' => 'ishawa',
    '🛁' => 'ibhafu yokuhlambela',
    '🛒' => 'inqwelo yokuthenga',
    '🚬' => 'icuba',
    '⚰' => 'ibhokisi',
    '⚱' => 'ingqayi yomngcwabo',
    '🗿' => 'i-moai',
    '🏧' => 'uphawu lwe-ATM',
    '🚮' => 'uphawu lwenkunkuma esemgqomeni',
    '🚰' => 'amanzi aphathwayo',
    '♿' => 'isimboli yesitulo samavili',
    '🚹' => 'igumbi lamadoda',
    '🚺' => 'igumi lamabhinqa',
    '🚻' => 'igumbi lokuphumla',
    '🚼' => 'isimboli yosana',
    '🚾' => 'ithoyilethi egungxulwayo',
    '🛂' => 'ulawulo lwephaspoti',
    '🛃' => 'amasiko',
    '🛄' => 'ukulanda impahla',
    '🛅' => 'umthwalo wasekhohlo',
    '⚠' => 'isilumkiso',
    '🚸' => 'abantwana abawelayo',
    '⛔' => 'akungenwa',
    '🚫' => 'yalelwe',
    '🚳' => 'iibhayisekile azivumelekanga',
    '🚭' => 'akutshaywa',
    '🚯' => 'akulahlwa nkunkuma',
    '🚱' => 'amanzi angaphathwayo',
    '🚷' => 'abahambi abavumelekanga',
    '📵' => 'iiselfowuni azivumelekanga',
    '🔞' => 'abangaphantsi kwelishumi elinesibhozo abavumelekanga',
    '☢' => 'i-radioactive',
    '☣' => 'i-biohazard',
    '⬆' => 'utolo oluphezulu',
    '↗' => 'utolo olujonge phezulu',
    '➡' => 'utolo olusekunene',
    '↘' => 'utolo olujonge ezantsi',
    '⬇' => 'utolo olusezantsi',
    '↙' => 'utolo olusezantsi ekhohlo',
    '⬅' => 'utolo olusekhohlo',
    '↖' => 'utolo olusekhohlo phezulu',
    '↕' => 'utolo olusezantsi phezulu',
    '↔' => 'utolo olusekunene ekhohlo',
    '↩' => 'utolo olusekunene olugobe ekhohlo',
    '↪' => 'utolo olusekhohlo olugobe ekunene',
    '⤴' => 'utolo olusekunene olugobe phezulu',
    '⤵' => 'utolo olusekunene olugobe ezantsi',
    '🔃' => 'amatolo athe nkqo ajikeleza ngasekunene',
    '🔄' => 'iqhosha lamatolo elijikeleza ngasekunene',
    '🔙' => 'utolo oluthi EMVA',
    '🔚' => 'utolo oluthi UKUPHELA',
    '🔛' => 'utolo oluthi iLayitile!',
    '🔜' => 'utolo oluthi KUNGEKUDALA',
    '🔝' => 'utolo oluthi PHEZULU',
    '🛐' => 'indawo yokunqula',
    '⚛' => 'isimboli yeatom',
    '🕉' => 'i-om',
    '✡' => 'inkwenkwezi kaDavide',
    '☸' => 'ivili le-dharma',
    '☯' => 'i-yin yang',
    '✝' => 'umnqamlezo we-latin',
    '☦' => 'umnqamlezo we-orthodox',
    '☪' => 'inkwenkwezi neceba',
    '☮' => 'isimboli yoxolo',
    '🕎' => 'i-menorah',
    '🔯' => 'inkwenkwezi eneekona ezintandathu enechaphaza',
    '♈' => 'I-Aries',
    '♉' => 'I-Taurus',
    '♊' => 'I-Gemini',
    '♋' => 'I-Cancer',
    '♌' => 'I-Leo',
    '♍' => 'I-Virgo',
    '♎' => 'I-Libra',
    '♏' => 'I-scorpius',
    '♐' => 'I-Sagittarius',
    '♑' => 'I-Capricorn',
    '♒' => 'I-Aquarius',
    '♓' => 'I-Pisces',
    '⛎' => 'I-Ophiuchus',
    '🔀' => 'iqhosha lokushafula iingoma',
    '🔁' => 'iqhosha lokuphinda',
    '🔂' => 'iqhosha elithi phinda kanye',
    '▶' => 'iqhosha lokudlala',
    '⏩' => 'iqhosha lokukhawulezisa',
    '⏭' => 'iqhosha lengoma elandelayo',
    '⏯' => 'iqhosha lokudlala okanye lokunqumamisa',
    '◀' => 'iqhosha lokubuyisela emva',
    '⏪' => 'iqhosha lobuyisel’ umva ngokukhawuleza',
    '⏮' => 'iqhosha lengoma yokugqibela',
    '🔼' => 'iqhosha laphezulu',
    '⏫' => 'iqhosha laphezulu ngokukhawuleza',
    '🔽' => 'iqhosha lasezantsi',
    '⏬' => 'iqhosha lasezantsi lokukhawulezisa',
    '⏸' => 'iqhosha lokunqumamisa',
    '⏹' => 'iqhosha lokumisa',
    '⏺' => 'iqhosha lokurekhoda',
    '⏏' => 'iqhosha lokukhupha',
    '🎦' => 'isinema',
    '🔅' => 'iqhosha lobumfiliba',
    '🔆' => 'iqhosha elikhanyayo',
    '📶' => 'iibha zentonga',
    '📳' => 'imowudi eshukumayo',
    '📴' => 'iselfowuni icimile',
    '♀' => 'uphawu lwebhinqa',
    '♂' => 'uphawu lwendoda',
    '✖' => 'uphindaphindo olungqindilili x',
    '➕' => 'uphawu lokudibanisa olungqindilili',
    '➖' => 'uphawu lokuthabatha olungqindilili',
    '➗' => 'uphawu lolwahlulo olungqindilili',
    '‼' => 'uphawu lwesikhuzo ophindaphindeneyo',
    '⁉' => 'uphawu lombuzo lwesikhuzo',
    '❓' => 'uphawu lombuzo',
    '❔' => 'uphawu lombuzo olumhlophe',
    '❕' => 'uphawu lwesikhuzo olumhlophe',
    '❗' => 'uphawu lwesikhuzo',
    '〰' => 'idesh ewangawangisayo',
    '💱' => 'utshintshiselwano lwekharensi',
    '💲' => 'uphawu lwe-dollar olungqindilili',
    '⚕' => 'isimboli yezonyango',
    '♻' => 'isimboli yokubuyisela kwimo yangaphambili',
    '⚜' => 'i-fleur-de-lis',
    '🔱' => 'umfuziselo womkhonto oneencam ezintathu',
    '📛' => 'igama lebheji',
    '🔰' => 'isimboli yaseJapan yabaqalayo',
    '⭕' => 'isangqa esikhulu esingqindilili',
    '✅' => 'uphawu lokuhlola olungqindilili olumhlophe',
    '☑' => 'ibhokisi yebhalothi yokhetho',
    '✔' => 'uphawu lokhetho olungqindilili',
    '❌' => 'uphawu lomnqamlezo',
    '❎' => 'iqhosha lophawu lomnqamlezo',
    '➰' => 'irhintyela eliphotheneyo',
    '➿' => 'irhintyela eliphotheneyo kabini',
    '〽' => 'uphawu lwenguqulelo oluyinxalenye',
    '✳' => 'inkwenkwezana eneencam ezisibhozo',
    '✴' => 'inkwenkwezi eneencam ezisibhozo',
    '❇' => 'khazimla',
    '™' => 'uphawu lorhwebo',
    '🔠' => 'fakela oonobumba abakhulu baselatin',
    '🔡' => 'fakela oonobumba abancinane besilatin',
    '🔢' => 'amanani ongeniso',
    '🔣' => 'iisimboli zongeniso',
    '🔤' => 'fakela oonobumba besilatin',
    '🅰' => 'iqhosha elithi A (uhlobo lwegazi)',
    '🆎' => 'iqhosha elithi AB (uhlobo lwegazi)',
    '🅱' => 'iqhosha elithi B (uhlobo lwegazi)',
    '🆑' => 'iqhosha elithi CL',
    '🆒' => 'iqhosha elithi KUHLE',
    '🆓' => 'iqhosha elithi simahla',
    'ℹ' => 'inkcazelo',
    '🆔' => 'iqhosha le-ID',
    'Ⓜ' => 'wenze isangqa M',
    '🆕' => 'iqhosha elithi ENTSHA',
    '🆖' => 'iqhosha elithi NG',
    '🅾' => 'iqhosha elithi O (uhlobo lwegazi)',
    '🆗' => 'iqhosha elithi KULUNGILE',
    '🅿' => 'iqhosha elithi P',
    '🆘' => 'iqhosha elithi SOS',
    '🆙' => 'iqhosha elithi PHEZULU!',
    '🆚' => 'iqhosha elithi VS',
    '🈁' => 'iqhosha elithi "apha" laseJapan',
    '🈂' => 'Iqhosha elithi “intlawulo yenkonzo” elingesiJapan',
    '🈷' => 'iqhosha elithi "imali yenyanga" lesiJapan',
    '🈶' => 'iqhosha elithi "ayikho simahla" lesiJapan',
    '🈯' => 'iqhosha elithi "ibhukhishiwe" lesiJapan',
    '🉐' => 'iqhosha elithi "isaphulelo" lesiJapan',
    '🈹' => 'iqhosha elithi "lesaphulelo" lesiJapan',
    '🈚' => 'iqhosha elithi "simahala" lesiJapan',
    '🈲' => 'iqhosha elithi "ithintelwe" lesiJapan',
    '🉑' => 'iqhosha elithi "yamkelekile" lesiJapan',
    '🈸' => 'iqhosha elithi "usetyenziso"',
    '🈴' => 'iqhosha elithi "ukuphumelela ibanga" lesiJapan',
    '🈳' => 'iqhosha elithi "umsebenzi" lesiJapan',
    '㊗' => 'iqhosha elithi "huntshu" lesiJapan',
    '㊙' => 'iqhosha elith "imfihlelo" lesiJapan',
    '🈺' => 'iqhosha elithi ’ishishini livulekile’ laseJapan',
    '🈵' => 'iqhosha elithi "akukho msebenzi" lesiJapan',
    '🔴' => 'isangqa esibomvu',
    '🔵' => 'isangqa esibhlowu',
    '⚫' => 'isangqa esimnyama',
    '⚪' => 'isangqa esimhlophe',
    '⬛' => 'iskwere esikhulu esimnyama',
    '⬜' => 'iskwere esikhulu esimhlophe',
    '◼' => 'iskwere esiphakathi esimnyama',
    '◻' => 'iskwere esiphakathi esimhlophe',
    '◾' => 'iskrwere esiphakathi-buncinane esimnyama',
    '◽' => 'iskwere esiphakathi-buncinane esimhlophe',
    '▪' => 'iskwere esincinane esimnyama',
    '▫' => 'iskwere esincinane esimhlophe',
    '🔶' => 'idayimani eorenji enkulu',
    '🔷' => 'idayimani ebhlowu enkulu',
    '🔸' => 'idayimani eorenji encinane',
    '🔹' => 'idayimani ebhlowu encinane',
    '🔺' => 'unxantathu obomvu okhombe phezulu',
    '🔻' => 'unxantathu obomvu okhombe ezantsi',
    '💠' => 'idayimani enechaphaza',
    '🔘' => 'iqhosha lerediyo',
    '🔳' => 'iqhosha leskwere elimhlophe',
    '🔲' => 'iqhosha eliskrwere elimnyama',
    '🏁' => 'iflegi etsheke',
    '🚩' => 'iflegi engunxantathu',
    '🎌' => 'iiflegi ezinqamlezeneyo',
    '🏴' => 'iflegi emnyama',
    '🏳' => 'iflegi emhlophe',
];
